"""Bundled PugBrain skills for Claude Code.

Skills are installed to ~/.claude/skills/ via `pug install-skills`.
"""

from __future__ import annotations

from pathlib import Path

SKILLS_DIR: Path = Path(__file__).parent
