import{j as d}from"./vendor-query-gNoSRy1B.js";import{r as s}from"./vendor-react-Bv3FVr6H.js";import{s as o}from"./index-KKtPEXlb.js";const t=s.forwardRef(({className:a,...r},e)=>d.jsx("div",{ref:e,className:o("rounded-xl border border-border bg-card/70 text-card-foreground shadow-lg backdrop-blur-md transition-all hover:border-primary/30",a),...r}));t.displayName="Card";const i=s.forwardRef(({className:a,...r},e)=>d.jsx("div",{ref:e,className:o("flex flex-col space-y-1.5 p-6",a),...r}));i.displayName="CardHeader";const l=s.forwardRef(({className:a,...r},e)=>d.jsx("div",{ref:e,className:o("font-display text-lg font-semibold leading-none tracking-tight",a),...r}));l.displayName="CardTitle";const n=s.forwardRef(({className:a,...r},e)=>d.jsx("div",{ref:e,className:o("text-sm text-muted-foreground",a),...r}));n.displayName="CardDescription";const m=s.forwardRef(({className:a,...r},e)=>d.jsx("div",{ref:e,className:o("p-6 pt-0",a),...r}));m.displayName="CardContent";export{t as C,i as a,l as b,m as c};
