import{j as t}from"./vendor-query-gNoSRy1B.js";import{s as m}from"./index-KKtPEXlb.js";function n({className:e,...s}){return t.jsx("div",{className:m("animate-pulse rounded-md bg-muted",e),...s})}export{n as S};
