const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OverviewPage-DMeHa7oG.js","assets/vendor-query-gNoSRy1B.js","assets/vendor-react-Bv3FVr6H.js","assets/card-MQ8QxJhT.js","assets/skeleton-B2q3LzC-.js","assets/vendor-ui-B_txYLwR.js","assets/HealthPage-DlixN64H.js","assets/vendor-recharts-DqMNzGhv.js","assets/GraphPage-OYcaWfTG.js","assets/TimelinePage-Bi56EYGw.js","assets/EvolutionPage-gBW1Q5Su.js","assets/DiagramsPage-CpiaiL7z.js","assets/DiagramsPage-BZV40eAE.css","assets/SettingsPage-DVxiNWC1.js","assets/SyncPage-D3717Xlh.js","assets/OraclePage-BL0_Z9Bu.js","assets/ToolStatsPage-Dr1i9c83.js"])))=>i.map(i=>d[i]);
var mp=Object.defineProperty;var pp=(c,u,s)=>u in c?mp(c,u,{enumerable:!0,configurable:!0,writable:!0,value:s}):c[u]=s;var sh=(c,u,s)=>pp(c,typeof u!="symbol"?u+"":u,s);import{j as w,u as Ce,a as Yh,b as Vh,Q as yp,c as vp}from"./vendor-query-gNoSRy1B.js";import{a as Gh,b as bp,R as L,d as Sp,r as K,N as xp,e as Tp,O as Ep,f as Op,h as Ve,i as zp,B as Dp}from"./vendor-react-Bv3FVr6H.js";import{t as Ap,c as Np,D as Cp,L as Mp,H as _p,N as Rp,C as Up,T as wp,S as Bp,a as Lp,b as jp,d as Hp,e as qp,f as Qh,P as Yp,g as Vp,G as Gp,M as Qp,h as Xp,i as Kp}from"./vendor-ui-B_txYLwR.js";(function(){const u=document.createElement("link").relList;if(u&&u.supports&&u.supports("modulepreload"))return;for(const f of document.querySelectorAll('link[rel="modulepreload"]'))o(f);new MutationObserver(f=>{for(const d of f)if(d.type==="childList")for(const m of d.addedNodes)m.tagName==="LINK"&&m.rel==="modulepreload"&&o(m)}).observe(document,{childList:!0,subtree:!0});function s(f){const d={};return f.integrity&&(d.integrity=f.integrity),f.referrerPolicy&&(d.referrerPolicy=f.referrerPolicy),f.crossOrigin==="use-credentials"?d.credentials="include":f.crossOrigin==="anonymous"?d.credentials="omit":d.credentials="same-origin",d}function o(f){if(f.ep)return;f.ep=!0;const d=s(f);fetch(f.href,d)}})();var ac={exports:{}},fi={},nc={exports:{}},lc={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var oh;function Zp(){return oh||(oh=1,(function(c){function u(E,U){var q=E.length;E.push(U);t:for(;0<q;){var at=q-1>>>1,tt=E[at];if(0<f(tt,U))E[at]=U,E[q]=tt,q=at;else break t}}function s(E){return E.length===0?null:E[0]}function o(E){if(E.length===0)return null;var U=E[0],q=E.pop();if(q!==U){E[0]=q;t:for(var at=0,tt=E.length,nt=tt>>>1;at<nt;){var st=2*(at+1)-1,j=E[st],$=st+1,ot=E[$];if(0>f(j,q))$<tt&&0>f(ot,j)?(E[at]=ot,E[$]=q,at=$):(E[at]=j,E[st]=q,at=st);else if($<tt&&0>f(ot,q))E[at]=ot,E[$]=q,at=$;else break t}}return U}function f(E,U){var q=E.sortIndex-U.sortIndex;return q!==0?q:E.id-U.id}if(c.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var d=performance;c.unstable_now=function(){return d.now()}}else{var m=Date,p=m.now();c.unstable_now=function(){return m.now()-p}}var S=[],v=[],N=1,g=null,R=3,B=!1,M=!1,V=!1,et=!1,Q=typeof setTimeout=="function"?setTimeout:null,Dt=typeof clearTimeout=="function"?clearTimeout:null,ft=typeof setImmediate<"u"?setImmediate:null;function ht(E){for(var U=s(v);U!==null;){if(U.callback===null)o(v);else if(U.startTime<=E)o(v),U.sortIndex=U.expirationTime,u(S,U);else break;U=s(v)}}function At(E){if(V=!1,ht(E),!M)if(s(S)!==null)M=!0,vt||(vt=!0,k());else{var U=s(v);U!==null&&ut(At,U.startTime-E)}}var vt=!1,Tt=-1,Nt=5,Ct=-1;function yt(){return et?!0:!(c.unstable_now()-Ct<Nt)}function ae(){if(et=!1,vt){var E=c.unstable_now();Ct=E;var U=!0;try{t:{M=!1,V&&(V=!1,Dt(Tt),Tt=-1),B=!0;var q=R;try{e:{for(ht(E),g=s(S);g!==null&&!(g.expirationTime>E&&yt());){var at=g.callback;if(typeof at=="function"){g.callback=null,R=g.priorityLevel;var tt=at(g.expirationTime<=E);if(E=c.unstable_now(),typeof tt=="function"){g.callback=tt,ht(E),U=!0;break e}g===s(S)&&o(S),ht(E)}else o(S);g=s(S)}if(g!==null)U=!0;else{var nt=s(v);nt!==null&&ut(At,nt.startTime-E),U=!1}}break t}finally{g=null,R=q,B=!1}U=void 0}}finally{U?k():vt=!1}}}var k;if(typeof ft=="function")k=function(){ft(ae)};else if(typeof MessageChannel<"u"){var Z=new MessageChannel,W=Z.port2;Z.port1.onmessage=ae,k=function(){W.postMessage(null)}}else k=function(){Q(ae,0)};function ut(E,U){Tt=Q(function(){E(c.unstable_now())},U)}c.unstable_IdlePriority=5,c.unstable_ImmediatePriority=1,c.unstable_LowPriority=4,c.unstable_NormalPriority=3,c.unstable_Profiling=null,c.unstable_UserBlockingPriority=2,c.unstable_cancelCallback=function(E){E.callback=null},c.unstable_forceFrameRate=function(E){0>E||125<E?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):Nt=0<E?Math.floor(1e3/E):5},c.unstable_getCurrentPriorityLevel=function(){return R},c.unstable_next=function(E){switch(R){case 1:case 2:case 3:var U=3;break;default:U=R}var q=R;R=U;try{return E()}finally{R=q}},c.unstable_requestPaint=function(){et=!0},c.unstable_runWithPriority=function(E,U){switch(E){case 1:case 2:case 3:case 4:case 5:break;default:E=3}var q=R;R=E;try{return U()}finally{R=q}},c.unstable_scheduleCallback=function(E,U,q){var at=c.unstable_now();switch(typeof q=="object"&&q!==null?(q=q.delay,q=typeof q=="number"&&0<q?at+q:at):q=at,E){case 1:var tt=-1;break;case 2:tt=250;break;case 5:tt=1073741823;break;case 4:tt=1e4;break;default:tt=5e3}return tt=q+tt,E={id:N++,callback:U,priorityLevel:E,startTime:q,expirationTime:tt,sortIndex:-1},q>at?(E.sortIndex=q,u(v,E),s(S)===null&&E===s(v)&&(V?(Dt(Tt),Tt=-1):V=!0,ut(At,q-at))):(E.sortIndex=tt,u(S,E),M||B||(M=!0,vt||(vt=!0,k()))),E},c.unstable_shouldYield=yt,c.unstable_wrapCallback=function(E){var U=R;return function(){var q=R;R=U;try{return E.apply(this,arguments)}finally{R=q}}}})(lc)),lc}var ch;function kp(){return ch||(ch=1,nc.exports=Zp()),nc.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var rh;function Jp(){if(rh)return fi;rh=1;var c=kp(),u=Gh(),s=bp();function o(t){var e="https://react.dev/errors/"+t;if(1<arguments.length){e+="?args[]="+encodeURIComponent(arguments[1]);for(var a=2;a<arguments.length;a++)e+="&args[]="+encodeURIComponent(arguments[a])}return"Minified React error #"+t+"; visit "+e+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function f(t){return!(!t||t.nodeType!==1&&t.nodeType!==9&&t.nodeType!==11)}function d(t){var e=t,a=t;if(t.alternate)for(;e.return;)e=e.return;else{t=e;do e=t,(e.flags&4098)!==0&&(a=e.return),t=e.return;while(t)}return e.tag===3?a:null}function m(t){if(t.tag===13){var e=t.memoizedState;if(e===null&&(t=t.alternate,t!==null&&(e=t.memoizedState)),e!==null)return e.dehydrated}return null}function p(t){if(t.tag===31){var e=t.memoizedState;if(e===null&&(t=t.alternate,t!==null&&(e=t.memoizedState)),e!==null)return e.dehydrated}return null}function S(t){if(d(t)!==t)throw Error(o(188))}function v(t){var e=t.alternate;if(!e){if(e=d(t),e===null)throw Error(o(188));return e!==t?null:t}for(var a=t,n=e;;){var l=a.return;if(l===null)break;var i=l.alternate;if(i===null){if(n=l.return,n!==null){a=n;continue}break}if(l.child===i.child){for(i=l.child;i;){if(i===a)return S(l),t;if(i===n)return S(l),e;i=i.sibling}throw Error(o(188))}if(a.return!==n.return)a=l,n=i;else{for(var r=!1,h=l.child;h;){if(h===a){r=!0,a=l,n=i;break}if(h===n){r=!0,n=l,a=i;break}h=h.sibling}if(!r){for(h=i.child;h;){if(h===a){r=!0,a=i,n=l;break}if(h===n){r=!0,n=i,a=l;break}h=h.sibling}if(!r)throw Error(o(189))}}if(a.alternate!==n)throw Error(o(190))}if(a.tag!==3)throw Error(o(188));return a.stateNode.current===a?t:e}function N(t){var e=t.tag;if(e===5||e===26||e===27||e===6)return t;for(t=t.child;t!==null;){if(e=N(t),e!==null)return e;t=t.sibling}return null}var g=Object.assign,R=Symbol.for("react.element"),B=Symbol.for("react.transitional.element"),M=Symbol.for("react.portal"),V=Symbol.for("react.fragment"),et=Symbol.for("react.strict_mode"),Q=Symbol.for("react.profiler"),Dt=Symbol.for("react.consumer"),ft=Symbol.for("react.context"),ht=Symbol.for("react.forward_ref"),At=Symbol.for("react.suspense"),vt=Symbol.for("react.suspense_list"),Tt=Symbol.for("react.memo"),Nt=Symbol.for("react.lazy"),Ct=Symbol.for("react.activity"),yt=Symbol.for("react.memo_cache_sentinel"),ae=Symbol.iterator;function k(t){return t===null||typeof t!="object"?null:(t=ae&&t[ae]||t["@@iterator"],typeof t=="function"?t:null)}var Z=Symbol.for("react.client.reference");function W(t){if(t==null)return null;if(typeof t=="function")return t.$$typeof===Z?null:t.displayName||t.name||null;if(typeof t=="string")return t;switch(t){case V:return"Fragment";case Q:return"Profiler";case et:return"StrictMode";case At:return"Suspense";case vt:return"SuspenseList";case Ct:return"Activity"}if(typeof t=="object")switch(t.$$typeof){case M:return"Portal";case ft:return t.displayName||"Context";case Dt:return(t._context.displayName||"Context")+".Consumer";case ht:var e=t.render;return t=t.displayName,t||(t=e.displayName||e.name||"",t=t!==""?"ForwardRef("+t+")":"ForwardRef"),t;case Tt:return e=t.displayName||null,e!==null?e:W(t.type)||"Memo";case Nt:e=t._payload,t=t._init;try{return W(t(e))}catch{}}return null}var ut=Array.isArray,E=u.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,U=s.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,q={pending:!1,data:null,method:null,action:null},at=[],tt=-1;function nt(t){return{current:t}}function st(t){0>tt||(t.current=at[tt],at[tt]=null,tt--)}function j(t,e){tt++,at[tt]=t.current,t.current=e}var $=nt(null),ot=nt(null),Ht=nt(null),Ge=nt(null);function bt(t,e){switch(j(Ht,e),j(ot,t),j($,null),e.nodeType){case 9:case 11:t=(t=e.documentElement)&&(t=t.namespaceURI)?Md(t):0;break;default:if(t=e.tagName,e=e.namespaceURI)e=Md(e),t=_d(e,t);else switch(t){case"svg":t=1;break;case"math":t=2;break;default:t=0}}st($),j($,t)}function Se(){st($),st(ot),st(Ht)}function Da(t){t.memoizedState!==null&&j(Ge,t);var e=$.current,a=_d(e,t.type);e!==a&&(j(ot,t),j($,a))}function ua(t){ot.current===t&&(st($),st(ot)),Ge.current===t&&(st(Ge),si._currentValue=q)}var Fe,yi;function Qe(t){if(Fe===void 0)try{throw Error()}catch(a){var e=a.stack.trim().match(/\n( *(at )?)/);Fe=e&&e[1]||"",yi=-1<a.stack.indexOf(`
    at`)?" (<anonymous>)":-1<a.stack.indexOf("@")?"@unknown:0:0":""}return`
`+Fe+t+yi}var pl=!1;function Dn(t,e){if(!t||pl)return"";pl=!0;var a=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var n={DetermineComponentFrameRoot:function(){try{if(e){var _=function(){throw Error()};if(Object.defineProperty(_.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(_,[])}catch(D){var z=D}Reflect.construct(t,[],_)}else{try{_.call()}catch(D){z=D}t.call(_.prototype)}}else{try{throw Error()}catch(D){z=D}(_=t())&&typeof _.catch=="function"&&_.catch(function(){})}}catch(D){if(D&&z&&typeof D.stack=="string")return[D.stack,z.stack]}return[null,null]}};n.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var l=Object.getOwnPropertyDescriptor(n.DetermineComponentFrameRoot,"name");l&&l.configurable&&Object.defineProperty(n.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var i=n.DetermineComponentFrameRoot(),r=i[0],h=i[1];if(r&&h){var y=r.split(`
`),O=h.split(`
`);for(l=n=0;n<y.length&&!y[n].includes("DetermineComponentFrameRoot");)n++;for(;l<O.length&&!O[l].includes("DetermineComponentFrameRoot");)l++;if(n===y.length||l===O.length)for(n=y.length-1,l=O.length-1;1<=n&&0<=l&&y[n]!==O[l];)l--;for(;1<=n&&0<=l;n--,l--)if(y[n]!==O[l]){if(n!==1||l!==1)do if(n--,l--,0>l||y[n]!==O[l]){var A=`
`+y[n].replace(" at new "," at ");return t.displayName&&A.includes("<anonymous>")&&(A=A.replace("<anonymous>",t.displayName)),A}while(1<=n&&0<=l);break}}}finally{pl=!1,Error.prepareStackTrace=a}return(a=t?t.displayName||t.name:"")?Qe(a):""}function tn(t,e){switch(t.tag){case 26:case 27:case 5:return Qe(t.type);case 16:return Qe("Lazy");case 13:return t.child!==e&&e!==null?Qe("Suspense Fallback"):Qe("Suspense");case 19:return Qe("SuspenseList");case 0:case 15:return Dn(t.type,!1);case 11:return Dn(t.type.render,!1);case 1:return Dn(t.type,!0);case 31:return Qe("Activity");default:return""}}function yl(t){try{var e="",a=null;do e+=tn(t,a),a=t,t=t.return;while(t);return e}catch(n){return`
Error generating stack: `+n.message+`
`+n.stack}}var xe=Object.prototype.hasOwnProperty,vl=c.unstable_scheduleCallback,bl=c.unstable_cancelCallback,ne=c.unstable_shouldYield,Aa=c.unstable_requestPaint,le=c.unstable_now,Qu=c.unstable_getCurrentPriorityLevel,en=c.unstable_ImmediatePriority,vi=c.unstable_UserBlockingPriority,an=c.unstable_NormalPriority,Sl=c.unstable_LowPriority,sa=c.unstable_IdlePriority,bi=c.log,Na=c.unstable_setDisableYieldValue,nn=null,ie=null;function Xe(t){if(typeof bi=="function"&&Na(t),ie&&typeof ie.setStrictMode=="function")try{ie.setStrictMode(nn,t)}catch{}}var te=Math.clz32?Math.clz32:$e,Xu=Math.log,xl=Math.LN2;function $e(t){return t>>>=0,t===0?32:31-(Xu(t)/xl|0)|0}var An=256,Nn=262144,ln=4194304;function We(t){var e=t&42;if(e!==0)return e;switch(t&-t){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return t&261888;case 262144:case 524288:case 1048576:case 2097152:return t&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return t&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return t}}function J(t,e,a){var n=t.pendingLanes;if(n===0)return 0;var l=0,i=t.suspendedLanes,r=t.pingedLanes;t=t.warmLanes;var h=n&134217727;return h!==0?(n=h&~i,n!==0?l=We(n):(r&=h,r!==0?l=We(r):a||(a=h&~t,a!==0&&(l=We(a))))):(h=n&~i,h!==0?l=We(h):r!==0?l=We(r):a||(a=n&~t,a!==0&&(l=We(a)))),l===0?0:e!==0&&e!==l&&(e&i)===0&&(i=l&-l,a=e&-e,i>=a||i===32&&(a&4194048)!==0)?e:l}function Ut(t,e){return(t.pendingLanes&~(t.suspendedLanes&~t.pingedLanes)&e)===0}function Zt(t,e){switch(t){case 1:case 2:case 4:case 8:case 64:return e+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return e+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function ee(){var t=ln;return ln<<=1,(ln&62914560)===0&&(ln=4194304),t}function Ca(t){for(var e=[],a=0;31>a;a++)e.push(t);return e}function Bt(t,e){t.pendingLanes|=e,e!==268435456&&(t.suspendedLanes=0,t.pingedLanes=0,t.warmLanes=0)}function ce(t,e,a,n,l,i){var r=t.pendingLanes;t.pendingLanes=a,t.suspendedLanes=0,t.pingedLanes=0,t.warmLanes=0,t.expiredLanes&=a,t.entangledLanes&=a,t.errorRecoveryDisabledLanes&=a,t.shellSuspendCounter=0;var h=t.entanglements,y=t.expirationTimes,O=t.hiddenUpdates;for(a=r&~a;0<a;){var A=31-te(a),_=1<<A;h[A]=0,y[A]=-1;var z=O[A];if(z!==null)for(O[A]=null,A=0;A<z.length;A++){var D=z[A];D!==null&&(D.lane&=-536870913)}a&=~_}n!==0&&un(t,n,0),i!==0&&l===0&&t.tag!==0&&(t.suspendedLanes|=i&~(r&~e))}function un(t,e,a){t.pendingLanes|=e,t.suspendedLanes&=~e;var n=31-te(e);t.entangledLanes|=e,t.entanglements[n]=t.entanglements[n]|1073741824|a&261930}function re(t,e){var a=t.entangledLanes|=e;for(t=t.entanglements;a;){var n=31-te(a),l=1<<n;l&e|t[n]&e&&(t[n]|=e),a&=~l}}function fe(t,e){var a=e&-e;return a=(a&42)!==0?1:Cn(a),(a&(t.suspendedLanes|e))!==0?0:a}function Cn(t){switch(t){case 2:t=1;break;case 8:t=4;break;case 32:t=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:t=128;break;case 268435456:t=134217728;break;default:t=0}return t}function Ke(t){return t&=-t,2<t?8<t?(t&134217727)!==0?32:268435456:8:2}function Ku(){var t=U.p;return t!==0?t:(t=window.event,t===void 0?32:th(t.type))}function mc(t,e){var a=U.p;try{return U.p=t,e()}finally{U.p=a}}var Ma=Math.random().toString(36).slice(2),Ft="__reactFiber$"+Ma,de="__reactProps$"+Ma,Mn="__reactContainer$"+Ma,Zu="__reactEvents$"+Ma,lg="__reactListeners$"+Ma,ig="__reactHandles$"+Ma,pc="__reactResources$"+Ma,Tl="__reactMarker$"+Ma;function ku(t){delete t[Ft],delete t[de],delete t[Zu],delete t[lg],delete t[ig]}function _n(t){var e=t[Ft];if(e)return e;for(var a=t.parentNode;a;){if(e=a[Mn]||a[Ft]){if(a=e.alternate,e.child!==null||a!==null&&a.child!==null)for(t=Hd(t);t!==null;){if(a=t[Ft])return a;t=Hd(t)}return e}t=a,a=t.parentNode}return null}function Rn(t){if(t=t[Ft]||t[Mn]){var e=t.tag;if(e===5||e===6||e===13||e===31||e===26||e===27||e===3)return t}return null}function El(t){var e=t.tag;if(e===5||e===26||e===27||e===6)return t.stateNode;throw Error(o(33))}function Un(t){var e=t[pc];return e||(e=t[pc]={hoistableStyles:new Map,hoistableScripts:new Map}),e}function kt(t){t[Tl]=!0}var yc=new Set,vc={};function sn(t,e){wn(t,e),wn(t+"Capture",e)}function wn(t,e){for(vc[t]=e,t=0;t<e.length;t++)yc.add(e[t])}var ug=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),bc={},Sc={};function sg(t){return xe.call(Sc,t)?!0:xe.call(bc,t)?!1:ug.test(t)?Sc[t]=!0:(bc[t]=!0,!1)}function Si(t,e,a){if(sg(e))if(a===null)t.removeAttribute(e);else{switch(typeof a){case"undefined":case"function":case"symbol":t.removeAttribute(e);return;case"boolean":var n=e.toLowerCase().slice(0,5);if(n!=="data-"&&n!=="aria-"){t.removeAttribute(e);return}}t.setAttribute(e,""+a)}}function xi(t,e,a){if(a===null)t.removeAttribute(e);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":t.removeAttribute(e);return}t.setAttribute(e,""+a)}}function oa(t,e,a,n){if(n===null)t.removeAttribute(a);else{switch(typeof n){case"undefined":case"function":case"symbol":case"boolean":t.removeAttribute(a);return}t.setAttributeNS(e,a,""+n)}}function _e(t){switch(typeof t){case"bigint":case"boolean":case"number":case"string":case"undefined":return t;case"object":return t;default:return""}}function xc(t){var e=t.type;return(t=t.nodeName)&&t.toLowerCase()==="input"&&(e==="checkbox"||e==="radio")}function og(t,e,a){var n=Object.getOwnPropertyDescriptor(t.constructor.prototype,e);if(!t.hasOwnProperty(e)&&typeof n<"u"&&typeof n.get=="function"&&typeof n.set=="function"){var l=n.get,i=n.set;return Object.defineProperty(t,e,{configurable:!0,get:function(){return l.call(this)},set:function(r){a=""+r,i.call(this,r)}}),Object.defineProperty(t,e,{enumerable:n.enumerable}),{getValue:function(){return a},setValue:function(r){a=""+r},stopTracking:function(){t._valueTracker=null,delete t[e]}}}}function Ju(t){if(!t._valueTracker){var e=xc(t)?"checked":"value";t._valueTracker=og(t,e,""+t[e])}}function Tc(t){if(!t)return!1;var e=t._valueTracker;if(!e)return!0;var a=e.getValue(),n="";return t&&(n=xc(t)?t.checked?"true":"false":t.value),t=n,t!==a?(e.setValue(t),!0):!1}function Ti(t){if(t=t||(typeof document<"u"?document:void 0),typeof t>"u")return null;try{return t.activeElement||t.body}catch{return t.body}}var cg=/[\n"\\]/g;function Re(t){return t.replace(cg,function(e){return"\\"+e.charCodeAt(0).toString(16)+" "})}function Fu(t,e,a,n,l,i,r,h){t.name="",r!=null&&typeof r!="function"&&typeof r!="symbol"&&typeof r!="boolean"?t.type=r:t.removeAttribute("type"),e!=null?r==="number"?(e===0&&t.value===""||t.value!=e)&&(t.value=""+_e(e)):t.value!==""+_e(e)&&(t.value=""+_e(e)):r!=="submit"&&r!=="reset"||t.removeAttribute("value"),e!=null?$u(t,r,_e(e)):a!=null?$u(t,r,_e(a)):n!=null&&t.removeAttribute("value"),l==null&&i!=null&&(t.defaultChecked=!!i),l!=null&&(t.checked=l&&typeof l!="function"&&typeof l!="symbol"),h!=null&&typeof h!="function"&&typeof h!="symbol"&&typeof h!="boolean"?t.name=""+_e(h):t.removeAttribute("name")}function Ec(t,e,a,n,l,i,r,h){if(i!=null&&typeof i!="function"&&typeof i!="symbol"&&typeof i!="boolean"&&(t.type=i),e!=null||a!=null){if(!(i!=="submit"&&i!=="reset"||e!=null)){Ju(t);return}a=a!=null?""+_e(a):"",e=e!=null?""+_e(e):a,h||e===t.value||(t.value=e),t.defaultValue=e}n=n??l,n=typeof n!="function"&&typeof n!="symbol"&&!!n,t.checked=h?t.checked:!!n,t.defaultChecked=!!n,r!=null&&typeof r!="function"&&typeof r!="symbol"&&typeof r!="boolean"&&(t.name=r),Ju(t)}function $u(t,e,a){e==="number"&&Ti(t.ownerDocument)===t||t.defaultValue===""+a||(t.defaultValue=""+a)}function Bn(t,e,a,n){if(t=t.options,e){e={};for(var l=0;l<a.length;l++)e["$"+a[l]]=!0;for(a=0;a<t.length;a++)l=e.hasOwnProperty("$"+t[a].value),t[a].selected!==l&&(t[a].selected=l),l&&n&&(t[a].defaultSelected=!0)}else{for(a=""+_e(a),e=null,l=0;l<t.length;l++){if(t[l].value===a){t[l].selected=!0,n&&(t[l].defaultSelected=!0);return}e!==null||t[l].disabled||(e=t[l])}e!==null&&(e.selected=!0)}}function Oc(t,e,a){if(e!=null&&(e=""+_e(e),e!==t.value&&(t.value=e),a==null)){t.defaultValue!==e&&(t.defaultValue=e);return}t.defaultValue=a!=null?""+_e(a):""}function zc(t,e,a,n){if(e==null){if(n!=null){if(a!=null)throw Error(o(92));if(ut(n)){if(1<n.length)throw Error(o(93));n=n[0]}a=n}a==null&&(a=""),e=a}a=_e(e),t.defaultValue=a,n=t.textContent,n===a&&n!==""&&n!==null&&(t.value=n),Ju(t)}function Ln(t,e){if(e){var a=t.firstChild;if(a&&a===t.lastChild&&a.nodeType===3){a.nodeValue=e;return}}t.textContent=e}var rg=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function Dc(t,e,a){var n=e.indexOf("--")===0;a==null||typeof a=="boolean"||a===""?n?t.setProperty(e,""):e==="float"?t.cssFloat="":t[e]="":n?t.setProperty(e,a):typeof a!="number"||a===0||rg.has(e)?e==="float"?t.cssFloat=a:t[e]=(""+a).trim():t[e]=a+"px"}function Ac(t,e,a){if(e!=null&&typeof e!="object")throw Error(o(62));if(t=t.style,a!=null){for(var n in a)!a.hasOwnProperty(n)||e!=null&&e.hasOwnProperty(n)||(n.indexOf("--")===0?t.setProperty(n,""):n==="float"?t.cssFloat="":t[n]="");for(var l in e)n=e[l],e.hasOwnProperty(l)&&a[l]!==n&&Dc(t,l,n)}else for(var i in e)e.hasOwnProperty(i)&&Dc(t,i,e[i])}function Wu(t){if(t.indexOf("-")===-1)return!1;switch(t){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var fg=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),dg=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Ei(t){return dg.test(""+t)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":t}function ca(){}var Iu=null;function Pu(t){return t=t.target||t.srcElement||window,t.correspondingUseElement&&(t=t.correspondingUseElement),t.nodeType===3?t.parentNode:t}var jn=null,Hn=null;function Nc(t){var e=Rn(t);if(e&&(t=e.stateNode)){var a=t[de]||null;t:switch(t=e.stateNode,e.type){case"input":if(Fu(t,a.value,a.defaultValue,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name),e=a.name,a.type==="radio"&&e!=null){for(a=t;a.parentNode;)a=a.parentNode;for(a=a.querySelectorAll('input[name="'+Re(""+e)+'"][type="radio"]'),e=0;e<a.length;e++){var n=a[e];if(n!==t&&n.form===t.form){var l=n[de]||null;if(!l)throw Error(o(90));Fu(n,l.value,l.defaultValue,l.defaultValue,l.checked,l.defaultChecked,l.type,l.name)}}for(e=0;e<a.length;e++)n=a[e],n.form===t.form&&Tc(n)}break t;case"textarea":Oc(t,a.value,a.defaultValue);break t;case"select":e=a.value,e!=null&&Bn(t,!!a.multiple,e,!1)}}}var ts=!1;function Cc(t,e,a){if(ts)return t(e,a);ts=!0;try{var n=t(e);return n}finally{if(ts=!1,(jn!==null||Hn!==null)&&(ru(),jn&&(e=jn,t=Hn,Hn=jn=null,Nc(e),t)))for(e=0;e<t.length;e++)Nc(t[e])}}function Ol(t,e){var a=t.stateNode;if(a===null)return null;var n=a[de]||null;if(n===null)return null;a=n[e];t:switch(e){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(n=!n.disabled)||(t=t.type,n=!(t==="button"||t==="input"||t==="select"||t==="textarea")),t=!n;break t;default:t=!1}if(t)return null;if(a&&typeof a!="function")throw Error(o(231,e,typeof a));return a}var ra=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),es=!1;if(ra)try{var zl={};Object.defineProperty(zl,"passive",{get:function(){es=!0}}),window.addEventListener("test",zl,zl),window.removeEventListener("test",zl,zl)}catch{es=!1}var _a=null,as=null,Oi=null;function Mc(){if(Oi)return Oi;var t,e=as,a=e.length,n,l="value"in _a?_a.value:_a.textContent,i=l.length;for(t=0;t<a&&e[t]===l[t];t++);var r=a-t;for(n=1;n<=r&&e[a-n]===l[i-n];n++);return Oi=l.slice(t,1<n?1-n:void 0)}function zi(t){var e=t.keyCode;return"charCode"in t?(t=t.charCode,t===0&&e===13&&(t=13)):t=e,t===10&&(t=13),32<=t||t===13?t:0}function Di(){return!0}function _c(){return!1}function he(t){function e(a,n,l,i,r){this._reactName=a,this._targetInst=l,this.type=n,this.nativeEvent=i,this.target=r,this.currentTarget=null;for(var h in t)t.hasOwnProperty(h)&&(a=t[h],this[h]=a?a(i):i[h]);return this.isDefaultPrevented=(i.defaultPrevented!=null?i.defaultPrevented:i.returnValue===!1)?Di:_c,this.isPropagationStopped=_c,this}return g(e.prototype,{preventDefault:function(){this.defaultPrevented=!0;var a=this.nativeEvent;a&&(a.preventDefault?a.preventDefault():typeof a.returnValue!="unknown"&&(a.returnValue=!1),this.isDefaultPrevented=Di)},stopPropagation:function(){var a=this.nativeEvent;a&&(a.stopPropagation?a.stopPropagation():typeof a.cancelBubble!="unknown"&&(a.cancelBubble=!0),this.isPropagationStopped=Di)},persist:function(){},isPersistent:Di}),e}var on={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(t){return t.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Ai=he(on),Dl=g({},on,{view:0,detail:0}),hg=he(Dl),ns,ls,Al,Ni=g({},Dl,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:us,button:0,buttons:0,relatedTarget:function(t){return t.relatedTarget===void 0?t.fromElement===t.srcElement?t.toElement:t.fromElement:t.relatedTarget},movementX:function(t){return"movementX"in t?t.movementX:(t!==Al&&(Al&&t.type==="mousemove"?(ns=t.screenX-Al.screenX,ls=t.screenY-Al.screenY):ls=ns=0,Al=t),ns)},movementY:function(t){return"movementY"in t?t.movementY:ls}}),Rc=he(Ni),gg=g({},Ni,{dataTransfer:0}),mg=he(gg),pg=g({},Dl,{relatedTarget:0}),is=he(pg),yg=g({},on,{animationName:0,elapsedTime:0,pseudoElement:0}),vg=he(yg),bg=g({},on,{clipboardData:function(t){return"clipboardData"in t?t.clipboardData:window.clipboardData}}),Sg=he(bg),xg=g({},on,{data:0}),Uc=he(xg),Tg={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},Eg={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},Og={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function zg(t){var e=this.nativeEvent;return e.getModifierState?e.getModifierState(t):(t=Og[t])?!!e[t]:!1}function us(){return zg}var Dg=g({},Dl,{key:function(t){if(t.key){var e=Tg[t.key]||t.key;if(e!=="Unidentified")return e}return t.type==="keypress"?(t=zi(t),t===13?"Enter":String.fromCharCode(t)):t.type==="keydown"||t.type==="keyup"?Eg[t.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:us,charCode:function(t){return t.type==="keypress"?zi(t):0},keyCode:function(t){return t.type==="keydown"||t.type==="keyup"?t.keyCode:0},which:function(t){return t.type==="keypress"?zi(t):t.type==="keydown"||t.type==="keyup"?t.keyCode:0}}),Ag=he(Dg),Ng=g({},Ni,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),wc=he(Ng),Cg=g({},Dl,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:us}),Mg=he(Cg),_g=g({},on,{propertyName:0,elapsedTime:0,pseudoElement:0}),Rg=he(_g),Ug=g({},Ni,{deltaX:function(t){return"deltaX"in t?t.deltaX:"wheelDeltaX"in t?-t.wheelDeltaX:0},deltaY:function(t){return"deltaY"in t?t.deltaY:"wheelDeltaY"in t?-t.wheelDeltaY:"wheelDelta"in t?-t.wheelDelta:0},deltaZ:0,deltaMode:0}),wg=he(Ug),Bg=g({},on,{newState:0,oldState:0}),Lg=he(Bg),jg=[9,13,27,32],ss=ra&&"CompositionEvent"in window,Nl=null;ra&&"documentMode"in document&&(Nl=document.documentMode);var Hg=ra&&"TextEvent"in window&&!Nl,Bc=ra&&(!ss||Nl&&8<Nl&&11>=Nl),Lc=" ",jc=!1;function Hc(t,e){switch(t){case"keyup":return jg.indexOf(e.keyCode)!==-1;case"keydown":return e.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function qc(t){return t=t.detail,typeof t=="object"&&"data"in t?t.data:null}var qn=!1;function qg(t,e){switch(t){case"compositionend":return qc(e);case"keypress":return e.which!==32?null:(jc=!0,Lc);case"textInput":return t=e.data,t===Lc&&jc?null:t;default:return null}}function Yg(t,e){if(qn)return t==="compositionend"||!ss&&Hc(t,e)?(t=Mc(),Oi=as=_a=null,qn=!1,t):null;switch(t){case"paste":return null;case"keypress":if(!(e.ctrlKey||e.altKey||e.metaKey)||e.ctrlKey&&e.altKey){if(e.char&&1<e.char.length)return e.char;if(e.which)return String.fromCharCode(e.which)}return null;case"compositionend":return Bc&&e.locale!=="ko"?null:e.data;default:return null}}var Vg={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Yc(t){var e=t&&t.nodeName&&t.nodeName.toLowerCase();return e==="input"?!!Vg[t.type]:e==="textarea"}function Vc(t,e,a,n){jn?Hn?Hn.push(n):Hn=[n]:jn=n,e=yu(e,"onChange"),0<e.length&&(a=new Ai("onChange","change",null,a,n),t.push({event:a,listeners:e}))}var Cl=null,Ml=null;function Gg(t){Od(t,0)}function Ci(t){var e=El(t);if(Tc(e))return t}function Gc(t,e){if(t==="change")return e}var Qc=!1;if(ra){var os;if(ra){var cs="oninput"in document;if(!cs){var Xc=document.createElement("div");Xc.setAttribute("oninput","return;"),cs=typeof Xc.oninput=="function"}os=cs}else os=!1;Qc=os&&(!document.documentMode||9<document.documentMode)}function Kc(){Cl&&(Cl.detachEvent("onpropertychange",Zc),Ml=Cl=null)}function Zc(t){if(t.propertyName==="value"&&Ci(Ml)){var e=[];Vc(e,Ml,t,Pu(t)),Cc(Gg,e)}}function Qg(t,e,a){t==="focusin"?(Kc(),Cl=e,Ml=a,Cl.attachEvent("onpropertychange",Zc)):t==="focusout"&&Kc()}function Xg(t){if(t==="selectionchange"||t==="keyup"||t==="keydown")return Ci(Ml)}function Kg(t,e){if(t==="click")return Ci(e)}function Zg(t,e){if(t==="input"||t==="change")return Ci(e)}function kg(t,e){return t===e&&(t!==0||1/t===1/e)||t!==t&&e!==e}var Te=typeof Object.is=="function"?Object.is:kg;function _l(t,e){if(Te(t,e))return!0;if(typeof t!="object"||t===null||typeof e!="object"||e===null)return!1;var a=Object.keys(t),n=Object.keys(e);if(a.length!==n.length)return!1;for(n=0;n<a.length;n++){var l=a[n];if(!xe.call(e,l)||!Te(t[l],e[l]))return!1}return!0}function kc(t){for(;t&&t.firstChild;)t=t.firstChild;return t}function Jc(t,e){var a=kc(t);t=0;for(var n;a;){if(a.nodeType===3){if(n=t+a.textContent.length,t<=e&&n>=e)return{node:a,offset:e-t};t=n}t:{for(;a;){if(a.nextSibling){a=a.nextSibling;break t}a=a.parentNode}a=void 0}a=kc(a)}}function Fc(t,e){return t&&e?t===e?!0:t&&t.nodeType===3?!1:e&&e.nodeType===3?Fc(t,e.parentNode):"contains"in t?t.contains(e):t.compareDocumentPosition?!!(t.compareDocumentPosition(e)&16):!1:!1}function $c(t){t=t!=null&&t.ownerDocument!=null&&t.ownerDocument.defaultView!=null?t.ownerDocument.defaultView:window;for(var e=Ti(t.document);e instanceof t.HTMLIFrameElement;){try{var a=typeof e.contentWindow.location.href=="string"}catch{a=!1}if(a)t=e.contentWindow;else break;e=Ti(t.document)}return e}function rs(t){var e=t&&t.nodeName&&t.nodeName.toLowerCase();return e&&(e==="input"&&(t.type==="text"||t.type==="search"||t.type==="tel"||t.type==="url"||t.type==="password")||e==="textarea"||t.contentEditable==="true")}var Jg=ra&&"documentMode"in document&&11>=document.documentMode,Yn=null,fs=null,Rl=null,ds=!1;function Wc(t,e,a){var n=a.window===a?a.document:a.nodeType===9?a:a.ownerDocument;ds||Yn==null||Yn!==Ti(n)||(n=Yn,"selectionStart"in n&&rs(n)?n={start:n.selectionStart,end:n.selectionEnd}:(n=(n.ownerDocument&&n.ownerDocument.defaultView||window).getSelection(),n={anchorNode:n.anchorNode,anchorOffset:n.anchorOffset,focusNode:n.focusNode,focusOffset:n.focusOffset}),Rl&&_l(Rl,n)||(Rl=n,n=yu(fs,"onSelect"),0<n.length&&(e=new Ai("onSelect","select",null,e,a),t.push({event:e,listeners:n}),e.target=Yn)))}function cn(t,e){var a={};return a[t.toLowerCase()]=e.toLowerCase(),a["Webkit"+t]="webkit"+e,a["Moz"+t]="moz"+e,a}var Vn={animationend:cn("Animation","AnimationEnd"),animationiteration:cn("Animation","AnimationIteration"),animationstart:cn("Animation","AnimationStart"),transitionrun:cn("Transition","TransitionRun"),transitionstart:cn("Transition","TransitionStart"),transitioncancel:cn("Transition","TransitionCancel"),transitionend:cn("Transition","TransitionEnd")},hs={},Ic={};ra&&(Ic=document.createElement("div").style,"AnimationEvent"in window||(delete Vn.animationend.animation,delete Vn.animationiteration.animation,delete Vn.animationstart.animation),"TransitionEvent"in window||delete Vn.transitionend.transition);function rn(t){if(hs[t])return hs[t];if(!Vn[t])return t;var e=Vn[t],a;for(a in e)if(e.hasOwnProperty(a)&&a in Ic)return hs[t]=e[a];return t}var Pc=rn("animationend"),tr=rn("animationiteration"),er=rn("animationstart"),Fg=rn("transitionrun"),$g=rn("transitionstart"),Wg=rn("transitioncancel"),ar=rn("transitionend"),nr=new Map,gs="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");gs.push("scrollEnd");function Ze(t,e){nr.set(t,e),sn(e,[t])}var Mi=typeof reportError=="function"?reportError:function(t){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var e=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof t=="object"&&t!==null&&typeof t.message=="string"?String(t.message):String(t),error:t});if(!window.dispatchEvent(e))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",t);return}console.error(t)},Ue=[],Gn=0,ms=0;function _i(){for(var t=Gn,e=ms=Gn=0;e<t;){var a=Ue[e];Ue[e++]=null;var n=Ue[e];Ue[e++]=null;var l=Ue[e];Ue[e++]=null;var i=Ue[e];if(Ue[e++]=null,n!==null&&l!==null){var r=n.pending;r===null?l.next=l:(l.next=r.next,r.next=l),n.pending=l}i!==0&&lr(a,l,i)}}function Ri(t,e,a,n){Ue[Gn++]=t,Ue[Gn++]=e,Ue[Gn++]=a,Ue[Gn++]=n,ms|=n,t.lanes|=n,t=t.alternate,t!==null&&(t.lanes|=n)}function ps(t,e,a,n){return Ri(t,e,a,n),Ui(t)}function fn(t,e){return Ri(t,null,null,e),Ui(t)}function lr(t,e,a){t.lanes|=a;var n=t.alternate;n!==null&&(n.lanes|=a);for(var l=!1,i=t.return;i!==null;)i.childLanes|=a,n=i.alternate,n!==null&&(n.childLanes|=a),i.tag===22&&(t=i.stateNode,t===null||t._visibility&1||(l=!0)),t=i,i=i.return;return t.tag===3?(i=t.stateNode,l&&e!==null&&(l=31-te(a),t=i.hiddenUpdates,n=t[l],n===null?t[l]=[e]:n.push(e),e.lane=a|536870912),i):null}function Ui(t){if(50<ti)throw ti=0,Do=null,Error(o(185));for(var e=t.return;e!==null;)t=e,e=t.return;return t.tag===3?t.stateNode:null}var Qn={};function Ig(t,e,a,n){this.tag=t,this.key=a,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=e,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=n,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function Ee(t,e,a,n){return new Ig(t,e,a,n)}function ys(t){return t=t.prototype,!(!t||!t.isReactComponent)}function fa(t,e){var a=t.alternate;return a===null?(a=Ee(t.tag,e,t.key,t.mode),a.elementType=t.elementType,a.type=t.type,a.stateNode=t.stateNode,a.alternate=t,t.alternate=a):(a.pendingProps=e,a.type=t.type,a.flags=0,a.subtreeFlags=0,a.deletions=null),a.flags=t.flags&65011712,a.childLanes=t.childLanes,a.lanes=t.lanes,a.child=t.child,a.memoizedProps=t.memoizedProps,a.memoizedState=t.memoizedState,a.updateQueue=t.updateQueue,e=t.dependencies,a.dependencies=e===null?null:{lanes:e.lanes,firstContext:e.firstContext},a.sibling=t.sibling,a.index=t.index,a.ref=t.ref,a.refCleanup=t.refCleanup,a}function ir(t,e){t.flags&=65011714;var a=t.alternate;return a===null?(t.childLanes=0,t.lanes=e,t.child=null,t.subtreeFlags=0,t.memoizedProps=null,t.memoizedState=null,t.updateQueue=null,t.dependencies=null,t.stateNode=null):(t.childLanes=a.childLanes,t.lanes=a.lanes,t.child=a.child,t.subtreeFlags=0,t.deletions=null,t.memoizedProps=a.memoizedProps,t.memoizedState=a.memoizedState,t.updateQueue=a.updateQueue,t.type=a.type,e=a.dependencies,t.dependencies=e===null?null:{lanes:e.lanes,firstContext:e.firstContext}),t}function wi(t,e,a,n,l,i){var r=0;if(n=t,typeof t=="function")ys(t)&&(r=1);else if(typeof t=="string")r=np(t,a,$.current)?26:t==="html"||t==="head"||t==="body"?27:5;else t:switch(t){case Ct:return t=Ee(31,a,e,l),t.elementType=Ct,t.lanes=i,t;case V:return dn(a.children,l,i,e);case et:r=8,l|=24;break;case Q:return t=Ee(12,a,e,l|2),t.elementType=Q,t.lanes=i,t;case At:return t=Ee(13,a,e,l),t.elementType=At,t.lanes=i,t;case vt:return t=Ee(19,a,e,l),t.elementType=vt,t.lanes=i,t;default:if(typeof t=="object"&&t!==null)switch(t.$$typeof){case ft:r=10;break t;case Dt:r=9;break t;case ht:r=11;break t;case Tt:r=14;break t;case Nt:r=16,n=null;break t}r=29,a=Error(o(130,t===null?"null":typeof t,"")),n=null}return e=Ee(r,a,e,l),e.elementType=t,e.type=n,e.lanes=i,e}function dn(t,e,a,n){return t=Ee(7,t,n,e),t.lanes=a,t}function vs(t,e,a){return t=Ee(6,t,null,e),t.lanes=a,t}function ur(t){var e=Ee(18,null,null,0);return e.stateNode=t,e}function bs(t,e,a){return e=Ee(4,t.children!==null?t.children:[],t.key,e),e.lanes=a,e.stateNode={containerInfo:t.containerInfo,pendingChildren:null,implementation:t.implementation},e}var sr=new WeakMap;function we(t,e){if(typeof t=="object"&&t!==null){var a=sr.get(t);return a!==void 0?a:(e={value:t,source:e,stack:yl(e)},sr.set(t,e),e)}return{value:t,source:e,stack:yl(e)}}var Xn=[],Kn=0,Bi=null,Ul=0,Be=[],Le=0,Ra=null,Ie=1,Pe="";function da(t,e){Xn[Kn++]=Ul,Xn[Kn++]=Bi,Bi=t,Ul=e}function or(t,e,a){Be[Le++]=Ie,Be[Le++]=Pe,Be[Le++]=Ra,Ra=t;var n=Ie;t=Pe;var l=32-te(n)-1;n&=~(1<<l),a+=1;var i=32-te(e)+l;if(30<i){var r=l-l%5;i=(n&(1<<r)-1).toString(32),n>>=r,l-=r,Ie=1<<32-te(e)+l|a<<l|n,Pe=i+t}else Ie=1<<i|a<<l|n,Pe=t}function Ss(t){t.return!==null&&(da(t,1),or(t,1,0))}function xs(t){for(;t===Bi;)Bi=Xn[--Kn],Xn[Kn]=null,Ul=Xn[--Kn],Xn[Kn]=null;for(;t===Ra;)Ra=Be[--Le],Be[Le]=null,Pe=Be[--Le],Be[Le]=null,Ie=Be[--Le],Be[Le]=null}function cr(t,e){Be[Le++]=Ie,Be[Le++]=Pe,Be[Le++]=Ra,Ie=e.id,Pe=e.overflow,Ra=t}var $t=null,_t=null,dt=!1,Ua=null,je=!1,Ts=Error(o(519));function wa(t){var e=Error(o(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw wl(we(e,t)),Ts}function rr(t){var e=t.stateNode,a=t.type,n=t.memoizedProps;switch(e[Ft]=t,e[de]=n,a){case"dialog":it("cancel",e),it("close",e);break;case"iframe":case"object":case"embed":it("load",e);break;case"video":case"audio":for(a=0;a<ai.length;a++)it(ai[a],e);break;case"source":it("error",e);break;case"img":case"image":case"link":it("error",e),it("load",e);break;case"details":it("toggle",e);break;case"input":it("invalid",e),Ec(e,n.value,n.defaultValue,n.checked,n.defaultChecked,n.type,n.name,!0);break;case"select":it("invalid",e);break;case"textarea":it("invalid",e),zc(e,n.value,n.defaultValue,n.children)}a=n.children,typeof a!="string"&&typeof a!="number"&&typeof a!="bigint"||e.textContent===""+a||n.suppressHydrationWarning===!0||Nd(e.textContent,a)?(n.popover!=null&&(it("beforetoggle",e),it("toggle",e)),n.onScroll!=null&&it("scroll",e),n.onScrollEnd!=null&&it("scrollend",e),n.onClick!=null&&(e.onclick=ca),e=!0):e=!1,e||wa(t,!0)}function fr(t){for($t=t.return;$t;)switch($t.tag){case 5:case 31:case 13:je=!1;return;case 27:case 3:je=!0;return;default:$t=$t.return}}function Zn(t){if(t!==$t)return!1;if(!dt)return fr(t),dt=!0,!1;var e=t.tag,a;if((a=e!==3&&e!==27)&&((a=e===5)&&(a=t.type,a=!(a!=="form"&&a!=="button")||Vo(t.type,t.memoizedProps)),a=!a),a&&_t&&wa(t),fr(t),e===13){if(t=t.memoizedState,t=t!==null?t.dehydrated:null,!t)throw Error(o(317));_t=jd(t)}else if(e===31){if(t=t.memoizedState,t=t!==null?t.dehydrated:null,!t)throw Error(o(317));_t=jd(t)}else e===27?(e=_t,Ja(t.type)?(t=Zo,Zo=null,_t=t):_t=e):_t=$t?qe(t.stateNode.nextSibling):null;return!0}function hn(){_t=$t=null,dt=!1}function Es(){var t=Ua;return t!==null&&(ye===null?ye=t:ye.push.apply(ye,t),Ua=null),t}function wl(t){Ua===null?Ua=[t]:Ua.push(t)}var Os=nt(null),gn=null,ha=null;function Ba(t,e,a){j(Os,e._currentValue),e._currentValue=a}function ga(t){t._currentValue=Os.current,st(Os)}function zs(t,e,a){for(;t!==null;){var n=t.alternate;if((t.childLanes&e)!==e?(t.childLanes|=e,n!==null&&(n.childLanes|=e)):n!==null&&(n.childLanes&e)!==e&&(n.childLanes|=e),t===a)break;t=t.return}}function Ds(t,e,a,n){var l=t.child;for(l!==null&&(l.return=t);l!==null;){var i=l.dependencies;if(i!==null){var r=l.child;i=i.firstContext;t:for(;i!==null;){var h=i;i=l;for(var y=0;y<e.length;y++)if(h.context===e[y]){i.lanes|=a,h=i.alternate,h!==null&&(h.lanes|=a),zs(i.return,a,t),n||(r=null);break t}i=h.next}}else if(l.tag===18){if(r=l.return,r===null)throw Error(o(341));r.lanes|=a,i=r.alternate,i!==null&&(i.lanes|=a),zs(r,a,t),r=null}else r=l.child;if(r!==null)r.return=l;else for(r=l;r!==null;){if(r===t){r=null;break}if(l=r.sibling,l!==null){l.return=r.return,r=l;break}r=r.return}l=r}}function kn(t,e,a,n){t=null;for(var l=e,i=!1;l!==null;){if(!i){if((l.flags&524288)!==0)i=!0;else if((l.flags&262144)!==0)break}if(l.tag===10){var r=l.alternate;if(r===null)throw Error(o(387));if(r=r.memoizedProps,r!==null){var h=l.type;Te(l.pendingProps.value,r.value)||(t!==null?t.push(h):t=[h])}}else if(l===Ge.current){if(r=l.alternate,r===null)throw Error(o(387));r.memoizedState.memoizedState!==l.memoizedState.memoizedState&&(t!==null?t.push(si):t=[si])}l=l.return}t!==null&&Ds(e,t,a,n),e.flags|=262144}function Li(t){for(t=t.firstContext;t!==null;){if(!Te(t.context._currentValue,t.memoizedValue))return!0;t=t.next}return!1}function mn(t){gn=t,ha=null,t=t.dependencies,t!==null&&(t.firstContext=null)}function Wt(t){return dr(gn,t)}function ji(t,e){return gn===null&&mn(t),dr(t,e)}function dr(t,e){var a=e._currentValue;if(e={context:e,memoizedValue:a,next:null},ha===null){if(t===null)throw Error(o(308));ha=e,t.dependencies={lanes:0,firstContext:e},t.flags|=524288}else ha=ha.next=e;return a}var Pg=typeof AbortController<"u"?AbortController:function(){var t=[],e=this.signal={aborted:!1,addEventListener:function(a,n){t.push(n)}};this.abort=function(){e.aborted=!0,t.forEach(function(a){return a()})}},tm=c.unstable_scheduleCallback,em=c.unstable_NormalPriority,Vt={$$typeof:ft,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function As(){return{controller:new Pg,data:new Map,refCount:0}}function Bl(t){t.refCount--,t.refCount===0&&tm(em,function(){t.controller.abort()})}var Ll=null,Ns=0,Jn=0,Fn=null;function am(t,e){if(Ll===null){var a=Ll=[];Ns=0,Jn=Ro(),Fn={status:"pending",value:void 0,then:function(n){a.push(n)}}}return Ns++,e.then(hr,hr),e}function hr(){if(--Ns===0&&Ll!==null){Fn!==null&&(Fn.status="fulfilled");var t=Ll;Ll=null,Jn=0,Fn=null;for(var e=0;e<t.length;e++)(0,t[e])()}}function nm(t,e){var a=[],n={status:"pending",value:null,reason:null,then:function(l){a.push(l)}};return t.then(function(){n.status="fulfilled",n.value=e;for(var l=0;l<a.length;l++)(0,a[l])(e)},function(l){for(n.status="rejected",n.reason=l,l=0;l<a.length;l++)(0,a[l])(void 0)}),n}var gr=E.S;E.S=function(t,e){If=le(),typeof e=="object"&&e!==null&&typeof e.then=="function"&&am(t,e),gr!==null&&gr(t,e)};var pn=nt(null);function Cs(){var t=pn.current;return t!==null?t:Mt.pooledCache}function Hi(t,e){e===null?j(pn,pn.current):j(pn,e.pool)}function mr(){var t=Cs();return t===null?null:{parent:Vt._currentValue,pool:t}}var $n=Error(o(460)),Ms=Error(o(474)),qi=Error(o(542)),Yi={then:function(){}};function pr(t){return t=t.status,t==="fulfilled"||t==="rejected"}function yr(t,e,a){switch(a=t[a],a===void 0?t.push(e):a!==e&&(e.then(ca,ca),e=a),e.status){case"fulfilled":return e.value;case"rejected":throw t=e.reason,br(t),t;default:if(typeof e.status=="string")e.then(ca,ca);else{if(t=Mt,t!==null&&100<t.shellSuspendCounter)throw Error(o(482));t=e,t.status="pending",t.then(function(n){if(e.status==="pending"){var l=e;l.status="fulfilled",l.value=n}},function(n){if(e.status==="pending"){var l=e;l.status="rejected",l.reason=n}})}switch(e.status){case"fulfilled":return e.value;case"rejected":throw t=e.reason,br(t),t}throw vn=e,$n}}function yn(t){try{var e=t._init;return e(t._payload)}catch(a){throw a!==null&&typeof a=="object"&&typeof a.then=="function"?(vn=a,$n):a}}var vn=null;function vr(){if(vn===null)throw Error(o(459));var t=vn;return vn=null,t}function br(t){if(t===$n||t===qi)throw Error(o(483))}var Wn=null,jl=0;function Vi(t){var e=jl;return jl+=1,Wn===null&&(Wn=[]),yr(Wn,t,e)}function Hl(t,e){e=e.props.ref,t.ref=e!==void 0?e:null}function Gi(t,e){throw e.$$typeof===R?Error(o(525)):(t=Object.prototype.toString.call(e),Error(o(31,t==="[object Object]"?"object with keys {"+Object.keys(e).join(", ")+"}":t)))}function Sr(t){function e(x,b){if(t){var T=x.deletions;T===null?(x.deletions=[b],x.flags|=16):T.push(b)}}function a(x,b){if(!t)return null;for(;b!==null;)e(x,b),b=b.sibling;return null}function n(x){for(var b=new Map;x!==null;)x.key!==null?b.set(x.key,x):b.set(x.index,x),x=x.sibling;return b}function l(x,b){return x=fa(x,b),x.index=0,x.sibling=null,x}function i(x,b,T){return x.index=T,t?(T=x.alternate,T!==null?(T=T.index,T<b?(x.flags|=67108866,b):T):(x.flags|=67108866,b)):(x.flags|=1048576,b)}function r(x){return t&&x.alternate===null&&(x.flags|=67108866),x}function h(x,b,T,C){return b===null||b.tag!==6?(b=vs(T,x.mode,C),b.return=x,b):(b=l(b,T),b.return=x,b)}function y(x,b,T,C){var G=T.type;return G===V?A(x,b,T.props.children,C,T.key):b!==null&&(b.elementType===G||typeof G=="object"&&G!==null&&G.$$typeof===Nt&&yn(G)===b.type)?(b=l(b,T.props),Hl(b,T),b.return=x,b):(b=wi(T.type,T.key,T.props,null,x.mode,C),Hl(b,T),b.return=x,b)}function O(x,b,T,C){return b===null||b.tag!==4||b.stateNode.containerInfo!==T.containerInfo||b.stateNode.implementation!==T.implementation?(b=bs(T,x.mode,C),b.return=x,b):(b=l(b,T.children||[]),b.return=x,b)}function A(x,b,T,C,G){return b===null||b.tag!==7?(b=dn(T,x.mode,C,G),b.return=x,b):(b=l(b,T),b.return=x,b)}function _(x,b,T){if(typeof b=="string"&&b!==""||typeof b=="number"||typeof b=="bigint")return b=vs(""+b,x.mode,T),b.return=x,b;if(typeof b=="object"&&b!==null){switch(b.$$typeof){case B:return T=wi(b.type,b.key,b.props,null,x.mode,T),Hl(T,b),T.return=x,T;case M:return b=bs(b,x.mode,T),b.return=x,b;case Nt:return b=yn(b),_(x,b,T)}if(ut(b)||k(b))return b=dn(b,x.mode,T,null),b.return=x,b;if(typeof b.then=="function")return _(x,Vi(b),T);if(b.$$typeof===ft)return _(x,ji(x,b),T);Gi(x,b)}return null}function z(x,b,T,C){var G=b!==null?b.key:null;if(typeof T=="string"&&T!==""||typeof T=="number"||typeof T=="bigint")return G!==null?null:h(x,b,""+T,C);if(typeof T=="object"&&T!==null){switch(T.$$typeof){case B:return T.key===G?y(x,b,T,C):null;case M:return T.key===G?O(x,b,T,C):null;case Nt:return T=yn(T),z(x,b,T,C)}if(ut(T)||k(T))return G!==null?null:A(x,b,T,C,null);if(typeof T.then=="function")return z(x,b,Vi(T),C);if(T.$$typeof===ft)return z(x,b,ji(x,T),C);Gi(x,T)}return null}function D(x,b,T,C,G){if(typeof C=="string"&&C!==""||typeof C=="number"||typeof C=="bigint")return x=x.get(T)||null,h(b,x,""+C,G);if(typeof C=="object"&&C!==null){switch(C.$$typeof){case B:return x=x.get(C.key===null?T:C.key)||null,y(b,x,C,G);case M:return x=x.get(C.key===null?T:C.key)||null,O(b,x,C,G);case Nt:return C=yn(C),D(x,b,T,C,G)}if(ut(C)||k(C))return x=x.get(T)||null,A(b,x,C,G,null);if(typeof C.then=="function")return D(x,b,T,Vi(C),G);if(C.$$typeof===ft)return D(x,b,T,ji(b,C),G);Gi(b,C)}return null}function H(x,b,T,C){for(var G=null,gt=null,Y=b,P=b=0,rt=null;Y!==null&&P<T.length;P++){Y.index>P?(rt=Y,Y=null):rt=Y.sibling;var mt=z(x,Y,T[P],C);if(mt===null){Y===null&&(Y=rt);break}t&&Y&&mt.alternate===null&&e(x,Y),b=i(mt,b,P),gt===null?G=mt:gt.sibling=mt,gt=mt,Y=rt}if(P===T.length)return a(x,Y),dt&&da(x,P),G;if(Y===null){for(;P<T.length;P++)Y=_(x,T[P],C),Y!==null&&(b=i(Y,b,P),gt===null?G=Y:gt.sibling=Y,gt=Y);return dt&&da(x,P),G}for(Y=n(Y);P<T.length;P++)rt=D(Y,x,P,T[P],C),rt!==null&&(t&&rt.alternate!==null&&Y.delete(rt.key===null?P:rt.key),b=i(rt,b,P),gt===null?G=rt:gt.sibling=rt,gt=rt);return t&&Y.forEach(function(Pa){return e(x,Pa)}),dt&&da(x,P),G}function X(x,b,T,C){if(T==null)throw Error(o(151));for(var G=null,gt=null,Y=b,P=b=0,rt=null,mt=T.next();Y!==null&&!mt.done;P++,mt=T.next()){Y.index>P?(rt=Y,Y=null):rt=Y.sibling;var Pa=z(x,Y,mt.value,C);if(Pa===null){Y===null&&(Y=rt);break}t&&Y&&Pa.alternate===null&&e(x,Y),b=i(Pa,b,P),gt===null?G=Pa:gt.sibling=Pa,gt=Pa,Y=rt}if(mt.done)return a(x,Y),dt&&da(x,P),G;if(Y===null){for(;!mt.done;P++,mt=T.next())mt=_(x,mt.value,C),mt!==null&&(b=i(mt,b,P),gt===null?G=mt:gt.sibling=mt,gt=mt);return dt&&da(x,P),G}for(Y=n(Y);!mt.done;P++,mt=T.next())mt=D(Y,x,P,mt.value,C),mt!==null&&(t&&mt.alternate!==null&&Y.delete(mt.key===null?P:mt.key),b=i(mt,b,P),gt===null?G=mt:gt.sibling=mt,gt=mt);return t&&Y.forEach(function(gp){return e(x,gp)}),dt&&da(x,P),G}function zt(x,b,T,C){if(typeof T=="object"&&T!==null&&T.type===V&&T.key===null&&(T=T.props.children),typeof T=="object"&&T!==null){switch(T.$$typeof){case B:t:{for(var G=T.key;b!==null;){if(b.key===G){if(G=T.type,G===V){if(b.tag===7){a(x,b.sibling),C=l(b,T.props.children),C.return=x,x=C;break t}}else if(b.elementType===G||typeof G=="object"&&G!==null&&G.$$typeof===Nt&&yn(G)===b.type){a(x,b.sibling),C=l(b,T.props),Hl(C,T),C.return=x,x=C;break t}a(x,b);break}else e(x,b);b=b.sibling}T.type===V?(C=dn(T.props.children,x.mode,C,T.key),C.return=x,x=C):(C=wi(T.type,T.key,T.props,null,x.mode,C),Hl(C,T),C.return=x,x=C)}return r(x);case M:t:{for(G=T.key;b!==null;){if(b.key===G)if(b.tag===4&&b.stateNode.containerInfo===T.containerInfo&&b.stateNode.implementation===T.implementation){a(x,b.sibling),C=l(b,T.children||[]),C.return=x,x=C;break t}else{a(x,b);break}else e(x,b);b=b.sibling}C=bs(T,x.mode,C),C.return=x,x=C}return r(x);case Nt:return T=yn(T),zt(x,b,T,C)}if(ut(T))return H(x,b,T,C);if(k(T)){if(G=k(T),typeof G!="function")throw Error(o(150));return T=G.call(T),X(x,b,T,C)}if(typeof T.then=="function")return zt(x,b,Vi(T),C);if(T.$$typeof===ft)return zt(x,b,ji(x,T),C);Gi(x,T)}return typeof T=="string"&&T!==""||typeof T=="number"||typeof T=="bigint"?(T=""+T,b!==null&&b.tag===6?(a(x,b.sibling),C=l(b,T),C.return=x,x=C):(a(x,b),C=vs(T,x.mode,C),C.return=x,x=C),r(x)):a(x,b)}return function(x,b,T,C){try{jl=0;var G=zt(x,b,T,C);return Wn=null,G}catch(Y){if(Y===$n||Y===qi)throw Y;var gt=Ee(29,Y,null,x.mode);return gt.lanes=C,gt.return=x,gt}finally{}}}var bn=Sr(!0),xr=Sr(!1),La=!1;function _s(t){t.updateQueue={baseState:t.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Rs(t,e){t=t.updateQueue,e.updateQueue===t&&(e.updateQueue={baseState:t.baseState,firstBaseUpdate:t.firstBaseUpdate,lastBaseUpdate:t.lastBaseUpdate,shared:t.shared,callbacks:null})}function ja(t){return{lane:t,tag:0,payload:null,callback:null,next:null}}function Ha(t,e,a){var n=t.updateQueue;if(n===null)return null;if(n=n.shared,(pt&2)!==0){var l=n.pending;return l===null?e.next=e:(e.next=l.next,l.next=e),n.pending=e,e=Ui(t),lr(t,null,a),e}return Ri(t,n,e,a),Ui(t)}function ql(t,e,a){if(e=e.updateQueue,e!==null&&(e=e.shared,(a&4194048)!==0)){var n=e.lanes;n&=t.pendingLanes,a|=n,e.lanes=a,re(t,a)}}function Us(t,e){var a=t.updateQueue,n=t.alternate;if(n!==null&&(n=n.updateQueue,a===n)){var l=null,i=null;if(a=a.firstBaseUpdate,a!==null){do{var r={lane:a.lane,tag:a.tag,payload:a.payload,callback:null,next:null};i===null?l=i=r:i=i.next=r,a=a.next}while(a!==null);i===null?l=i=e:i=i.next=e}else l=i=e;a={baseState:n.baseState,firstBaseUpdate:l,lastBaseUpdate:i,shared:n.shared,callbacks:n.callbacks},t.updateQueue=a;return}t=a.lastBaseUpdate,t===null?a.firstBaseUpdate=e:t.next=e,a.lastBaseUpdate=e}var ws=!1;function Yl(){if(ws){var t=Fn;if(t!==null)throw t}}function Vl(t,e,a,n){ws=!1;var l=t.updateQueue;La=!1;var i=l.firstBaseUpdate,r=l.lastBaseUpdate,h=l.shared.pending;if(h!==null){l.shared.pending=null;var y=h,O=y.next;y.next=null,r===null?i=O:r.next=O,r=y;var A=t.alternate;A!==null&&(A=A.updateQueue,h=A.lastBaseUpdate,h!==r&&(h===null?A.firstBaseUpdate=O:h.next=O,A.lastBaseUpdate=y))}if(i!==null){var _=l.baseState;r=0,A=O=y=null,h=i;do{var z=h.lane&-536870913,D=z!==h.lane;if(D?(ct&z)===z:(n&z)===z){z!==0&&z===Jn&&(ws=!0),A!==null&&(A=A.next={lane:0,tag:h.tag,payload:h.payload,callback:null,next:null});t:{var H=t,X=h;z=e;var zt=a;switch(X.tag){case 1:if(H=X.payload,typeof H=="function"){_=H.call(zt,_,z);break t}_=H;break t;case 3:H.flags=H.flags&-65537|128;case 0:if(H=X.payload,z=typeof H=="function"?H.call(zt,_,z):H,z==null)break t;_=g({},_,z);break t;case 2:La=!0}}z=h.callback,z!==null&&(t.flags|=64,D&&(t.flags|=8192),D=l.callbacks,D===null?l.callbacks=[z]:D.push(z))}else D={lane:z,tag:h.tag,payload:h.payload,callback:h.callback,next:null},A===null?(O=A=D,y=_):A=A.next=D,r|=z;if(h=h.next,h===null){if(h=l.shared.pending,h===null)break;D=h,h=D.next,D.next=null,l.lastBaseUpdate=D,l.shared.pending=null}}while(!0);A===null&&(y=_),l.baseState=y,l.firstBaseUpdate=O,l.lastBaseUpdate=A,i===null&&(l.shared.lanes=0),Qa|=r,t.lanes=r,t.memoizedState=_}}function Tr(t,e){if(typeof t!="function")throw Error(o(191,t));t.call(e)}function Er(t,e){var a=t.callbacks;if(a!==null)for(t.callbacks=null,t=0;t<a.length;t++)Tr(a[t],e)}var In=nt(null),Qi=nt(0);function Or(t,e){t=Ea,j(Qi,t),j(In,e),Ea=t|e.baseLanes}function Bs(){j(Qi,Ea),j(In,In.current)}function Ls(){Ea=Qi.current,st(In),st(Qi)}var Oe=nt(null),He=null;function qa(t){var e=t.alternate;j(qt,qt.current&1),j(Oe,t),He===null&&(e===null||In.current!==null||e.memoizedState!==null)&&(He=t)}function js(t){j(qt,qt.current),j(Oe,t),He===null&&(He=t)}function zr(t){t.tag===22?(j(qt,qt.current),j(Oe,t),He===null&&(He=t)):Ya()}function Ya(){j(qt,qt.current),j(Oe,Oe.current)}function ze(t){st(Oe),He===t&&(He=null),st(qt)}var qt=nt(0);function Xi(t){for(var e=t;e!==null;){if(e.tag===13){var a=e.memoizedState;if(a!==null&&(a=a.dehydrated,a===null||Xo(a)||Ko(a)))return e}else if(e.tag===19&&(e.memoizedProps.revealOrder==="forwards"||e.memoizedProps.revealOrder==="backwards"||e.memoizedProps.revealOrder==="unstable_legacy-backwards"||e.memoizedProps.revealOrder==="together")){if((e.flags&128)!==0)return e}else if(e.child!==null){e.child.return=e,e=e.child;continue}if(e===t)break;for(;e.sibling===null;){if(e.return===null||e.return===t)return null;e=e.return}e.sibling.return=e.return,e=e.sibling}return null}var ma=0,I=null,Et=null,Gt=null,Ki=!1,Pn=!1,Sn=!1,Zi=0,Gl=0,tl=null,lm=0;function Lt(){throw Error(o(321))}function Hs(t,e){if(e===null)return!1;for(var a=0;a<e.length&&a<t.length;a++)if(!Te(t[a],e[a]))return!1;return!0}function qs(t,e,a,n,l,i){return ma=i,I=e,e.memoizedState=null,e.updateQueue=null,e.lanes=0,E.H=t===null||t.memoizedState===null?cf:to,Sn=!1,i=a(n,l),Sn=!1,Pn&&(i=Ar(e,a,n,l)),Dr(t),i}function Dr(t){E.H=Kl;var e=Et!==null&&Et.next!==null;if(ma=0,Gt=Et=I=null,Ki=!1,Gl=0,tl=null,e)throw Error(o(300));t===null||Qt||(t=t.dependencies,t!==null&&Li(t)&&(Qt=!0))}function Ar(t,e,a,n){I=t;var l=0;do{if(Pn&&(tl=null),Gl=0,Pn=!1,25<=l)throw Error(o(301));if(l+=1,Gt=Et=null,t.updateQueue!=null){var i=t.updateQueue;i.lastEffect=null,i.events=null,i.stores=null,i.memoCache!=null&&(i.memoCache.index=0)}E.H=rf,i=e(a,n)}while(Pn);return i}function im(){var t=E.H,e=t.useState()[0];return e=typeof e.then=="function"?Ql(e):e,t=t.useState()[0],(Et!==null?Et.memoizedState:null)!==t&&(I.flags|=1024),e}function Ys(){var t=Zi!==0;return Zi=0,t}function Vs(t,e,a){e.updateQueue=t.updateQueue,e.flags&=-2053,t.lanes&=~a}function Gs(t){if(Ki){for(t=t.memoizedState;t!==null;){var e=t.queue;e!==null&&(e.pending=null),t=t.next}Ki=!1}ma=0,Gt=Et=I=null,Pn=!1,Gl=Zi=0,tl=null}function ue(){var t={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Gt===null?I.memoizedState=Gt=t:Gt=Gt.next=t,Gt}function Yt(){if(Et===null){var t=I.alternate;t=t!==null?t.memoizedState:null}else t=Et.next;var e=Gt===null?I.memoizedState:Gt.next;if(e!==null)Gt=e,Et=t;else{if(t===null)throw I.alternate===null?Error(o(467)):Error(o(310));Et=t,t={memoizedState:Et.memoizedState,baseState:Et.baseState,baseQueue:Et.baseQueue,queue:Et.queue,next:null},Gt===null?I.memoizedState=Gt=t:Gt=Gt.next=t}return Gt}function ki(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Ql(t){var e=Gl;return Gl+=1,tl===null&&(tl=[]),t=yr(tl,t,e),e=I,(Gt===null?e.memoizedState:Gt.next)===null&&(e=e.alternate,E.H=e===null||e.memoizedState===null?cf:to),t}function Ji(t){if(t!==null&&typeof t=="object"){if(typeof t.then=="function")return Ql(t);if(t.$$typeof===ft)return Wt(t)}throw Error(o(438,String(t)))}function Qs(t){var e=null,a=I.updateQueue;if(a!==null&&(e=a.memoCache),e==null){var n=I.alternate;n!==null&&(n=n.updateQueue,n!==null&&(n=n.memoCache,n!=null&&(e={data:n.data.map(function(l){return l.slice()}),index:0})))}if(e==null&&(e={data:[],index:0}),a===null&&(a=ki(),I.updateQueue=a),a.memoCache=e,a=e.data[e.index],a===void 0)for(a=e.data[e.index]=Array(t),n=0;n<t;n++)a[n]=yt;return e.index++,a}function pa(t,e){return typeof e=="function"?e(t):e}function Fi(t){var e=Yt();return Xs(e,Et,t)}function Xs(t,e,a){var n=t.queue;if(n===null)throw Error(o(311));n.lastRenderedReducer=a;var l=t.baseQueue,i=n.pending;if(i!==null){if(l!==null){var r=l.next;l.next=i.next,i.next=r}e.baseQueue=l=i,n.pending=null}if(i=t.baseState,l===null)t.memoizedState=i;else{e=l.next;var h=r=null,y=null,O=e,A=!1;do{var _=O.lane&-536870913;if(_!==O.lane?(ct&_)===_:(ma&_)===_){var z=O.revertLane;if(z===0)y!==null&&(y=y.next={lane:0,revertLane:0,gesture:null,action:O.action,hasEagerState:O.hasEagerState,eagerState:O.eagerState,next:null}),_===Jn&&(A=!0);else if((ma&z)===z){O=O.next,z===Jn&&(A=!0);continue}else _={lane:0,revertLane:O.revertLane,gesture:null,action:O.action,hasEagerState:O.hasEagerState,eagerState:O.eagerState,next:null},y===null?(h=y=_,r=i):y=y.next=_,I.lanes|=z,Qa|=z;_=O.action,Sn&&a(i,_),i=O.hasEagerState?O.eagerState:a(i,_)}else z={lane:_,revertLane:O.revertLane,gesture:O.gesture,action:O.action,hasEagerState:O.hasEagerState,eagerState:O.eagerState,next:null},y===null?(h=y=z,r=i):y=y.next=z,I.lanes|=_,Qa|=_;O=O.next}while(O!==null&&O!==e);if(y===null?r=i:y.next=h,!Te(i,t.memoizedState)&&(Qt=!0,A&&(a=Fn,a!==null)))throw a;t.memoizedState=i,t.baseState=r,t.baseQueue=y,n.lastRenderedState=i}return l===null&&(n.lanes=0),[t.memoizedState,n.dispatch]}function Ks(t){var e=Yt(),a=e.queue;if(a===null)throw Error(o(311));a.lastRenderedReducer=t;var n=a.dispatch,l=a.pending,i=e.memoizedState;if(l!==null){a.pending=null;var r=l=l.next;do i=t(i,r.action),r=r.next;while(r!==l);Te(i,e.memoizedState)||(Qt=!0),e.memoizedState=i,e.baseQueue===null&&(e.baseState=i),a.lastRenderedState=i}return[i,n]}function Nr(t,e,a){var n=I,l=Yt(),i=dt;if(i){if(a===void 0)throw Error(o(407));a=a()}else a=e();var r=!Te((Et||l).memoizedState,a);if(r&&(l.memoizedState=a,Qt=!0),l=l.queue,Js(_r.bind(null,n,l,t),[t]),l.getSnapshot!==e||r||Gt!==null&&Gt.memoizedState.tag&1){if(n.flags|=2048,el(9,{destroy:void 0},Mr.bind(null,n,l,a,e),null),Mt===null)throw Error(o(349));i||(ma&127)!==0||Cr(n,e,a)}return a}function Cr(t,e,a){t.flags|=16384,t={getSnapshot:e,value:a},e=I.updateQueue,e===null?(e=ki(),I.updateQueue=e,e.stores=[t]):(a=e.stores,a===null?e.stores=[t]:a.push(t))}function Mr(t,e,a,n){e.value=a,e.getSnapshot=n,Rr(e)&&Ur(t)}function _r(t,e,a){return a(function(){Rr(e)&&Ur(t)})}function Rr(t){var e=t.getSnapshot;t=t.value;try{var a=e();return!Te(t,a)}catch{return!0}}function Ur(t){var e=fn(t,2);e!==null&&ve(e,t,2)}function Zs(t){var e=ue();if(typeof t=="function"){var a=t;if(t=a(),Sn){Xe(!0);try{a()}finally{Xe(!1)}}}return e.memoizedState=e.baseState=t,e.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:pa,lastRenderedState:t},e}function wr(t,e,a,n){return t.baseState=a,Xs(t,Et,typeof n=="function"?n:pa)}function um(t,e,a,n,l){if(Ii(t))throw Error(o(485));if(t=e.action,t!==null){var i={payload:l,action:t,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(r){i.listeners.push(r)}};E.T!==null?a(!0):i.isTransition=!1,n(i),a=e.pending,a===null?(i.next=e.pending=i,Br(e,i)):(i.next=a.next,e.pending=a.next=i)}}function Br(t,e){var a=e.action,n=e.payload,l=t.state;if(e.isTransition){var i=E.T,r={};E.T=r;try{var h=a(l,n),y=E.S;y!==null&&y(r,h),Lr(t,e,h)}catch(O){ks(t,e,O)}finally{i!==null&&r.types!==null&&(i.types=r.types),E.T=i}}else try{i=a(l,n),Lr(t,e,i)}catch(O){ks(t,e,O)}}function Lr(t,e,a){a!==null&&typeof a=="object"&&typeof a.then=="function"?a.then(function(n){jr(t,e,n)},function(n){return ks(t,e,n)}):jr(t,e,a)}function jr(t,e,a){e.status="fulfilled",e.value=a,Hr(e),t.state=a,e=t.pending,e!==null&&(a=e.next,a===e?t.pending=null:(a=a.next,e.next=a,Br(t,a)))}function ks(t,e,a){var n=t.pending;if(t.pending=null,n!==null){n=n.next;do e.status="rejected",e.reason=a,Hr(e),e=e.next;while(e!==n)}t.action=null}function Hr(t){t=t.listeners;for(var e=0;e<t.length;e++)(0,t[e])()}function qr(t,e){return e}function Yr(t,e){if(dt){var a=Mt.formState;if(a!==null){t:{var n=I;if(dt){if(_t){e:{for(var l=_t,i=je;l.nodeType!==8;){if(!i){l=null;break e}if(l=qe(l.nextSibling),l===null){l=null;break e}}i=l.data,l=i==="F!"||i==="F"?l:null}if(l){_t=qe(l.nextSibling),n=l.data==="F!";break t}}wa(n)}n=!1}n&&(e=a[0])}}return a=ue(),a.memoizedState=a.baseState=e,n={pending:null,lanes:0,dispatch:null,lastRenderedReducer:qr,lastRenderedState:e},a.queue=n,a=uf.bind(null,I,n),n.dispatch=a,n=Zs(!1),i=Ps.bind(null,I,!1,n.queue),n=ue(),l={state:e,dispatch:null,action:t,pending:null},n.queue=l,a=um.bind(null,I,l,i,a),l.dispatch=a,n.memoizedState=t,[e,a,!1]}function Vr(t){var e=Yt();return Gr(e,Et,t)}function Gr(t,e,a){if(e=Xs(t,e,qr)[0],t=Fi(pa)[0],typeof e=="object"&&e!==null&&typeof e.then=="function")try{var n=Ql(e)}catch(r){throw r===$n?qi:r}else n=e;e=Yt();var l=e.queue,i=l.dispatch;return a!==e.memoizedState&&(I.flags|=2048,el(9,{destroy:void 0},sm.bind(null,l,a),null)),[n,i,t]}function sm(t,e){t.action=e}function Qr(t){var e=Yt(),a=Et;if(a!==null)return Gr(e,a,t);Yt(),e=e.memoizedState,a=Yt();var n=a.queue.dispatch;return a.memoizedState=t,[e,n,!1]}function el(t,e,a,n){return t={tag:t,create:a,deps:n,inst:e,next:null},e=I.updateQueue,e===null&&(e=ki(),I.updateQueue=e),a=e.lastEffect,a===null?e.lastEffect=t.next=t:(n=a.next,a.next=t,t.next=n,e.lastEffect=t),t}function Xr(){return Yt().memoizedState}function $i(t,e,a,n){var l=ue();I.flags|=t,l.memoizedState=el(1|e,{destroy:void 0},a,n===void 0?null:n)}function Wi(t,e,a,n){var l=Yt();n=n===void 0?null:n;var i=l.memoizedState.inst;Et!==null&&n!==null&&Hs(n,Et.memoizedState.deps)?l.memoizedState=el(e,i,a,n):(I.flags|=t,l.memoizedState=el(1|e,i,a,n))}function Kr(t,e){$i(8390656,8,t,e)}function Js(t,e){Wi(2048,8,t,e)}function om(t){I.flags|=4;var e=I.updateQueue;if(e===null)e=ki(),I.updateQueue=e,e.events=[t];else{var a=e.events;a===null?e.events=[t]:a.push(t)}}function Zr(t){var e=Yt().memoizedState;return om({ref:e,nextImpl:t}),function(){if((pt&2)!==0)throw Error(o(440));return e.impl.apply(void 0,arguments)}}function kr(t,e){return Wi(4,2,t,e)}function Jr(t,e){return Wi(4,4,t,e)}function Fr(t,e){if(typeof e=="function"){t=t();var a=e(t);return function(){typeof a=="function"?a():e(null)}}if(e!=null)return t=t(),e.current=t,function(){e.current=null}}function $r(t,e,a){a=a!=null?a.concat([t]):null,Wi(4,4,Fr.bind(null,e,t),a)}function Fs(){}function Wr(t,e){var a=Yt();e=e===void 0?null:e;var n=a.memoizedState;return e!==null&&Hs(e,n[1])?n[0]:(a.memoizedState=[t,e],t)}function Ir(t,e){var a=Yt();e=e===void 0?null:e;var n=a.memoizedState;if(e!==null&&Hs(e,n[1]))return n[0];if(n=t(),Sn){Xe(!0);try{t()}finally{Xe(!1)}}return a.memoizedState=[n,e],n}function $s(t,e,a){return a===void 0||(ma&1073741824)!==0&&(ct&261930)===0?t.memoizedState=e:(t.memoizedState=a,t=td(),I.lanes|=t,Qa|=t,a)}function Pr(t,e,a,n){return Te(a,e)?a:In.current!==null?(t=$s(t,a,n),Te(t,e)||(Qt=!0),t):(ma&42)===0||(ma&1073741824)!==0&&(ct&261930)===0?(Qt=!0,t.memoizedState=a):(t=td(),I.lanes|=t,Qa|=t,e)}function tf(t,e,a,n,l){var i=U.p;U.p=i!==0&&8>i?i:8;var r=E.T,h={};E.T=h,Ps(t,!1,e,a);try{var y=l(),O=E.S;if(O!==null&&O(h,y),y!==null&&typeof y=="object"&&typeof y.then=="function"){var A=nm(y,n);Xl(t,e,A,Ne(t))}else Xl(t,e,n,Ne(t))}catch(_){Xl(t,e,{then:function(){},status:"rejected",reason:_},Ne())}finally{U.p=i,r!==null&&h.types!==null&&(r.types=h.types),E.T=r}}function cm(){}function Ws(t,e,a,n){if(t.tag!==5)throw Error(o(476));var l=ef(t).queue;tf(t,l,e,q,a===null?cm:function(){return af(t),a(n)})}function ef(t){var e=t.memoizedState;if(e!==null)return e;e={memoizedState:q,baseState:q,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:pa,lastRenderedState:q},next:null};var a={};return e.next={memoizedState:a,baseState:a,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:pa,lastRenderedState:a},next:null},t.memoizedState=e,t=t.alternate,t!==null&&(t.memoizedState=e),e}function af(t){var e=ef(t);e.next===null&&(e=t.alternate.memoizedState),Xl(t,e.next.queue,{},Ne())}function Is(){return Wt(si)}function nf(){return Yt().memoizedState}function lf(){return Yt().memoizedState}function rm(t){for(var e=t.return;e!==null;){switch(e.tag){case 24:case 3:var a=Ne();t=ja(a);var n=Ha(e,t,a);n!==null&&(ve(n,e,a),ql(n,e,a)),e={cache:As()},t.payload=e;return}e=e.return}}function fm(t,e,a){var n=Ne();a={lane:n,revertLane:0,gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null},Ii(t)?sf(e,a):(a=ps(t,e,a,n),a!==null&&(ve(a,t,n),of(a,e,n)))}function uf(t,e,a){var n=Ne();Xl(t,e,a,n)}function Xl(t,e,a,n){var l={lane:n,revertLane:0,gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null};if(Ii(t))sf(e,l);else{var i=t.alternate;if(t.lanes===0&&(i===null||i.lanes===0)&&(i=e.lastRenderedReducer,i!==null))try{var r=e.lastRenderedState,h=i(r,a);if(l.hasEagerState=!0,l.eagerState=h,Te(h,r))return Ri(t,e,l,0),Mt===null&&_i(),!1}catch{}finally{}if(a=ps(t,e,l,n),a!==null)return ve(a,t,n),of(a,e,n),!0}return!1}function Ps(t,e,a,n){if(n={lane:2,revertLane:Ro(),gesture:null,action:n,hasEagerState:!1,eagerState:null,next:null},Ii(t)){if(e)throw Error(o(479))}else e=ps(t,a,n,2),e!==null&&ve(e,t,2)}function Ii(t){var e=t.alternate;return t===I||e!==null&&e===I}function sf(t,e){Pn=Ki=!0;var a=t.pending;a===null?e.next=e:(e.next=a.next,a.next=e),t.pending=e}function of(t,e,a){if((a&4194048)!==0){var n=e.lanes;n&=t.pendingLanes,a|=n,e.lanes=a,re(t,a)}}var Kl={readContext:Wt,use:Ji,useCallback:Lt,useContext:Lt,useEffect:Lt,useImperativeHandle:Lt,useLayoutEffect:Lt,useInsertionEffect:Lt,useMemo:Lt,useReducer:Lt,useRef:Lt,useState:Lt,useDebugValue:Lt,useDeferredValue:Lt,useTransition:Lt,useSyncExternalStore:Lt,useId:Lt,useHostTransitionStatus:Lt,useFormState:Lt,useActionState:Lt,useOptimistic:Lt,useMemoCache:Lt,useCacheRefresh:Lt};Kl.useEffectEvent=Lt;var cf={readContext:Wt,use:Ji,useCallback:function(t,e){return ue().memoizedState=[t,e===void 0?null:e],t},useContext:Wt,useEffect:Kr,useImperativeHandle:function(t,e,a){a=a!=null?a.concat([t]):null,$i(4194308,4,Fr.bind(null,e,t),a)},useLayoutEffect:function(t,e){return $i(4194308,4,t,e)},useInsertionEffect:function(t,e){$i(4,2,t,e)},useMemo:function(t,e){var a=ue();e=e===void 0?null:e;var n=t();if(Sn){Xe(!0);try{t()}finally{Xe(!1)}}return a.memoizedState=[n,e],n},useReducer:function(t,e,a){var n=ue();if(a!==void 0){var l=a(e);if(Sn){Xe(!0);try{a(e)}finally{Xe(!1)}}}else l=e;return n.memoizedState=n.baseState=l,t={pending:null,lanes:0,dispatch:null,lastRenderedReducer:t,lastRenderedState:l},n.queue=t,t=t.dispatch=fm.bind(null,I,t),[n.memoizedState,t]},useRef:function(t){var e=ue();return t={current:t},e.memoizedState=t},useState:function(t){t=Zs(t);var e=t.queue,a=uf.bind(null,I,e);return e.dispatch=a,[t.memoizedState,a]},useDebugValue:Fs,useDeferredValue:function(t,e){var a=ue();return $s(a,t,e)},useTransition:function(){var t=Zs(!1);return t=tf.bind(null,I,t.queue,!0,!1),ue().memoizedState=t,[!1,t]},useSyncExternalStore:function(t,e,a){var n=I,l=ue();if(dt){if(a===void 0)throw Error(o(407));a=a()}else{if(a=e(),Mt===null)throw Error(o(349));(ct&127)!==0||Cr(n,e,a)}l.memoizedState=a;var i={value:a,getSnapshot:e};return l.queue=i,Kr(_r.bind(null,n,i,t),[t]),n.flags|=2048,el(9,{destroy:void 0},Mr.bind(null,n,i,a,e),null),a},useId:function(){var t=ue(),e=Mt.identifierPrefix;if(dt){var a=Pe,n=Ie;a=(n&~(1<<32-te(n)-1)).toString(32)+a,e="_"+e+"R_"+a,a=Zi++,0<a&&(e+="H"+a.toString(32)),e+="_"}else a=lm++,e="_"+e+"r_"+a.toString(32)+"_";return t.memoizedState=e},useHostTransitionStatus:Is,useFormState:Yr,useActionState:Yr,useOptimistic:function(t){var e=ue();e.memoizedState=e.baseState=t;var a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return e.queue=a,e=Ps.bind(null,I,!0,a),a.dispatch=e,[t,e]},useMemoCache:Qs,useCacheRefresh:function(){return ue().memoizedState=rm.bind(null,I)},useEffectEvent:function(t){var e=ue(),a={impl:t};return e.memoizedState=a,function(){if((pt&2)!==0)throw Error(o(440));return a.impl.apply(void 0,arguments)}}},to={readContext:Wt,use:Ji,useCallback:Wr,useContext:Wt,useEffect:Js,useImperativeHandle:$r,useInsertionEffect:kr,useLayoutEffect:Jr,useMemo:Ir,useReducer:Fi,useRef:Xr,useState:function(){return Fi(pa)},useDebugValue:Fs,useDeferredValue:function(t,e){var a=Yt();return Pr(a,Et.memoizedState,t,e)},useTransition:function(){var t=Fi(pa)[0],e=Yt().memoizedState;return[typeof t=="boolean"?t:Ql(t),e]},useSyncExternalStore:Nr,useId:nf,useHostTransitionStatus:Is,useFormState:Vr,useActionState:Vr,useOptimistic:function(t,e){var a=Yt();return wr(a,Et,t,e)},useMemoCache:Qs,useCacheRefresh:lf};to.useEffectEvent=Zr;var rf={readContext:Wt,use:Ji,useCallback:Wr,useContext:Wt,useEffect:Js,useImperativeHandle:$r,useInsertionEffect:kr,useLayoutEffect:Jr,useMemo:Ir,useReducer:Ks,useRef:Xr,useState:function(){return Ks(pa)},useDebugValue:Fs,useDeferredValue:function(t,e){var a=Yt();return Et===null?$s(a,t,e):Pr(a,Et.memoizedState,t,e)},useTransition:function(){var t=Ks(pa)[0],e=Yt().memoizedState;return[typeof t=="boolean"?t:Ql(t),e]},useSyncExternalStore:Nr,useId:nf,useHostTransitionStatus:Is,useFormState:Qr,useActionState:Qr,useOptimistic:function(t,e){var a=Yt();return Et!==null?wr(a,Et,t,e):(a.baseState=t,[t,a.queue.dispatch])},useMemoCache:Qs,useCacheRefresh:lf};rf.useEffectEvent=Zr;function eo(t,e,a,n){e=t.memoizedState,a=a(n,e),a=a==null?e:g({},e,a),t.memoizedState=a,t.lanes===0&&(t.updateQueue.baseState=a)}var ao={enqueueSetState:function(t,e,a){t=t._reactInternals;var n=Ne(),l=ja(n);l.payload=e,a!=null&&(l.callback=a),e=Ha(t,l,n),e!==null&&(ve(e,t,n),ql(e,t,n))},enqueueReplaceState:function(t,e,a){t=t._reactInternals;var n=Ne(),l=ja(n);l.tag=1,l.payload=e,a!=null&&(l.callback=a),e=Ha(t,l,n),e!==null&&(ve(e,t,n),ql(e,t,n))},enqueueForceUpdate:function(t,e){t=t._reactInternals;var a=Ne(),n=ja(a);n.tag=2,e!=null&&(n.callback=e),e=Ha(t,n,a),e!==null&&(ve(e,t,a),ql(e,t,a))}};function ff(t,e,a,n,l,i,r){return t=t.stateNode,typeof t.shouldComponentUpdate=="function"?t.shouldComponentUpdate(n,i,r):e.prototype&&e.prototype.isPureReactComponent?!_l(a,n)||!_l(l,i):!0}function df(t,e,a,n){t=e.state,typeof e.componentWillReceiveProps=="function"&&e.componentWillReceiveProps(a,n),typeof e.UNSAFE_componentWillReceiveProps=="function"&&e.UNSAFE_componentWillReceiveProps(a,n),e.state!==t&&ao.enqueueReplaceState(e,e.state,null)}function xn(t,e){var a=e;if("ref"in e){a={};for(var n in e)n!=="ref"&&(a[n]=e[n])}if(t=t.defaultProps){a===e&&(a=g({},a));for(var l in t)a[l]===void 0&&(a[l]=t[l])}return a}function hf(t){Mi(t)}function gf(t){console.error(t)}function mf(t){Mi(t)}function Pi(t,e){try{var a=t.onUncaughtError;a(e.value,{componentStack:e.stack})}catch(n){setTimeout(function(){throw n})}}function pf(t,e,a){try{var n=t.onCaughtError;n(a.value,{componentStack:a.stack,errorBoundary:e.tag===1?e.stateNode:null})}catch(l){setTimeout(function(){throw l})}}function no(t,e,a){return a=ja(a),a.tag=3,a.payload={element:null},a.callback=function(){Pi(t,e)},a}function yf(t){return t=ja(t),t.tag=3,t}function vf(t,e,a,n){var l=a.type.getDerivedStateFromError;if(typeof l=="function"){var i=n.value;t.payload=function(){return l(i)},t.callback=function(){pf(e,a,n)}}var r=a.stateNode;r!==null&&typeof r.componentDidCatch=="function"&&(t.callback=function(){pf(e,a,n),typeof l!="function"&&(Xa===null?Xa=new Set([this]):Xa.add(this));var h=n.stack;this.componentDidCatch(n.value,{componentStack:h!==null?h:""})})}function dm(t,e,a,n,l){if(a.flags|=32768,n!==null&&typeof n=="object"&&typeof n.then=="function"){if(e=a.alternate,e!==null&&kn(e,a,l,!0),a=Oe.current,a!==null){switch(a.tag){case 31:case 13:return He===null?fu():a.alternate===null&&jt===0&&(jt=3),a.flags&=-257,a.flags|=65536,a.lanes=l,n===Yi?a.flags|=16384:(e=a.updateQueue,e===null?a.updateQueue=new Set([n]):e.add(n),Co(t,n,l)),!1;case 22:return a.flags|=65536,n===Yi?a.flags|=16384:(e=a.updateQueue,e===null?(e={transitions:null,markerInstances:null,retryQueue:new Set([n])},a.updateQueue=e):(a=e.retryQueue,a===null?e.retryQueue=new Set([n]):a.add(n)),Co(t,n,l)),!1}throw Error(o(435,a.tag))}return Co(t,n,l),fu(),!1}if(dt)return e=Oe.current,e!==null?((e.flags&65536)===0&&(e.flags|=256),e.flags|=65536,e.lanes=l,n!==Ts&&(t=Error(o(422),{cause:n}),wl(we(t,a)))):(n!==Ts&&(e=Error(o(423),{cause:n}),wl(we(e,a))),t=t.current.alternate,t.flags|=65536,l&=-l,t.lanes|=l,n=we(n,a),l=no(t.stateNode,n,l),Us(t,l),jt!==4&&(jt=2)),!1;var i=Error(o(520),{cause:n});if(i=we(i,a),Pl===null?Pl=[i]:Pl.push(i),jt!==4&&(jt=2),e===null)return!0;n=we(n,a),a=e;do{switch(a.tag){case 3:return a.flags|=65536,t=l&-l,a.lanes|=t,t=no(a.stateNode,n,t),Us(a,t),!1;case 1:if(e=a.type,i=a.stateNode,(a.flags&128)===0&&(typeof e.getDerivedStateFromError=="function"||i!==null&&typeof i.componentDidCatch=="function"&&(Xa===null||!Xa.has(i))))return a.flags|=65536,l&=-l,a.lanes|=l,l=yf(l),vf(l,t,a,n),Us(a,l),!1}a=a.return}while(a!==null);return!1}var lo=Error(o(461)),Qt=!1;function It(t,e,a,n){e.child=t===null?xr(e,null,a,n):bn(e,t.child,a,n)}function bf(t,e,a,n,l){a=a.render;var i=e.ref;if("ref"in n){var r={};for(var h in n)h!=="ref"&&(r[h]=n[h])}else r=n;return mn(e),n=qs(t,e,a,r,i,l),h=Ys(),t!==null&&!Qt?(Vs(t,e,l),ya(t,e,l)):(dt&&h&&Ss(e),e.flags|=1,It(t,e,n,l),e.child)}function Sf(t,e,a,n,l){if(t===null){var i=a.type;return typeof i=="function"&&!ys(i)&&i.defaultProps===void 0&&a.compare===null?(e.tag=15,e.type=i,xf(t,e,i,n,l)):(t=wi(a.type,null,n,e,e.mode,l),t.ref=e.ref,t.return=e,e.child=t)}if(i=t.child,!ho(t,l)){var r=i.memoizedProps;if(a=a.compare,a=a!==null?a:_l,a(r,n)&&t.ref===e.ref)return ya(t,e,l)}return e.flags|=1,t=fa(i,n),t.ref=e.ref,t.return=e,e.child=t}function xf(t,e,a,n,l){if(t!==null){var i=t.memoizedProps;if(_l(i,n)&&t.ref===e.ref)if(Qt=!1,e.pendingProps=n=i,ho(t,l))(t.flags&131072)!==0&&(Qt=!0);else return e.lanes=t.lanes,ya(t,e,l)}return io(t,e,a,n,l)}function Tf(t,e,a,n){var l=n.children,i=t!==null?t.memoizedState:null;if(t===null&&e.stateNode===null&&(e.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),n.mode==="hidden"){if((e.flags&128)!==0){if(i=i!==null?i.baseLanes|a:a,t!==null){for(n=e.child=t.child,l=0;n!==null;)l=l|n.lanes|n.childLanes,n=n.sibling;n=l&~i}else n=0,e.child=null;return Ef(t,e,i,a,n)}if((a&536870912)!==0)e.memoizedState={baseLanes:0,cachePool:null},t!==null&&Hi(e,i!==null?i.cachePool:null),i!==null?Or(e,i):Bs(),zr(e);else return n=e.lanes=536870912,Ef(t,e,i!==null?i.baseLanes|a:a,a,n)}else i!==null?(Hi(e,i.cachePool),Or(e,i),Ya(),e.memoizedState=null):(t!==null&&Hi(e,null),Bs(),Ya());return It(t,e,l,a),e.child}function Zl(t,e){return t!==null&&t.tag===22||e.stateNode!==null||(e.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),e.sibling}function Ef(t,e,a,n,l){var i=Cs();return i=i===null?null:{parent:Vt._currentValue,pool:i},e.memoizedState={baseLanes:a,cachePool:i},t!==null&&Hi(e,null),Bs(),zr(e),t!==null&&kn(t,e,n,!0),e.childLanes=l,null}function tu(t,e){return e=au({mode:e.mode,children:e.children},t.mode),e.ref=t.ref,t.child=e,e.return=t,e}function Of(t,e,a){return bn(e,t.child,null,a),t=tu(e,e.pendingProps),t.flags|=2,ze(e),e.memoizedState=null,t}function hm(t,e,a){var n=e.pendingProps,l=(e.flags&128)!==0;if(e.flags&=-129,t===null){if(dt){if(n.mode==="hidden")return t=tu(e,n),e.lanes=536870912,Zl(null,t);if(js(e),(t=_t)?(t=Ld(t,je),t=t!==null&&t.data==="&"?t:null,t!==null&&(e.memoizedState={dehydrated:t,treeContext:Ra!==null?{id:Ie,overflow:Pe}:null,retryLane:536870912,hydrationErrors:null},a=ur(t),a.return=e,e.child=a,$t=e,_t=null)):t=null,t===null)throw wa(e);return e.lanes=536870912,null}return tu(e,n)}var i=t.memoizedState;if(i!==null){var r=i.dehydrated;if(js(e),l)if(e.flags&256)e.flags&=-257,e=Of(t,e,a);else if(e.memoizedState!==null)e.child=t.child,e.flags|=128,e=null;else throw Error(o(558));else if(Qt||kn(t,e,a,!1),l=(a&t.childLanes)!==0,Qt||l){if(n=Mt,n!==null&&(r=fe(n,a),r!==0&&r!==i.retryLane))throw i.retryLane=r,fn(t,r),ve(n,t,r),lo;fu(),e=Of(t,e,a)}else t=i.treeContext,_t=qe(r.nextSibling),$t=e,dt=!0,Ua=null,je=!1,t!==null&&cr(e,t),e=tu(e,n),e.flags|=4096;return e}return t=fa(t.child,{mode:n.mode,children:n.children}),t.ref=e.ref,e.child=t,t.return=e,t}function eu(t,e){var a=e.ref;if(a===null)t!==null&&t.ref!==null&&(e.flags|=4194816);else{if(typeof a!="function"&&typeof a!="object")throw Error(o(284));(t===null||t.ref!==a)&&(e.flags|=4194816)}}function io(t,e,a,n,l){return mn(e),a=qs(t,e,a,n,void 0,l),n=Ys(),t!==null&&!Qt?(Vs(t,e,l),ya(t,e,l)):(dt&&n&&Ss(e),e.flags|=1,It(t,e,a,l),e.child)}function zf(t,e,a,n,l,i){return mn(e),e.updateQueue=null,a=Ar(e,n,a,l),Dr(t),n=Ys(),t!==null&&!Qt?(Vs(t,e,i),ya(t,e,i)):(dt&&n&&Ss(e),e.flags|=1,It(t,e,a,i),e.child)}function Df(t,e,a,n,l){if(mn(e),e.stateNode===null){var i=Qn,r=a.contextType;typeof r=="object"&&r!==null&&(i=Wt(r)),i=new a(n,i),e.memoizedState=i.state!==null&&i.state!==void 0?i.state:null,i.updater=ao,e.stateNode=i,i._reactInternals=e,i=e.stateNode,i.props=n,i.state=e.memoizedState,i.refs={},_s(e),r=a.contextType,i.context=typeof r=="object"&&r!==null?Wt(r):Qn,i.state=e.memoizedState,r=a.getDerivedStateFromProps,typeof r=="function"&&(eo(e,a,r,n),i.state=e.memoizedState),typeof a.getDerivedStateFromProps=="function"||typeof i.getSnapshotBeforeUpdate=="function"||typeof i.UNSAFE_componentWillMount!="function"&&typeof i.componentWillMount!="function"||(r=i.state,typeof i.componentWillMount=="function"&&i.componentWillMount(),typeof i.UNSAFE_componentWillMount=="function"&&i.UNSAFE_componentWillMount(),r!==i.state&&ao.enqueueReplaceState(i,i.state,null),Vl(e,n,i,l),Yl(),i.state=e.memoizedState),typeof i.componentDidMount=="function"&&(e.flags|=4194308),n=!0}else if(t===null){i=e.stateNode;var h=e.memoizedProps,y=xn(a,h);i.props=y;var O=i.context,A=a.contextType;r=Qn,typeof A=="object"&&A!==null&&(r=Wt(A));var _=a.getDerivedStateFromProps;A=typeof _=="function"||typeof i.getSnapshotBeforeUpdate=="function",h=e.pendingProps!==h,A||typeof i.UNSAFE_componentWillReceiveProps!="function"&&typeof i.componentWillReceiveProps!="function"||(h||O!==r)&&df(e,i,n,r),La=!1;var z=e.memoizedState;i.state=z,Vl(e,n,i,l),Yl(),O=e.memoizedState,h||z!==O||La?(typeof _=="function"&&(eo(e,a,_,n),O=e.memoizedState),(y=La||ff(e,a,y,n,z,O,r))?(A||typeof i.UNSAFE_componentWillMount!="function"&&typeof i.componentWillMount!="function"||(typeof i.componentWillMount=="function"&&i.componentWillMount(),typeof i.UNSAFE_componentWillMount=="function"&&i.UNSAFE_componentWillMount()),typeof i.componentDidMount=="function"&&(e.flags|=4194308)):(typeof i.componentDidMount=="function"&&(e.flags|=4194308),e.memoizedProps=n,e.memoizedState=O),i.props=n,i.state=O,i.context=r,n=y):(typeof i.componentDidMount=="function"&&(e.flags|=4194308),n=!1)}else{i=e.stateNode,Rs(t,e),r=e.memoizedProps,A=xn(a,r),i.props=A,_=e.pendingProps,z=i.context,O=a.contextType,y=Qn,typeof O=="object"&&O!==null&&(y=Wt(O)),h=a.getDerivedStateFromProps,(O=typeof h=="function"||typeof i.getSnapshotBeforeUpdate=="function")||typeof i.UNSAFE_componentWillReceiveProps!="function"&&typeof i.componentWillReceiveProps!="function"||(r!==_||z!==y)&&df(e,i,n,y),La=!1,z=e.memoizedState,i.state=z,Vl(e,n,i,l),Yl();var D=e.memoizedState;r!==_||z!==D||La||t!==null&&t.dependencies!==null&&Li(t.dependencies)?(typeof h=="function"&&(eo(e,a,h,n),D=e.memoizedState),(A=La||ff(e,a,A,n,z,D,y)||t!==null&&t.dependencies!==null&&Li(t.dependencies))?(O||typeof i.UNSAFE_componentWillUpdate!="function"&&typeof i.componentWillUpdate!="function"||(typeof i.componentWillUpdate=="function"&&i.componentWillUpdate(n,D,y),typeof i.UNSAFE_componentWillUpdate=="function"&&i.UNSAFE_componentWillUpdate(n,D,y)),typeof i.componentDidUpdate=="function"&&(e.flags|=4),typeof i.getSnapshotBeforeUpdate=="function"&&(e.flags|=1024)):(typeof i.componentDidUpdate!="function"||r===t.memoizedProps&&z===t.memoizedState||(e.flags|=4),typeof i.getSnapshotBeforeUpdate!="function"||r===t.memoizedProps&&z===t.memoizedState||(e.flags|=1024),e.memoizedProps=n,e.memoizedState=D),i.props=n,i.state=D,i.context=y,n=A):(typeof i.componentDidUpdate!="function"||r===t.memoizedProps&&z===t.memoizedState||(e.flags|=4),typeof i.getSnapshotBeforeUpdate!="function"||r===t.memoizedProps&&z===t.memoizedState||(e.flags|=1024),n=!1)}return i=n,eu(t,e),n=(e.flags&128)!==0,i||n?(i=e.stateNode,a=n&&typeof a.getDerivedStateFromError!="function"?null:i.render(),e.flags|=1,t!==null&&n?(e.child=bn(e,t.child,null,l),e.child=bn(e,null,a,l)):It(t,e,a,l),e.memoizedState=i.state,t=e.child):t=ya(t,e,l),t}function Af(t,e,a,n){return hn(),e.flags|=256,It(t,e,a,n),e.child}var uo={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function so(t){return{baseLanes:t,cachePool:mr()}}function oo(t,e,a){return t=t!==null?t.childLanes&~a:0,e&&(t|=Ae),t}function Nf(t,e,a){var n=e.pendingProps,l=!1,i=(e.flags&128)!==0,r;if((r=i)||(r=t!==null&&t.memoizedState===null?!1:(qt.current&2)!==0),r&&(l=!0,e.flags&=-129),r=(e.flags&32)!==0,e.flags&=-33,t===null){if(dt){if(l?qa(e):Ya(),(t=_t)?(t=Ld(t,je),t=t!==null&&t.data!=="&"?t:null,t!==null&&(e.memoizedState={dehydrated:t,treeContext:Ra!==null?{id:Ie,overflow:Pe}:null,retryLane:536870912,hydrationErrors:null},a=ur(t),a.return=e,e.child=a,$t=e,_t=null)):t=null,t===null)throw wa(e);return Ko(t)?e.lanes=32:e.lanes=536870912,null}var h=n.children;return n=n.fallback,l?(Ya(),l=e.mode,h=au({mode:"hidden",children:h},l),n=dn(n,l,a,null),h.return=e,n.return=e,h.sibling=n,e.child=h,n=e.child,n.memoizedState=so(a),n.childLanes=oo(t,r,a),e.memoizedState=uo,Zl(null,n)):(qa(e),co(e,h))}var y=t.memoizedState;if(y!==null&&(h=y.dehydrated,h!==null)){if(i)e.flags&256?(qa(e),e.flags&=-257,e=ro(t,e,a)):e.memoizedState!==null?(Ya(),e.child=t.child,e.flags|=128,e=null):(Ya(),h=n.fallback,l=e.mode,n=au({mode:"visible",children:n.children},l),h=dn(h,l,a,null),h.flags|=2,n.return=e,h.return=e,n.sibling=h,e.child=n,bn(e,t.child,null,a),n=e.child,n.memoizedState=so(a),n.childLanes=oo(t,r,a),e.memoizedState=uo,e=Zl(null,n));else if(qa(e),Ko(h)){if(r=h.nextSibling&&h.nextSibling.dataset,r)var O=r.dgst;r=O,n=Error(o(419)),n.stack="",n.digest=r,wl({value:n,source:null,stack:null}),e=ro(t,e,a)}else if(Qt||kn(t,e,a,!1),r=(a&t.childLanes)!==0,Qt||r){if(r=Mt,r!==null&&(n=fe(r,a),n!==0&&n!==y.retryLane))throw y.retryLane=n,fn(t,n),ve(r,t,n),lo;Xo(h)||fu(),e=ro(t,e,a)}else Xo(h)?(e.flags|=192,e.child=t.child,e=null):(t=y.treeContext,_t=qe(h.nextSibling),$t=e,dt=!0,Ua=null,je=!1,t!==null&&cr(e,t),e=co(e,n.children),e.flags|=4096);return e}return l?(Ya(),h=n.fallback,l=e.mode,y=t.child,O=y.sibling,n=fa(y,{mode:"hidden",children:n.children}),n.subtreeFlags=y.subtreeFlags&65011712,O!==null?h=fa(O,h):(h=dn(h,l,a,null),h.flags|=2),h.return=e,n.return=e,n.sibling=h,e.child=n,Zl(null,n),n=e.child,h=t.child.memoizedState,h===null?h=so(a):(l=h.cachePool,l!==null?(y=Vt._currentValue,l=l.parent!==y?{parent:y,pool:y}:l):l=mr(),h={baseLanes:h.baseLanes|a,cachePool:l}),n.memoizedState=h,n.childLanes=oo(t,r,a),e.memoizedState=uo,Zl(t.child,n)):(qa(e),a=t.child,t=a.sibling,a=fa(a,{mode:"visible",children:n.children}),a.return=e,a.sibling=null,t!==null&&(r=e.deletions,r===null?(e.deletions=[t],e.flags|=16):r.push(t)),e.child=a,e.memoizedState=null,a)}function co(t,e){return e=au({mode:"visible",children:e},t.mode),e.return=t,t.child=e}function au(t,e){return t=Ee(22,t,null,e),t.lanes=0,t}function ro(t,e,a){return bn(e,t.child,null,a),t=co(e,e.pendingProps.children),t.flags|=2,e.memoizedState=null,t}function Cf(t,e,a){t.lanes|=e;var n=t.alternate;n!==null&&(n.lanes|=e),zs(t.return,e,a)}function fo(t,e,a,n,l,i){var r=t.memoizedState;r===null?t.memoizedState={isBackwards:e,rendering:null,renderingStartTime:0,last:n,tail:a,tailMode:l,treeForkCount:i}:(r.isBackwards=e,r.rendering=null,r.renderingStartTime=0,r.last=n,r.tail=a,r.tailMode=l,r.treeForkCount=i)}function Mf(t,e,a){var n=e.pendingProps,l=n.revealOrder,i=n.tail;n=n.children;var r=qt.current,h=(r&2)!==0;if(h?(r=r&1|2,e.flags|=128):r&=1,j(qt,r),It(t,e,n,a),n=dt?Ul:0,!h&&t!==null&&(t.flags&128)!==0)t:for(t=e.child;t!==null;){if(t.tag===13)t.memoizedState!==null&&Cf(t,a,e);else if(t.tag===19)Cf(t,a,e);else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===e)break t;for(;t.sibling===null;){if(t.return===null||t.return===e)break t;t=t.return}t.sibling.return=t.return,t=t.sibling}switch(l){case"forwards":for(a=e.child,l=null;a!==null;)t=a.alternate,t!==null&&Xi(t)===null&&(l=a),a=a.sibling;a=l,a===null?(l=e.child,e.child=null):(l=a.sibling,a.sibling=null),fo(e,!1,l,a,i,n);break;case"backwards":case"unstable_legacy-backwards":for(a=null,l=e.child,e.child=null;l!==null;){if(t=l.alternate,t!==null&&Xi(t)===null){e.child=l;break}t=l.sibling,l.sibling=a,a=l,l=t}fo(e,!0,a,null,i,n);break;case"together":fo(e,!1,null,null,void 0,n);break;default:e.memoizedState=null}return e.child}function ya(t,e,a){if(t!==null&&(e.dependencies=t.dependencies),Qa|=e.lanes,(a&e.childLanes)===0)if(t!==null){if(kn(t,e,a,!1),(a&e.childLanes)===0)return null}else return null;if(t!==null&&e.child!==t.child)throw Error(o(153));if(e.child!==null){for(t=e.child,a=fa(t,t.pendingProps),e.child=a,a.return=e;t.sibling!==null;)t=t.sibling,a=a.sibling=fa(t,t.pendingProps),a.return=e;a.sibling=null}return e.child}function ho(t,e){return(t.lanes&e)!==0?!0:(t=t.dependencies,!!(t!==null&&Li(t)))}function gm(t,e,a){switch(e.tag){case 3:bt(e,e.stateNode.containerInfo),Ba(e,Vt,t.memoizedState.cache),hn();break;case 27:case 5:Da(e);break;case 4:bt(e,e.stateNode.containerInfo);break;case 10:Ba(e,e.type,e.memoizedProps.value);break;case 31:if(e.memoizedState!==null)return e.flags|=128,js(e),null;break;case 13:var n=e.memoizedState;if(n!==null)return n.dehydrated!==null?(qa(e),e.flags|=128,null):(a&e.child.childLanes)!==0?Nf(t,e,a):(qa(e),t=ya(t,e,a),t!==null?t.sibling:null);qa(e);break;case 19:var l=(t.flags&128)!==0;if(n=(a&e.childLanes)!==0,n||(kn(t,e,a,!1),n=(a&e.childLanes)!==0),l){if(n)return Mf(t,e,a);e.flags|=128}if(l=e.memoizedState,l!==null&&(l.rendering=null,l.tail=null,l.lastEffect=null),j(qt,qt.current),n)break;return null;case 22:return e.lanes=0,Tf(t,e,a,e.pendingProps);case 24:Ba(e,Vt,t.memoizedState.cache)}return ya(t,e,a)}function _f(t,e,a){if(t!==null)if(t.memoizedProps!==e.pendingProps)Qt=!0;else{if(!ho(t,a)&&(e.flags&128)===0)return Qt=!1,gm(t,e,a);Qt=(t.flags&131072)!==0}else Qt=!1,dt&&(e.flags&1048576)!==0&&or(e,Ul,e.index);switch(e.lanes=0,e.tag){case 16:t:{var n=e.pendingProps;if(t=yn(e.elementType),e.type=t,typeof t=="function")ys(t)?(n=xn(t,n),e.tag=1,e=Df(null,e,t,n,a)):(e.tag=0,e=io(null,e,t,n,a));else{if(t!=null){var l=t.$$typeof;if(l===ht){e.tag=11,e=bf(null,e,t,n,a);break t}else if(l===Tt){e.tag=14,e=Sf(null,e,t,n,a);break t}}throw e=W(t)||t,Error(o(306,e,""))}}return e;case 0:return io(t,e,e.type,e.pendingProps,a);case 1:return n=e.type,l=xn(n,e.pendingProps),Df(t,e,n,l,a);case 3:t:{if(bt(e,e.stateNode.containerInfo),t===null)throw Error(o(387));n=e.pendingProps;var i=e.memoizedState;l=i.element,Rs(t,e),Vl(e,n,null,a);var r=e.memoizedState;if(n=r.cache,Ba(e,Vt,n),n!==i.cache&&Ds(e,[Vt],a,!0),Yl(),n=r.element,i.isDehydrated)if(i={element:n,isDehydrated:!1,cache:r.cache},e.updateQueue.baseState=i,e.memoizedState=i,e.flags&256){e=Af(t,e,n,a);break t}else if(n!==l){l=we(Error(o(424)),e),wl(l),e=Af(t,e,n,a);break t}else{switch(t=e.stateNode.containerInfo,t.nodeType){case 9:t=t.body;break;default:t=t.nodeName==="HTML"?t.ownerDocument.body:t}for(_t=qe(t.firstChild),$t=e,dt=!0,Ua=null,je=!0,a=xr(e,null,n,a),e.child=a;a;)a.flags=a.flags&-3|4096,a=a.sibling}else{if(hn(),n===l){e=ya(t,e,a);break t}It(t,e,n,a)}e=e.child}return e;case 26:return eu(t,e),t===null?(a=Gd(e.type,null,e.pendingProps,null))?e.memoizedState=a:dt||(a=e.type,t=e.pendingProps,n=vu(Ht.current).createElement(a),n[Ft]=e,n[de]=t,Pt(n,a,t),kt(n),e.stateNode=n):e.memoizedState=Gd(e.type,t.memoizedProps,e.pendingProps,t.memoizedState),null;case 27:return Da(e),t===null&&dt&&(n=e.stateNode=qd(e.type,e.pendingProps,Ht.current),$t=e,je=!0,l=_t,Ja(e.type)?(Zo=l,_t=qe(n.firstChild)):_t=l),It(t,e,e.pendingProps.children,a),eu(t,e),t===null&&(e.flags|=4194304),e.child;case 5:return t===null&&dt&&((l=n=_t)&&(n=Xm(n,e.type,e.pendingProps,je),n!==null?(e.stateNode=n,$t=e,_t=qe(n.firstChild),je=!1,l=!0):l=!1),l||wa(e)),Da(e),l=e.type,i=e.pendingProps,r=t!==null?t.memoizedProps:null,n=i.children,Vo(l,i)?n=null:r!==null&&Vo(l,r)&&(e.flags|=32),e.memoizedState!==null&&(l=qs(t,e,im,null,null,a),si._currentValue=l),eu(t,e),It(t,e,n,a),e.child;case 6:return t===null&&dt&&((t=a=_t)&&(a=Km(a,e.pendingProps,je),a!==null?(e.stateNode=a,$t=e,_t=null,t=!0):t=!1),t||wa(e)),null;case 13:return Nf(t,e,a);case 4:return bt(e,e.stateNode.containerInfo),n=e.pendingProps,t===null?e.child=bn(e,null,n,a):It(t,e,n,a),e.child;case 11:return bf(t,e,e.type,e.pendingProps,a);case 7:return It(t,e,e.pendingProps,a),e.child;case 8:return It(t,e,e.pendingProps.children,a),e.child;case 12:return It(t,e,e.pendingProps.children,a),e.child;case 10:return n=e.pendingProps,Ba(e,e.type,n.value),It(t,e,n.children,a),e.child;case 9:return l=e.type._context,n=e.pendingProps.children,mn(e),l=Wt(l),n=n(l),e.flags|=1,It(t,e,n,a),e.child;case 14:return Sf(t,e,e.type,e.pendingProps,a);case 15:return xf(t,e,e.type,e.pendingProps,a);case 19:return Mf(t,e,a);case 31:return hm(t,e,a);case 22:return Tf(t,e,a,e.pendingProps);case 24:return mn(e),n=Wt(Vt),t===null?(l=Cs(),l===null&&(l=Mt,i=As(),l.pooledCache=i,i.refCount++,i!==null&&(l.pooledCacheLanes|=a),l=i),e.memoizedState={parent:n,cache:l},_s(e),Ba(e,Vt,l)):((t.lanes&a)!==0&&(Rs(t,e),Vl(e,null,null,a),Yl()),l=t.memoizedState,i=e.memoizedState,l.parent!==n?(l={parent:n,cache:n},e.memoizedState=l,e.lanes===0&&(e.memoizedState=e.updateQueue.baseState=l),Ba(e,Vt,n)):(n=i.cache,Ba(e,Vt,n),n!==l.cache&&Ds(e,[Vt],a,!0))),It(t,e,e.pendingProps.children,a),e.child;case 29:throw e.pendingProps}throw Error(o(156,e.tag))}function va(t){t.flags|=4}function go(t,e,a,n,l){if((e=(t.mode&32)!==0)&&(e=!1),e){if(t.flags|=16777216,(l&335544128)===l)if(t.stateNode.complete)t.flags|=8192;else if(ld())t.flags|=8192;else throw vn=Yi,Ms}else t.flags&=-16777217}function Rf(t,e){if(e.type!=="stylesheet"||(e.state.loading&4)!==0)t.flags&=-16777217;else if(t.flags|=16777216,!kd(e))if(ld())t.flags|=8192;else throw vn=Yi,Ms}function nu(t,e){e!==null&&(t.flags|=4),t.flags&16384&&(e=t.tag!==22?ee():536870912,t.lanes|=e,il|=e)}function kl(t,e){if(!dt)switch(t.tailMode){case"hidden":e=t.tail;for(var a=null;e!==null;)e.alternate!==null&&(a=e),e=e.sibling;a===null?t.tail=null:a.sibling=null;break;case"collapsed":a=t.tail;for(var n=null;a!==null;)a.alternate!==null&&(n=a),a=a.sibling;n===null?e||t.tail===null?t.tail=null:t.tail.sibling=null:n.sibling=null}}function Rt(t){var e=t.alternate!==null&&t.alternate.child===t.child,a=0,n=0;if(e)for(var l=t.child;l!==null;)a|=l.lanes|l.childLanes,n|=l.subtreeFlags&65011712,n|=l.flags&65011712,l.return=t,l=l.sibling;else for(l=t.child;l!==null;)a|=l.lanes|l.childLanes,n|=l.subtreeFlags,n|=l.flags,l.return=t,l=l.sibling;return t.subtreeFlags|=n,t.childLanes=a,e}function mm(t,e,a){var n=e.pendingProps;switch(xs(e),e.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Rt(e),null;case 1:return Rt(e),null;case 3:return a=e.stateNode,n=null,t!==null&&(n=t.memoizedState.cache),e.memoizedState.cache!==n&&(e.flags|=2048),ga(Vt),Se(),a.pendingContext&&(a.context=a.pendingContext,a.pendingContext=null),(t===null||t.child===null)&&(Zn(e)?va(e):t===null||t.memoizedState.isDehydrated&&(e.flags&256)===0||(e.flags|=1024,Es())),Rt(e),null;case 26:var l=e.type,i=e.memoizedState;return t===null?(va(e),i!==null?(Rt(e),Rf(e,i)):(Rt(e),go(e,l,null,n,a))):i?i!==t.memoizedState?(va(e),Rt(e),Rf(e,i)):(Rt(e),e.flags&=-16777217):(t=t.memoizedProps,t!==n&&va(e),Rt(e),go(e,l,t,n,a)),null;case 27:if(ua(e),a=Ht.current,l=e.type,t!==null&&e.stateNode!=null)t.memoizedProps!==n&&va(e);else{if(!n){if(e.stateNode===null)throw Error(o(166));return Rt(e),null}t=$.current,Zn(e)?rr(e):(t=qd(l,n,a),e.stateNode=t,va(e))}return Rt(e),null;case 5:if(ua(e),l=e.type,t!==null&&e.stateNode!=null)t.memoizedProps!==n&&va(e);else{if(!n){if(e.stateNode===null)throw Error(o(166));return Rt(e),null}if(i=$.current,Zn(e))rr(e);else{var r=vu(Ht.current);switch(i){case 1:i=r.createElementNS("http://www.w3.org/2000/svg",l);break;case 2:i=r.createElementNS("http://www.w3.org/1998/Math/MathML",l);break;default:switch(l){case"svg":i=r.createElementNS("http://www.w3.org/2000/svg",l);break;case"math":i=r.createElementNS("http://www.w3.org/1998/Math/MathML",l);break;case"script":i=r.createElement("div"),i.innerHTML="<script><\/script>",i=i.removeChild(i.firstChild);break;case"select":i=typeof n.is=="string"?r.createElement("select",{is:n.is}):r.createElement("select"),n.multiple?i.multiple=!0:n.size&&(i.size=n.size);break;default:i=typeof n.is=="string"?r.createElement(l,{is:n.is}):r.createElement(l)}}i[Ft]=e,i[de]=n;t:for(r=e.child;r!==null;){if(r.tag===5||r.tag===6)i.appendChild(r.stateNode);else if(r.tag!==4&&r.tag!==27&&r.child!==null){r.child.return=r,r=r.child;continue}if(r===e)break t;for(;r.sibling===null;){if(r.return===null||r.return===e)break t;r=r.return}r.sibling.return=r.return,r=r.sibling}e.stateNode=i;t:switch(Pt(i,l,n),l){case"button":case"input":case"select":case"textarea":n=!!n.autoFocus;break t;case"img":n=!0;break t;default:n=!1}n&&va(e)}}return Rt(e),go(e,e.type,t===null?null:t.memoizedProps,e.pendingProps,a),null;case 6:if(t&&e.stateNode!=null)t.memoizedProps!==n&&va(e);else{if(typeof n!="string"&&e.stateNode===null)throw Error(o(166));if(t=Ht.current,Zn(e)){if(t=e.stateNode,a=e.memoizedProps,n=null,l=$t,l!==null)switch(l.tag){case 27:case 5:n=l.memoizedProps}t[Ft]=e,t=!!(t.nodeValue===a||n!==null&&n.suppressHydrationWarning===!0||Nd(t.nodeValue,a)),t||wa(e,!0)}else t=vu(t).createTextNode(n),t[Ft]=e,e.stateNode=t}return Rt(e),null;case 31:if(a=e.memoizedState,t===null||t.memoizedState!==null){if(n=Zn(e),a!==null){if(t===null){if(!n)throw Error(o(318));if(t=e.memoizedState,t=t!==null?t.dehydrated:null,!t)throw Error(o(557));t[Ft]=e}else hn(),(e.flags&128)===0&&(e.memoizedState=null),e.flags|=4;Rt(e),t=!1}else a=Es(),t!==null&&t.memoizedState!==null&&(t.memoizedState.hydrationErrors=a),t=!0;if(!t)return e.flags&256?(ze(e),e):(ze(e),null);if((e.flags&128)!==0)throw Error(o(558))}return Rt(e),null;case 13:if(n=e.memoizedState,t===null||t.memoizedState!==null&&t.memoizedState.dehydrated!==null){if(l=Zn(e),n!==null&&n.dehydrated!==null){if(t===null){if(!l)throw Error(o(318));if(l=e.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(o(317));l[Ft]=e}else hn(),(e.flags&128)===0&&(e.memoizedState=null),e.flags|=4;Rt(e),l=!1}else l=Es(),t!==null&&t.memoizedState!==null&&(t.memoizedState.hydrationErrors=l),l=!0;if(!l)return e.flags&256?(ze(e),e):(ze(e),null)}return ze(e),(e.flags&128)!==0?(e.lanes=a,e):(a=n!==null,t=t!==null&&t.memoizedState!==null,a&&(n=e.child,l=null,n.alternate!==null&&n.alternate.memoizedState!==null&&n.alternate.memoizedState.cachePool!==null&&(l=n.alternate.memoizedState.cachePool.pool),i=null,n.memoizedState!==null&&n.memoizedState.cachePool!==null&&(i=n.memoizedState.cachePool.pool),i!==l&&(n.flags|=2048)),a!==t&&a&&(e.child.flags|=8192),nu(e,e.updateQueue),Rt(e),null);case 4:return Se(),t===null&&Lo(e.stateNode.containerInfo),Rt(e),null;case 10:return ga(e.type),Rt(e),null;case 19:if(st(qt),n=e.memoizedState,n===null)return Rt(e),null;if(l=(e.flags&128)!==0,i=n.rendering,i===null)if(l)kl(n,!1);else{if(jt!==0||t!==null&&(t.flags&128)!==0)for(t=e.child;t!==null;){if(i=Xi(t),i!==null){for(e.flags|=128,kl(n,!1),t=i.updateQueue,e.updateQueue=t,nu(e,t),e.subtreeFlags=0,t=a,a=e.child;a!==null;)ir(a,t),a=a.sibling;return j(qt,qt.current&1|2),dt&&da(e,n.treeForkCount),e.child}t=t.sibling}n.tail!==null&&le()>ou&&(e.flags|=128,l=!0,kl(n,!1),e.lanes=4194304)}else{if(!l)if(t=Xi(i),t!==null){if(e.flags|=128,l=!0,t=t.updateQueue,e.updateQueue=t,nu(e,t),kl(n,!0),n.tail===null&&n.tailMode==="hidden"&&!i.alternate&&!dt)return Rt(e),null}else 2*le()-n.renderingStartTime>ou&&a!==536870912&&(e.flags|=128,l=!0,kl(n,!1),e.lanes=4194304);n.isBackwards?(i.sibling=e.child,e.child=i):(t=n.last,t!==null?t.sibling=i:e.child=i,n.last=i)}return n.tail!==null?(t=n.tail,n.rendering=t,n.tail=t.sibling,n.renderingStartTime=le(),t.sibling=null,a=qt.current,j(qt,l?a&1|2:a&1),dt&&da(e,n.treeForkCount),t):(Rt(e),null);case 22:case 23:return ze(e),Ls(),n=e.memoizedState!==null,t!==null?t.memoizedState!==null!==n&&(e.flags|=8192):n&&(e.flags|=8192),n?(a&536870912)!==0&&(e.flags&128)===0&&(Rt(e),e.subtreeFlags&6&&(e.flags|=8192)):Rt(e),a=e.updateQueue,a!==null&&nu(e,a.retryQueue),a=null,t!==null&&t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(a=t.memoizedState.cachePool.pool),n=null,e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(n=e.memoizedState.cachePool.pool),n!==a&&(e.flags|=2048),t!==null&&st(pn),null;case 24:return a=null,t!==null&&(a=t.memoizedState.cache),e.memoizedState.cache!==a&&(e.flags|=2048),ga(Vt),Rt(e),null;case 25:return null;case 30:return null}throw Error(o(156,e.tag))}function pm(t,e){switch(xs(e),e.tag){case 1:return t=e.flags,t&65536?(e.flags=t&-65537|128,e):null;case 3:return ga(Vt),Se(),t=e.flags,(t&65536)!==0&&(t&128)===0?(e.flags=t&-65537|128,e):null;case 26:case 27:case 5:return ua(e),null;case 31:if(e.memoizedState!==null){if(ze(e),e.alternate===null)throw Error(o(340));hn()}return t=e.flags,t&65536?(e.flags=t&-65537|128,e):null;case 13:if(ze(e),t=e.memoizedState,t!==null&&t.dehydrated!==null){if(e.alternate===null)throw Error(o(340));hn()}return t=e.flags,t&65536?(e.flags=t&-65537|128,e):null;case 19:return st(qt),null;case 4:return Se(),null;case 10:return ga(e.type),null;case 22:case 23:return ze(e),Ls(),t!==null&&st(pn),t=e.flags,t&65536?(e.flags=t&-65537|128,e):null;case 24:return ga(Vt),null;case 25:return null;default:return null}}function Uf(t,e){switch(xs(e),e.tag){case 3:ga(Vt),Se();break;case 26:case 27:case 5:ua(e);break;case 4:Se();break;case 31:e.memoizedState!==null&&ze(e);break;case 13:ze(e);break;case 19:st(qt);break;case 10:ga(e.type);break;case 22:case 23:ze(e),Ls(),t!==null&&st(pn);break;case 24:ga(Vt)}}function Jl(t,e){try{var a=e.updateQueue,n=a!==null?a.lastEffect:null;if(n!==null){var l=n.next;a=l;do{if((a.tag&t)===t){n=void 0;var i=a.create,r=a.inst;n=i(),r.destroy=n}a=a.next}while(a!==l)}}catch(h){xt(e,e.return,h)}}function Va(t,e,a){try{var n=e.updateQueue,l=n!==null?n.lastEffect:null;if(l!==null){var i=l.next;n=i;do{if((n.tag&t)===t){var r=n.inst,h=r.destroy;if(h!==void 0){r.destroy=void 0,l=e;var y=a,O=h;try{O()}catch(A){xt(l,y,A)}}}n=n.next}while(n!==i)}}catch(A){xt(e,e.return,A)}}function wf(t){var e=t.updateQueue;if(e!==null){var a=t.stateNode;try{Er(e,a)}catch(n){xt(t,t.return,n)}}}function Bf(t,e,a){a.props=xn(t.type,t.memoizedProps),a.state=t.memoizedState;try{a.componentWillUnmount()}catch(n){xt(t,e,n)}}function Fl(t,e){try{var a=t.ref;if(a!==null){switch(t.tag){case 26:case 27:case 5:var n=t.stateNode;break;case 30:n=t.stateNode;break;default:n=t.stateNode}typeof a=="function"?t.refCleanup=a(n):a.current=n}}catch(l){xt(t,e,l)}}function ta(t,e){var a=t.ref,n=t.refCleanup;if(a!==null)if(typeof n=="function")try{n()}catch(l){xt(t,e,l)}finally{t.refCleanup=null,t=t.alternate,t!=null&&(t.refCleanup=null)}else if(typeof a=="function")try{a(null)}catch(l){xt(t,e,l)}else a.current=null}function Lf(t){var e=t.type,a=t.memoizedProps,n=t.stateNode;try{t:switch(e){case"button":case"input":case"select":case"textarea":a.autoFocus&&n.focus();break t;case"img":a.src?n.src=a.src:a.srcSet&&(n.srcset=a.srcSet)}}catch(l){xt(t,t.return,l)}}function mo(t,e,a){try{var n=t.stateNode;Hm(n,t.type,a,e),n[de]=e}catch(l){xt(t,t.return,l)}}function jf(t){return t.tag===5||t.tag===3||t.tag===26||t.tag===27&&Ja(t.type)||t.tag===4}function po(t){t:for(;;){for(;t.sibling===null;){if(t.return===null||jf(t.return))return null;t=t.return}for(t.sibling.return=t.return,t=t.sibling;t.tag!==5&&t.tag!==6&&t.tag!==18;){if(t.tag===27&&Ja(t.type)||t.flags&2||t.child===null||t.tag===4)continue t;t.child.return=t,t=t.child}if(!(t.flags&2))return t.stateNode}}function yo(t,e,a){var n=t.tag;if(n===5||n===6)t=t.stateNode,e?(a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a).insertBefore(t,e):(e=a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a,e.appendChild(t),a=a._reactRootContainer,a!=null||e.onclick!==null||(e.onclick=ca));else if(n!==4&&(n===27&&Ja(t.type)&&(a=t.stateNode,e=null),t=t.child,t!==null))for(yo(t,e,a),t=t.sibling;t!==null;)yo(t,e,a),t=t.sibling}function lu(t,e,a){var n=t.tag;if(n===5||n===6)t=t.stateNode,e?a.insertBefore(t,e):a.appendChild(t);else if(n!==4&&(n===27&&Ja(t.type)&&(a=t.stateNode),t=t.child,t!==null))for(lu(t,e,a),t=t.sibling;t!==null;)lu(t,e,a),t=t.sibling}function Hf(t){var e=t.stateNode,a=t.memoizedProps;try{for(var n=t.type,l=e.attributes;l.length;)e.removeAttributeNode(l[0]);Pt(e,n,a),e[Ft]=t,e[de]=a}catch(i){xt(t,t.return,i)}}var ba=!1,Xt=!1,vo=!1,qf=typeof WeakSet=="function"?WeakSet:Set,Jt=null;function ym(t,e){if(t=t.containerInfo,qo=zu,t=$c(t),rs(t)){if("selectionStart"in t)var a={start:t.selectionStart,end:t.selectionEnd};else t:{a=(a=t.ownerDocument)&&a.defaultView||window;var n=a.getSelection&&a.getSelection();if(n&&n.rangeCount!==0){a=n.anchorNode;var l=n.anchorOffset,i=n.focusNode;n=n.focusOffset;try{a.nodeType,i.nodeType}catch{a=null;break t}var r=0,h=-1,y=-1,O=0,A=0,_=t,z=null;e:for(;;){for(var D;_!==a||l!==0&&_.nodeType!==3||(h=r+l),_!==i||n!==0&&_.nodeType!==3||(y=r+n),_.nodeType===3&&(r+=_.nodeValue.length),(D=_.firstChild)!==null;)z=_,_=D;for(;;){if(_===t)break e;if(z===a&&++O===l&&(h=r),z===i&&++A===n&&(y=r),(D=_.nextSibling)!==null)break;_=z,z=_.parentNode}_=D}a=h===-1||y===-1?null:{start:h,end:y}}else a=null}a=a||{start:0,end:0}}else a=null;for(Yo={focusedElem:t,selectionRange:a},zu=!1,Jt=e;Jt!==null;)if(e=Jt,t=e.child,(e.subtreeFlags&1028)!==0&&t!==null)t.return=e,Jt=t;else for(;Jt!==null;){switch(e=Jt,i=e.alternate,t=e.flags,e.tag){case 0:if((t&4)!==0&&(t=e.updateQueue,t=t!==null?t.events:null,t!==null))for(a=0;a<t.length;a++)l=t[a],l.ref.impl=l.nextImpl;break;case 11:case 15:break;case 1:if((t&1024)!==0&&i!==null){t=void 0,a=e,l=i.memoizedProps,i=i.memoizedState,n=a.stateNode;try{var H=xn(a.type,l);t=n.getSnapshotBeforeUpdate(H,i),n.__reactInternalSnapshotBeforeUpdate=t}catch(X){xt(a,a.return,X)}}break;case 3:if((t&1024)!==0){if(t=e.stateNode.containerInfo,a=t.nodeType,a===9)Qo(t);else if(a===1)switch(t.nodeName){case"HEAD":case"HTML":case"BODY":Qo(t);break;default:t.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((t&1024)!==0)throw Error(o(163))}if(t=e.sibling,t!==null){t.return=e.return,Jt=t;break}Jt=e.return}}function Yf(t,e,a){var n=a.flags;switch(a.tag){case 0:case 11:case 15:xa(t,a),n&4&&Jl(5,a);break;case 1:if(xa(t,a),n&4)if(t=a.stateNode,e===null)try{t.componentDidMount()}catch(r){xt(a,a.return,r)}else{var l=xn(a.type,e.memoizedProps);e=e.memoizedState;try{t.componentDidUpdate(l,e,t.__reactInternalSnapshotBeforeUpdate)}catch(r){xt(a,a.return,r)}}n&64&&wf(a),n&512&&Fl(a,a.return);break;case 3:if(xa(t,a),n&64&&(t=a.updateQueue,t!==null)){if(e=null,a.child!==null)switch(a.child.tag){case 27:case 5:e=a.child.stateNode;break;case 1:e=a.child.stateNode}try{Er(t,e)}catch(r){xt(a,a.return,r)}}break;case 27:e===null&&n&4&&Hf(a);case 26:case 5:xa(t,a),e===null&&n&4&&Lf(a),n&512&&Fl(a,a.return);break;case 12:xa(t,a);break;case 31:xa(t,a),n&4&&Qf(t,a);break;case 13:xa(t,a),n&4&&Xf(t,a),n&64&&(t=a.memoizedState,t!==null&&(t=t.dehydrated,t!==null&&(a=Dm.bind(null,a),Zm(t,a))));break;case 22:if(n=a.memoizedState!==null||ba,!n){e=e!==null&&e.memoizedState!==null||Xt,l=ba;var i=Xt;ba=n,(Xt=e)&&!i?Ta(t,a,(a.subtreeFlags&8772)!==0):xa(t,a),ba=l,Xt=i}break;case 30:break;default:xa(t,a)}}function Vf(t){var e=t.alternate;e!==null&&(t.alternate=null,Vf(e)),t.child=null,t.deletions=null,t.sibling=null,t.tag===5&&(e=t.stateNode,e!==null&&ku(e)),t.stateNode=null,t.return=null,t.dependencies=null,t.memoizedProps=null,t.memoizedState=null,t.pendingProps=null,t.stateNode=null,t.updateQueue=null}var wt=null,ge=!1;function Sa(t,e,a){for(a=a.child;a!==null;)Gf(t,e,a),a=a.sibling}function Gf(t,e,a){if(ie&&typeof ie.onCommitFiberUnmount=="function")try{ie.onCommitFiberUnmount(nn,a)}catch{}switch(a.tag){case 26:Xt||ta(a,e),Sa(t,e,a),a.memoizedState?a.memoizedState.count--:a.stateNode&&(a=a.stateNode,a.parentNode.removeChild(a));break;case 27:Xt||ta(a,e);var n=wt,l=ge;Ja(a.type)&&(wt=a.stateNode,ge=!1),Sa(t,e,a),li(a.stateNode),wt=n,ge=l;break;case 5:Xt||ta(a,e);case 6:if(n=wt,l=ge,wt=null,Sa(t,e,a),wt=n,ge=l,wt!==null)if(ge)try{(wt.nodeType===9?wt.body:wt.nodeName==="HTML"?wt.ownerDocument.body:wt).removeChild(a.stateNode)}catch(i){xt(a,e,i)}else try{wt.removeChild(a.stateNode)}catch(i){xt(a,e,i)}break;case 18:wt!==null&&(ge?(t=wt,wd(t.nodeType===9?t.body:t.nodeName==="HTML"?t.ownerDocument.body:t,a.stateNode),hl(t)):wd(wt,a.stateNode));break;case 4:n=wt,l=ge,wt=a.stateNode.containerInfo,ge=!0,Sa(t,e,a),wt=n,ge=l;break;case 0:case 11:case 14:case 15:Va(2,a,e),Xt||Va(4,a,e),Sa(t,e,a);break;case 1:Xt||(ta(a,e),n=a.stateNode,typeof n.componentWillUnmount=="function"&&Bf(a,e,n)),Sa(t,e,a);break;case 21:Sa(t,e,a);break;case 22:Xt=(n=Xt)||a.memoizedState!==null,Sa(t,e,a),Xt=n;break;default:Sa(t,e,a)}}function Qf(t,e){if(e.memoizedState===null&&(t=e.alternate,t!==null&&(t=t.memoizedState,t!==null))){t=t.dehydrated;try{hl(t)}catch(a){xt(e,e.return,a)}}}function Xf(t,e){if(e.memoizedState===null&&(t=e.alternate,t!==null&&(t=t.memoizedState,t!==null&&(t=t.dehydrated,t!==null))))try{hl(t)}catch(a){xt(e,e.return,a)}}function vm(t){switch(t.tag){case 31:case 13:case 19:var e=t.stateNode;return e===null&&(e=t.stateNode=new qf),e;case 22:return t=t.stateNode,e=t._retryCache,e===null&&(e=t._retryCache=new qf),e;default:throw Error(o(435,t.tag))}}function iu(t,e){var a=vm(t);e.forEach(function(n){if(!a.has(n)){a.add(n);var l=Am.bind(null,t,n);n.then(l,l)}})}function me(t,e){var a=e.deletions;if(a!==null)for(var n=0;n<a.length;n++){var l=a[n],i=t,r=e,h=r;t:for(;h!==null;){switch(h.tag){case 27:if(Ja(h.type)){wt=h.stateNode,ge=!1;break t}break;case 5:wt=h.stateNode,ge=!1;break t;case 3:case 4:wt=h.stateNode.containerInfo,ge=!0;break t}h=h.return}if(wt===null)throw Error(o(160));Gf(i,r,l),wt=null,ge=!1,i=l.alternate,i!==null&&(i.return=null),l.return=null}if(e.subtreeFlags&13886)for(e=e.child;e!==null;)Kf(e,t),e=e.sibling}var ke=null;function Kf(t,e){var a=t.alternate,n=t.flags;switch(t.tag){case 0:case 11:case 14:case 15:me(e,t),pe(t),n&4&&(Va(3,t,t.return),Jl(3,t),Va(5,t,t.return));break;case 1:me(e,t),pe(t),n&512&&(Xt||a===null||ta(a,a.return)),n&64&&ba&&(t=t.updateQueue,t!==null&&(n=t.callbacks,n!==null&&(a=t.shared.hiddenCallbacks,t.shared.hiddenCallbacks=a===null?n:a.concat(n))));break;case 26:var l=ke;if(me(e,t),pe(t),n&512&&(Xt||a===null||ta(a,a.return)),n&4){var i=a!==null?a.memoizedState:null;if(n=t.memoizedState,a===null)if(n===null)if(t.stateNode===null){t:{n=t.type,a=t.memoizedProps,l=l.ownerDocument||l;e:switch(n){case"title":i=l.getElementsByTagName("title")[0],(!i||i[Tl]||i[Ft]||i.namespaceURI==="http://www.w3.org/2000/svg"||i.hasAttribute("itemprop"))&&(i=l.createElement(n),l.head.insertBefore(i,l.querySelector("head > title"))),Pt(i,n,a),i[Ft]=t,kt(i),n=i;break t;case"link":var r=Kd("link","href",l).get(n+(a.href||""));if(r){for(var h=0;h<r.length;h++)if(i=r[h],i.getAttribute("href")===(a.href==null||a.href===""?null:a.href)&&i.getAttribute("rel")===(a.rel==null?null:a.rel)&&i.getAttribute("title")===(a.title==null?null:a.title)&&i.getAttribute("crossorigin")===(a.crossOrigin==null?null:a.crossOrigin)){r.splice(h,1);break e}}i=l.createElement(n),Pt(i,n,a),l.head.appendChild(i);break;case"meta":if(r=Kd("meta","content",l).get(n+(a.content||""))){for(h=0;h<r.length;h++)if(i=r[h],i.getAttribute("content")===(a.content==null?null:""+a.content)&&i.getAttribute("name")===(a.name==null?null:a.name)&&i.getAttribute("property")===(a.property==null?null:a.property)&&i.getAttribute("http-equiv")===(a.httpEquiv==null?null:a.httpEquiv)&&i.getAttribute("charset")===(a.charSet==null?null:a.charSet)){r.splice(h,1);break e}}i=l.createElement(n),Pt(i,n,a),l.head.appendChild(i);break;default:throw Error(o(468,n))}i[Ft]=t,kt(i),n=i}t.stateNode=n}else Zd(l,t.type,t.stateNode);else t.stateNode=Xd(l,n,t.memoizedProps);else i!==n?(i===null?a.stateNode!==null&&(a=a.stateNode,a.parentNode.removeChild(a)):i.count--,n===null?Zd(l,t.type,t.stateNode):Xd(l,n,t.memoizedProps)):n===null&&t.stateNode!==null&&mo(t,t.memoizedProps,a.memoizedProps)}break;case 27:me(e,t),pe(t),n&512&&(Xt||a===null||ta(a,a.return)),a!==null&&n&4&&mo(t,t.memoizedProps,a.memoizedProps);break;case 5:if(me(e,t),pe(t),n&512&&(Xt||a===null||ta(a,a.return)),t.flags&32){l=t.stateNode;try{Ln(l,"")}catch(H){xt(t,t.return,H)}}n&4&&t.stateNode!=null&&(l=t.memoizedProps,mo(t,l,a!==null?a.memoizedProps:l)),n&1024&&(vo=!0);break;case 6:if(me(e,t),pe(t),n&4){if(t.stateNode===null)throw Error(o(162));n=t.memoizedProps,a=t.stateNode;try{a.nodeValue=n}catch(H){xt(t,t.return,H)}}break;case 3:if(xu=null,l=ke,ke=bu(e.containerInfo),me(e,t),ke=l,pe(t),n&4&&a!==null&&a.memoizedState.isDehydrated)try{hl(e.containerInfo)}catch(H){xt(t,t.return,H)}vo&&(vo=!1,Zf(t));break;case 4:n=ke,ke=bu(t.stateNode.containerInfo),me(e,t),pe(t),ke=n;break;case 12:me(e,t),pe(t);break;case 31:me(e,t),pe(t),n&4&&(n=t.updateQueue,n!==null&&(t.updateQueue=null,iu(t,n)));break;case 13:me(e,t),pe(t),t.child.flags&8192&&t.memoizedState!==null!=(a!==null&&a.memoizedState!==null)&&(su=le()),n&4&&(n=t.updateQueue,n!==null&&(t.updateQueue=null,iu(t,n)));break;case 22:l=t.memoizedState!==null;var y=a!==null&&a.memoizedState!==null,O=ba,A=Xt;if(ba=O||l,Xt=A||y,me(e,t),Xt=A,ba=O,pe(t),n&8192)t:for(e=t.stateNode,e._visibility=l?e._visibility&-2:e._visibility|1,l&&(a===null||y||ba||Xt||Tn(t)),a=null,e=t;;){if(e.tag===5||e.tag===26){if(a===null){y=a=e;try{if(i=y.stateNode,l)r=i.style,typeof r.setProperty=="function"?r.setProperty("display","none","important"):r.display="none";else{h=y.stateNode;var _=y.memoizedProps.style,z=_!=null&&_.hasOwnProperty("display")?_.display:null;h.style.display=z==null||typeof z=="boolean"?"":(""+z).trim()}}catch(H){xt(y,y.return,H)}}}else if(e.tag===6){if(a===null){y=e;try{y.stateNode.nodeValue=l?"":y.memoizedProps}catch(H){xt(y,y.return,H)}}}else if(e.tag===18){if(a===null){y=e;try{var D=y.stateNode;l?Bd(D,!0):Bd(y.stateNode,!1)}catch(H){xt(y,y.return,H)}}}else if((e.tag!==22&&e.tag!==23||e.memoizedState===null||e===t)&&e.child!==null){e.child.return=e,e=e.child;continue}if(e===t)break t;for(;e.sibling===null;){if(e.return===null||e.return===t)break t;a===e&&(a=null),e=e.return}a===e&&(a=null),e.sibling.return=e.return,e=e.sibling}n&4&&(n=t.updateQueue,n!==null&&(a=n.retryQueue,a!==null&&(n.retryQueue=null,iu(t,a))));break;case 19:me(e,t),pe(t),n&4&&(n=t.updateQueue,n!==null&&(t.updateQueue=null,iu(t,n)));break;case 30:break;case 21:break;default:me(e,t),pe(t)}}function pe(t){var e=t.flags;if(e&2){try{for(var a,n=t.return;n!==null;){if(jf(n)){a=n;break}n=n.return}if(a==null)throw Error(o(160));switch(a.tag){case 27:var l=a.stateNode,i=po(t);lu(t,i,l);break;case 5:var r=a.stateNode;a.flags&32&&(Ln(r,""),a.flags&=-33);var h=po(t);lu(t,h,r);break;case 3:case 4:var y=a.stateNode.containerInfo,O=po(t);yo(t,O,y);break;default:throw Error(o(161))}}catch(A){xt(t,t.return,A)}t.flags&=-3}e&4096&&(t.flags&=-4097)}function Zf(t){if(t.subtreeFlags&1024)for(t=t.child;t!==null;){var e=t;Zf(e),e.tag===5&&e.flags&1024&&e.stateNode.reset(),t=t.sibling}}function xa(t,e){if(e.subtreeFlags&8772)for(e=e.child;e!==null;)Yf(t,e.alternate,e),e=e.sibling}function Tn(t){for(t=t.child;t!==null;){var e=t;switch(e.tag){case 0:case 11:case 14:case 15:Va(4,e,e.return),Tn(e);break;case 1:ta(e,e.return);var a=e.stateNode;typeof a.componentWillUnmount=="function"&&Bf(e,e.return,a),Tn(e);break;case 27:li(e.stateNode);case 26:case 5:ta(e,e.return),Tn(e);break;case 22:e.memoizedState===null&&Tn(e);break;case 30:Tn(e);break;default:Tn(e)}t=t.sibling}}function Ta(t,e,a){for(a=a&&(e.subtreeFlags&8772)!==0,e=e.child;e!==null;){var n=e.alternate,l=t,i=e,r=i.flags;switch(i.tag){case 0:case 11:case 15:Ta(l,i,a),Jl(4,i);break;case 1:if(Ta(l,i,a),n=i,l=n.stateNode,typeof l.componentDidMount=="function")try{l.componentDidMount()}catch(O){xt(n,n.return,O)}if(n=i,l=n.updateQueue,l!==null){var h=n.stateNode;try{var y=l.shared.hiddenCallbacks;if(y!==null)for(l.shared.hiddenCallbacks=null,l=0;l<y.length;l++)Tr(y[l],h)}catch(O){xt(n,n.return,O)}}a&&r&64&&wf(i),Fl(i,i.return);break;case 27:Hf(i);case 26:case 5:Ta(l,i,a),a&&n===null&&r&4&&Lf(i),Fl(i,i.return);break;case 12:Ta(l,i,a);break;case 31:Ta(l,i,a),a&&r&4&&Qf(l,i);break;case 13:Ta(l,i,a),a&&r&4&&Xf(l,i);break;case 22:i.memoizedState===null&&Ta(l,i,a),Fl(i,i.return);break;case 30:break;default:Ta(l,i,a)}e=e.sibling}}function bo(t,e){var a=null;t!==null&&t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(a=t.memoizedState.cachePool.pool),t=null,e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(t=e.memoizedState.cachePool.pool),t!==a&&(t!=null&&t.refCount++,a!=null&&Bl(a))}function So(t,e){t=null,e.alternate!==null&&(t=e.alternate.memoizedState.cache),e=e.memoizedState.cache,e!==t&&(e.refCount++,t!=null&&Bl(t))}function Je(t,e,a,n){if(e.subtreeFlags&10256)for(e=e.child;e!==null;)kf(t,e,a,n),e=e.sibling}function kf(t,e,a,n){var l=e.flags;switch(e.tag){case 0:case 11:case 15:Je(t,e,a,n),l&2048&&Jl(9,e);break;case 1:Je(t,e,a,n);break;case 3:Je(t,e,a,n),l&2048&&(t=null,e.alternate!==null&&(t=e.alternate.memoizedState.cache),e=e.memoizedState.cache,e!==t&&(e.refCount++,t!=null&&Bl(t)));break;case 12:if(l&2048){Je(t,e,a,n),t=e.stateNode;try{var i=e.memoizedProps,r=i.id,h=i.onPostCommit;typeof h=="function"&&h(r,e.alternate===null?"mount":"update",t.passiveEffectDuration,-0)}catch(y){xt(e,e.return,y)}}else Je(t,e,a,n);break;case 31:Je(t,e,a,n);break;case 13:Je(t,e,a,n);break;case 23:break;case 22:i=e.stateNode,r=e.alternate,e.memoizedState!==null?i._visibility&2?Je(t,e,a,n):$l(t,e):i._visibility&2?Je(t,e,a,n):(i._visibility|=2,al(t,e,a,n,(e.subtreeFlags&10256)!==0||!1)),l&2048&&bo(r,e);break;case 24:Je(t,e,a,n),l&2048&&So(e.alternate,e);break;default:Je(t,e,a,n)}}function al(t,e,a,n,l){for(l=l&&((e.subtreeFlags&10256)!==0||!1),e=e.child;e!==null;){var i=t,r=e,h=a,y=n,O=r.flags;switch(r.tag){case 0:case 11:case 15:al(i,r,h,y,l),Jl(8,r);break;case 23:break;case 22:var A=r.stateNode;r.memoizedState!==null?A._visibility&2?al(i,r,h,y,l):$l(i,r):(A._visibility|=2,al(i,r,h,y,l)),l&&O&2048&&bo(r.alternate,r);break;case 24:al(i,r,h,y,l),l&&O&2048&&So(r.alternate,r);break;default:al(i,r,h,y,l)}e=e.sibling}}function $l(t,e){if(e.subtreeFlags&10256)for(e=e.child;e!==null;){var a=t,n=e,l=n.flags;switch(n.tag){case 22:$l(a,n),l&2048&&bo(n.alternate,n);break;case 24:$l(a,n),l&2048&&So(n.alternate,n);break;default:$l(a,n)}e=e.sibling}}var Wl=8192;function nl(t,e,a){if(t.subtreeFlags&Wl)for(t=t.child;t!==null;)Jf(t,e,a),t=t.sibling}function Jf(t,e,a){switch(t.tag){case 26:nl(t,e,a),t.flags&Wl&&t.memoizedState!==null&&lp(a,ke,t.memoizedState,t.memoizedProps);break;case 5:nl(t,e,a);break;case 3:case 4:var n=ke;ke=bu(t.stateNode.containerInfo),nl(t,e,a),ke=n;break;case 22:t.memoizedState===null&&(n=t.alternate,n!==null&&n.memoizedState!==null?(n=Wl,Wl=16777216,nl(t,e,a),Wl=n):nl(t,e,a));break;default:nl(t,e,a)}}function Ff(t){var e=t.alternate;if(e!==null&&(t=e.child,t!==null)){e.child=null;do e=t.sibling,t.sibling=null,t=e;while(t!==null)}}function Il(t){var e=t.deletions;if((t.flags&16)!==0){if(e!==null)for(var a=0;a<e.length;a++){var n=e[a];Jt=n,Wf(n,t)}Ff(t)}if(t.subtreeFlags&10256)for(t=t.child;t!==null;)$f(t),t=t.sibling}function $f(t){switch(t.tag){case 0:case 11:case 15:Il(t),t.flags&2048&&Va(9,t,t.return);break;case 3:Il(t);break;case 12:Il(t);break;case 22:var e=t.stateNode;t.memoizedState!==null&&e._visibility&2&&(t.return===null||t.return.tag!==13)?(e._visibility&=-3,uu(t)):Il(t);break;default:Il(t)}}function uu(t){var e=t.deletions;if((t.flags&16)!==0){if(e!==null)for(var a=0;a<e.length;a++){var n=e[a];Jt=n,Wf(n,t)}Ff(t)}for(t=t.child;t!==null;){switch(e=t,e.tag){case 0:case 11:case 15:Va(8,e,e.return),uu(e);break;case 22:a=e.stateNode,a._visibility&2&&(a._visibility&=-3,uu(e));break;default:uu(e)}t=t.sibling}}function Wf(t,e){for(;Jt!==null;){var a=Jt;switch(a.tag){case 0:case 11:case 15:Va(8,a,e);break;case 23:case 22:if(a.memoizedState!==null&&a.memoizedState.cachePool!==null){var n=a.memoizedState.cachePool.pool;n!=null&&n.refCount++}break;case 24:Bl(a.memoizedState.cache)}if(n=a.child,n!==null)n.return=a,Jt=n;else t:for(a=t;Jt!==null;){n=Jt;var l=n.sibling,i=n.return;if(Vf(n),n===a){Jt=null;break t}if(l!==null){l.return=i,Jt=l;break t}Jt=i}}}var bm={getCacheForType:function(t){var e=Wt(Vt),a=e.data.get(t);return a===void 0&&(a=t(),e.data.set(t,a)),a},cacheSignal:function(){return Wt(Vt).controller.signal}},Sm=typeof WeakMap=="function"?WeakMap:Map,pt=0,Mt=null,lt=null,ct=0,St=0,De=null,Ga=!1,ll=!1,xo=!1,Ea=0,jt=0,Qa=0,En=0,To=0,Ae=0,il=0,Pl=null,ye=null,Eo=!1,su=0,If=0,ou=1/0,cu=null,Xa=null,Kt=0,Ka=null,ul=null,Oa=0,Oo=0,zo=null,Pf=null,ti=0,Do=null;function Ne(){return(pt&2)!==0&&ct!==0?ct&-ct:E.T!==null?Ro():Ku()}function td(){if(Ae===0)if((ct&536870912)===0||dt){var t=Nn;Nn<<=1,(Nn&3932160)===0&&(Nn=262144),Ae=t}else Ae=536870912;return t=Oe.current,t!==null&&(t.flags|=32),Ae}function ve(t,e,a){(t===Mt&&(St===2||St===9)||t.cancelPendingCommit!==null)&&(sl(t,0),Za(t,ct,Ae,!1)),Bt(t,a),((pt&2)===0||t!==Mt)&&(t===Mt&&((pt&2)===0&&(En|=a),jt===4&&Za(t,ct,Ae,!1)),ea(t))}function ed(t,e,a){if((pt&6)!==0)throw Error(o(327));var n=!a&&(e&127)===0&&(e&t.expiredLanes)===0||Ut(t,e),l=n?Em(t,e):No(t,e,!0),i=n;do{if(l===0){ll&&!n&&Za(t,e,0,!1);break}else{if(a=t.current.alternate,i&&!xm(a)){l=No(t,e,!1),i=!1;continue}if(l===2){if(i=e,t.errorRecoveryDisabledLanes&i)var r=0;else r=t.pendingLanes&-536870913,r=r!==0?r:r&536870912?536870912:0;if(r!==0){e=r;t:{var h=t;l=Pl;var y=h.current.memoizedState.isDehydrated;if(y&&(sl(h,r).flags|=256),r=No(h,r,!1),r!==2){if(xo&&!y){h.errorRecoveryDisabledLanes|=i,En|=i,l=4;break t}i=ye,ye=l,i!==null&&(ye===null?ye=i:ye.push.apply(ye,i))}l=r}if(i=!1,l!==2)continue}}if(l===1){sl(t,0),Za(t,e,0,!0);break}t:{switch(n=t,i=l,i){case 0:case 1:throw Error(o(345));case 4:if((e&4194048)!==e)break;case 6:Za(n,e,Ae,!Ga);break t;case 2:ye=null;break;case 3:case 5:break;default:throw Error(o(329))}if((e&62914560)===e&&(l=su+300-le(),10<l)){if(Za(n,e,Ae,!Ga),J(n,0,!0)!==0)break t;Oa=e,n.timeoutHandle=Rd(ad.bind(null,n,a,ye,cu,Eo,e,Ae,En,il,Ga,i,"Throttled",-0,0),l);break t}ad(n,a,ye,cu,Eo,e,Ae,En,il,Ga,i,null,-0,0)}}break}while(!0);ea(t)}function ad(t,e,a,n,l,i,r,h,y,O,A,_,z,D){if(t.timeoutHandle=-1,_=e.subtreeFlags,_&8192||(_&16785408)===16785408){_={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:ca},Jf(e,i,_);var H=(i&62914560)===i?su-le():(i&4194048)===i?If-le():0;if(H=ip(_,H),H!==null){Oa=i,t.cancelPendingCommit=H(rd.bind(null,t,e,i,a,n,l,r,h,y,A,_,null,z,D)),Za(t,i,r,!O);return}}rd(t,e,i,a,n,l,r,h,y)}function xm(t){for(var e=t;;){var a=e.tag;if((a===0||a===11||a===15)&&e.flags&16384&&(a=e.updateQueue,a!==null&&(a=a.stores,a!==null)))for(var n=0;n<a.length;n++){var l=a[n],i=l.getSnapshot;l=l.value;try{if(!Te(i(),l))return!1}catch{return!1}}if(a=e.child,e.subtreeFlags&16384&&a!==null)a.return=e,e=a;else{if(e===t)break;for(;e.sibling===null;){if(e.return===null||e.return===t)return!0;e=e.return}e.sibling.return=e.return,e=e.sibling}}return!0}function Za(t,e,a,n){e&=~To,e&=~En,t.suspendedLanes|=e,t.pingedLanes&=~e,n&&(t.warmLanes|=e),n=t.expirationTimes;for(var l=e;0<l;){var i=31-te(l),r=1<<i;n[i]=-1,l&=~r}a!==0&&un(t,a,e)}function ru(){return(pt&6)===0?(ei(0),!1):!0}function Ao(){if(lt!==null){if(St===0)var t=lt.return;else t=lt,ha=gn=null,Gs(t),Wn=null,jl=0,t=lt;for(;t!==null;)Uf(t.alternate,t),t=t.return;lt=null}}function sl(t,e){var a=t.timeoutHandle;a!==-1&&(t.timeoutHandle=-1,Vm(a)),a=t.cancelPendingCommit,a!==null&&(t.cancelPendingCommit=null,a()),Oa=0,Ao(),Mt=t,lt=a=fa(t.current,null),ct=e,St=0,De=null,Ga=!1,ll=Ut(t,e),xo=!1,il=Ae=To=En=Qa=jt=0,ye=Pl=null,Eo=!1,(e&8)!==0&&(e|=e&32);var n=t.entangledLanes;if(n!==0)for(t=t.entanglements,n&=e;0<n;){var l=31-te(n),i=1<<l;e|=t[l],n&=~i}return Ea=e,_i(),a}function nd(t,e){I=null,E.H=Kl,e===$n||e===qi?(e=vr(),St=3):e===Ms?(e=vr(),St=4):St=e===lo?8:e!==null&&typeof e=="object"&&typeof e.then=="function"?6:1,De=e,lt===null&&(jt=1,Pi(t,we(e,t.current)))}function ld(){var t=Oe.current;return t===null?!0:(ct&4194048)===ct?He===null:(ct&62914560)===ct||(ct&536870912)!==0?t===He:!1}function id(){var t=E.H;return E.H=Kl,t===null?Kl:t}function ud(){var t=E.A;return E.A=bm,t}function fu(){jt=4,Ga||(ct&4194048)!==ct&&Oe.current!==null||(ll=!0),(Qa&134217727)===0&&(En&134217727)===0||Mt===null||Za(Mt,ct,Ae,!1)}function No(t,e,a){var n=pt;pt|=2;var l=id(),i=ud();(Mt!==t||ct!==e)&&(cu=null,sl(t,e)),e=!1;var r=jt;t:do try{if(St!==0&&lt!==null){var h=lt,y=De;switch(St){case 8:Ao(),r=6;break t;case 3:case 2:case 9:case 6:Oe.current===null&&(e=!0);var O=St;if(St=0,De=null,ol(t,h,y,O),a&&ll){r=0;break t}break;default:O=St,St=0,De=null,ol(t,h,y,O)}}Tm(),r=jt;break}catch(A){nd(t,A)}while(!0);return e&&t.shellSuspendCounter++,ha=gn=null,pt=n,E.H=l,E.A=i,lt===null&&(Mt=null,ct=0,_i()),r}function Tm(){for(;lt!==null;)sd(lt)}function Em(t,e){var a=pt;pt|=2;var n=id(),l=ud();Mt!==t||ct!==e?(cu=null,ou=le()+500,sl(t,e)):ll=Ut(t,e);t:do try{if(St!==0&&lt!==null){e=lt;var i=De;e:switch(St){case 1:St=0,De=null,ol(t,e,i,1);break;case 2:case 9:if(pr(i)){St=0,De=null,od(e);break}e=function(){St!==2&&St!==9||Mt!==t||(St=7),ea(t)},i.then(e,e);break t;case 3:St=7;break t;case 4:St=5;break t;case 7:pr(i)?(St=0,De=null,od(e)):(St=0,De=null,ol(t,e,i,7));break;case 5:var r=null;switch(lt.tag){case 26:r=lt.memoizedState;case 5:case 27:var h=lt;if(r?kd(r):h.stateNode.complete){St=0,De=null;var y=h.sibling;if(y!==null)lt=y;else{var O=h.return;O!==null?(lt=O,du(O)):lt=null}break e}}St=0,De=null,ol(t,e,i,5);break;case 6:St=0,De=null,ol(t,e,i,6);break;case 8:Ao(),jt=6;break t;default:throw Error(o(462))}}Om();break}catch(A){nd(t,A)}while(!0);return ha=gn=null,E.H=n,E.A=l,pt=a,lt!==null?0:(Mt=null,ct=0,_i(),jt)}function Om(){for(;lt!==null&&!ne();)sd(lt)}function sd(t){var e=_f(t.alternate,t,Ea);t.memoizedProps=t.pendingProps,e===null?du(t):lt=e}function od(t){var e=t,a=e.alternate;switch(e.tag){case 15:case 0:e=zf(a,e,e.pendingProps,e.type,void 0,ct);break;case 11:e=zf(a,e,e.pendingProps,e.type.render,e.ref,ct);break;case 5:Gs(e);default:Uf(a,e),e=lt=ir(e,Ea),e=_f(a,e,Ea)}t.memoizedProps=t.pendingProps,e===null?du(t):lt=e}function ol(t,e,a,n){ha=gn=null,Gs(e),Wn=null,jl=0;var l=e.return;try{if(dm(t,l,e,a,ct)){jt=1,Pi(t,we(a,t.current)),lt=null;return}}catch(i){if(l!==null)throw lt=l,i;jt=1,Pi(t,we(a,t.current)),lt=null;return}e.flags&32768?(dt||n===1?t=!0:ll||(ct&536870912)!==0?t=!1:(Ga=t=!0,(n===2||n===9||n===3||n===6)&&(n=Oe.current,n!==null&&n.tag===13&&(n.flags|=16384))),cd(e,t)):du(e)}function du(t){var e=t;do{if((e.flags&32768)!==0){cd(e,Ga);return}t=e.return;var a=mm(e.alternate,e,Ea);if(a!==null){lt=a;return}if(e=e.sibling,e!==null){lt=e;return}lt=e=t}while(e!==null);jt===0&&(jt=5)}function cd(t,e){do{var a=pm(t.alternate,t);if(a!==null){a.flags&=32767,lt=a;return}if(a=t.return,a!==null&&(a.flags|=32768,a.subtreeFlags=0,a.deletions=null),!e&&(t=t.sibling,t!==null)){lt=t;return}lt=t=a}while(t!==null);jt=6,lt=null}function rd(t,e,a,n,l,i,r,h,y){t.cancelPendingCommit=null;do hu();while(Kt!==0);if((pt&6)!==0)throw Error(o(327));if(e!==null){if(e===t.current)throw Error(o(177));if(i=e.lanes|e.childLanes,i|=ms,ce(t,a,i,r,h,y),t===Mt&&(lt=Mt=null,ct=0),ul=e,Ka=t,Oa=a,Oo=i,zo=l,Pf=n,(e.subtreeFlags&10256)!==0||(e.flags&10256)!==0?(t.callbackNode=null,t.callbackPriority=0,Nm(an,function(){return md(),null})):(t.callbackNode=null,t.callbackPriority=0),n=(e.flags&13878)!==0,(e.subtreeFlags&13878)!==0||n){n=E.T,E.T=null,l=U.p,U.p=2,r=pt,pt|=4;try{ym(t,e,a)}finally{pt=r,U.p=l,E.T=n}}Kt=1,fd(),dd(),hd()}}function fd(){if(Kt===1){Kt=0;var t=Ka,e=ul,a=(e.flags&13878)!==0;if((e.subtreeFlags&13878)!==0||a){a=E.T,E.T=null;var n=U.p;U.p=2;var l=pt;pt|=4;try{Kf(e,t);var i=Yo,r=$c(t.containerInfo),h=i.focusedElem,y=i.selectionRange;if(r!==h&&h&&h.ownerDocument&&Fc(h.ownerDocument.documentElement,h)){if(y!==null&&rs(h)){var O=y.start,A=y.end;if(A===void 0&&(A=O),"selectionStart"in h)h.selectionStart=O,h.selectionEnd=Math.min(A,h.value.length);else{var _=h.ownerDocument||document,z=_&&_.defaultView||window;if(z.getSelection){var D=z.getSelection(),H=h.textContent.length,X=Math.min(y.start,H),zt=y.end===void 0?X:Math.min(y.end,H);!D.extend&&X>zt&&(r=zt,zt=X,X=r);var x=Jc(h,X),b=Jc(h,zt);if(x&&b&&(D.rangeCount!==1||D.anchorNode!==x.node||D.anchorOffset!==x.offset||D.focusNode!==b.node||D.focusOffset!==b.offset)){var T=_.createRange();T.setStart(x.node,x.offset),D.removeAllRanges(),X>zt?(D.addRange(T),D.extend(b.node,b.offset)):(T.setEnd(b.node,b.offset),D.addRange(T))}}}}for(_=[],D=h;D=D.parentNode;)D.nodeType===1&&_.push({element:D,left:D.scrollLeft,top:D.scrollTop});for(typeof h.focus=="function"&&h.focus(),h=0;h<_.length;h++){var C=_[h];C.element.scrollLeft=C.left,C.element.scrollTop=C.top}}zu=!!qo,Yo=qo=null}finally{pt=l,U.p=n,E.T=a}}t.current=e,Kt=2}}function dd(){if(Kt===2){Kt=0;var t=Ka,e=ul,a=(e.flags&8772)!==0;if((e.subtreeFlags&8772)!==0||a){a=E.T,E.T=null;var n=U.p;U.p=2;var l=pt;pt|=4;try{Yf(t,e.alternate,e)}finally{pt=l,U.p=n,E.T=a}}Kt=3}}function hd(){if(Kt===4||Kt===3){Kt=0,Aa();var t=Ka,e=ul,a=Oa,n=Pf;(e.subtreeFlags&10256)!==0||(e.flags&10256)!==0?Kt=5:(Kt=0,ul=Ka=null,gd(t,t.pendingLanes));var l=t.pendingLanes;if(l===0&&(Xa=null),Ke(a),e=e.stateNode,ie&&typeof ie.onCommitFiberRoot=="function")try{ie.onCommitFiberRoot(nn,e,void 0,(e.current.flags&128)===128)}catch{}if(n!==null){e=E.T,l=U.p,U.p=2,E.T=null;try{for(var i=t.onRecoverableError,r=0;r<n.length;r++){var h=n[r];i(h.value,{componentStack:h.stack})}}finally{E.T=e,U.p=l}}(Oa&3)!==0&&hu(),ea(t),l=t.pendingLanes,(a&261930)!==0&&(l&42)!==0?t===Do?ti++:(ti=0,Do=t):ti=0,ei(0)}}function gd(t,e){(t.pooledCacheLanes&=e)===0&&(e=t.pooledCache,e!=null&&(t.pooledCache=null,Bl(e)))}function hu(){return fd(),dd(),hd(),md()}function md(){if(Kt!==5)return!1;var t=Ka,e=Oo;Oo=0;var a=Ke(Oa),n=E.T,l=U.p;try{U.p=32>a?32:a,E.T=null,a=zo,zo=null;var i=Ka,r=Oa;if(Kt=0,ul=Ka=null,Oa=0,(pt&6)!==0)throw Error(o(331));var h=pt;if(pt|=4,$f(i.current),kf(i,i.current,r,a),pt=h,ei(0,!1),ie&&typeof ie.onPostCommitFiberRoot=="function")try{ie.onPostCommitFiberRoot(nn,i)}catch{}return!0}finally{U.p=l,E.T=n,gd(t,e)}}function pd(t,e,a){e=we(a,e),e=no(t.stateNode,e,2),t=Ha(t,e,2),t!==null&&(Bt(t,2),ea(t))}function xt(t,e,a){if(t.tag===3)pd(t,t,a);else for(;e!==null;){if(e.tag===3){pd(e,t,a);break}else if(e.tag===1){var n=e.stateNode;if(typeof e.type.getDerivedStateFromError=="function"||typeof n.componentDidCatch=="function"&&(Xa===null||!Xa.has(n))){t=we(a,t),a=yf(2),n=Ha(e,a,2),n!==null&&(vf(a,n,e,t),Bt(n,2),ea(n));break}}e=e.return}}function Co(t,e,a){var n=t.pingCache;if(n===null){n=t.pingCache=new Sm;var l=new Set;n.set(e,l)}else l=n.get(e),l===void 0&&(l=new Set,n.set(e,l));l.has(a)||(xo=!0,l.add(a),t=zm.bind(null,t,e,a),e.then(t,t))}function zm(t,e,a){var n=t.pingCache;n!==null&&n.delete(e),t.pingedLanes|=t.suspendedLanes&a,t.warmLanes&=~a,Mt===t&&(ct&a)===a&&(jt===4||jt===3&&(ct&62914560)===ct&&300>le()-su?(pt&2)===0&&sl(t,0):To|=a,il===ct&&(il=0)),ea(t)}function yd(t,e){e===0&&(e=ee()),t=fn(t,e),t!==null&&(Bt(t,e),ea(t))}function Dm(t){var e=t.memoizedState,a=0;e!==null&&(a=e.retryLane),yd(t,a)}function Am(t,e){var a=0;switch(t.tag){case 31:case 13:var n=t.stateNode,l=t.memoizedState;l!==null&&(a=l.retryLane);break;case 19:n=t.stateNode;break;case 22:n=t.stateNode._retryCache;break;default:throw Error(o(314))}n!==null&&n.delete(e),yd(t,a)}function Nm(t,e){return vl(t,e)}var gu=null,cl=null,Mo=!1,mu=!1,_o=!1,ka=0;function ea(t){t!==cl&&t.next===null&&(cl===null?gu=cl=t:cl=cl.next=t),mu=!0,Mo||(Mo=!0,Mm())}function ei(t,e){if(!_o&&mu){_o=!0;do for(var a=!1,n=gu;n!==null;){if(t!==0){var l=n.pendingLanes;if(l===0)var i=0;else{var r=n.suspendedLanes,h=n.pingedLanes;i=(1<<31-te(42|t)+1)-1,i&=l&~(r&~h),i=i&201326741?i&201326741|1:i?i|2:0}i!==0&&(a=!0,xd(n,i))}else i=ct,i=J(n,n===Mt?i:0,n.cancelPendingCommit!==null||n.timeoutHandle!==-1),(i&3)===0||Ut(n,i)||(a=!0,xd(n,i));n=n.next}while(a);_o=!1}}function Cm(){vd()}function vd(){mu=Mo=!1;var t=0;ka!==0&&Ym()&&(t=ka);for(var e=le(),a=null,n=gu;n!==null;){var l=n.next,i=bd(n,e);i===0?(n.next=null,a===null?gu=l:a.next=l,l===null&&(cl=a)):(a=n,(t!==0||(i&3)!==0)&&(mu=!0)),n=l}Kt!==0&&Kt!==5||ei(t),ka!==0&&(ka=0)}function bd(t,e){for(var a=t.suspendedLanes,n=t.pingedLanes,l=t.expirationTimes,i=t.pendingLanes&-62914561;0<i;){var r=31-te(i),h=1<<r,y=l[r];y===-1?((h&a)===0||(h&n)!==0)&&(l[r]=Zt(h,e)):y<=e&&(t.expiredLanes|=h),i&=~h}if(e=Mt,a=ct,a=J(t,t===e?a:0,t.cancelPendingCommit!==null||t.timeoutHandle!==-1),n=t.callbackNode,a===0||t===e&&(St===2||St===9)||t.cancelPendingCommit!==null)return n!==null&&n!==null&&bl(n),t.callbackNode=null,t.callbackPriority=0;if((a&3)===0||Ut(t,a)){if(e=a&-a,e===t.callbackPriority)return e;switch(n!==null&&bl(n),Ke(a)){case 2:case 8:a=vi;break;case 32:a=an;break;case 268435456:a=sa;break;default:a=an}return n=Sd.bind(null,t),a=vl(a,n),t.callbackPriority=e,t.callbackNode=a,e}return n!==null&&n!==null&&bl(n),t.callbackPriority=2,t.callbackNode=null,2}function Sd(t,e){if(Kt!==0&&Kt!==5)return t.callbackNode=null,t.callbackPriority=0,null;var a=t.callbackNode;if(hu()&&t.callbackNode!==a)return null;var n=ct;return n=J(t,t===Mt?n:0,t.cancelPendingCommit!==null||t.timeoutHandle!==-1),n===0?null:(ed(t,n,e),bd(t,le()),t.callbackNode!=null&&t.callbackNode===a?Sd.bind(null,t):null)}function xd(t,e){if(hu())return null;ed(t,e,!0)}function Mm(){Gm(function(){(pt&6)!==0?vl(en,Cm):vd()})}function Ro(){if(ka===0){var t=Jn;t===0&&(t=An,An<<=1,(An&261888)===0&&(An=256)),ka=t}return ka}function Td(t){return t==null||typeof t=="symbol"||typeof t=="boolean"?null:typeof t=="function"?t:Ei(""+t)}function Ed(t,e){var a=e.ownerDocument.createElement("input");return a.name=e.name,a.value=e.value,t.id&&a.setAttribute("form",t.id),e.parentNode.insertBefore(a,e),t=new FormData(t),a.parentNode.removeChild(a),t}function _m(t,e,a,n,l){if(e==="submit"&&a&&a.stateNode===l){var i=Td((l[de]||null).action),r=n.submitter;r&&(e=(e=r[de]||null)?Td(e.formAction):r.getAttribute("formAction"),e!==null&&(i=e,r=null));var h=new Ai("action","action",null,n,l);t.push({event:h,listeners:[{instance:null,listener:function(){if(n.defaultPrevented){if(ka!==0){var y=r?Ed(l,r):new FormData(l);Ws(a,{pending:!0,data:y,method:l.method,action:i},null,y)}}else typeof i=="function"&&(h.preventDefault(),y=r?Ed(l,r):new FormData(l),Ws(a,{pending:!0,data:y,method:l.method,action:i},i,y))},currentTarget:l}]})}}for(var Uo=0;Uo<gs.length;Uo++){var wo=gs[Uo],Rm=wo.toLowerCase(),Um=wo[0].toUpperCase()+wo.slice(1);Ze(Rm,"on"+Um)}Ze(Pc,"onAnimationEnd"),Ze(tr,"onAnimationIteration"),Ze(er,"onAnimationStart"),Ze("dblclick","onDoubleClick"),Ze("focusin","onFocus"),Ze("focusout","onBlur"),Ze(Fg,"onTransitionRun"),Ze($g,"onTransitionStart"),Ze(Wg,"onTransitionCancel"),Ze(ar,"onTransitionEnd"),wn("onMouseEnter",["mouseout","mouseover"]),wn("onMouseLeave",["mouseout","mouseover"]),wn("onPointerEnter",["pointerout","pointerover"]),wn("onPointerLeave",["pointerout","pointerover"]),sn("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),sn("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),sn("onBeforeInput",["compositionend","keypress","textInput","paste"]),sn("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),sn("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),sn("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var ai="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),wm=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(ai));function Od(t,e){e=(e&4)!==0;for(var a=0;a<t.length;a++){var n=t[a],l=n.event;n=n.listeners;t:{var i=void 0;if(e)for(var r=n.length-1;0<=r;r--){var h=n[r],y=h.instance,O=h.currentTarget;if(h=h.listener,y!==i&&l.isPropagationStopped())break t;i=h,l.currentTarget=O;try{i(l)}catch(A){Mi(A)}l.currentTarget=null,i=y}else for(r=0;r<n.length;r++){if(h=n[r],y=h.instance,O=h.currentTarget,h=h.listener,y!==i&&l.isPropagationStopped())break t;i=h,l.currentTarget=O;try{i(l)}catch(A){Mi(A)}l.currentTarget=null,i=y}}}}function it(t,e){var a=e[Zu];a===void 0&&(a=e[Zu]=new Set);var n=t+"__bubble";a.has(n)||(zd(e,t,2,!1),a.add(n))}function Bo(t,e,a){var n=0;e&&(n|=4),zd(a,t,n,e)}var pu="_reactListening"+Math.random().toString(36).slice(2);function Lo(t){if(!t[pu]){t[pu]=!0,yc.forEach(function(a){a!=="selectionchange"&&(wm.has(a)||Bo(a,!1,t),Bo(a,!0,t))});var e=t.nodeType===9?t:t.ownerDocument;e===null||e[pu]||(e[pu]=!0,Bo("selectionchange",!1,e))}}function zd(t,e,a,n){switch(th(e)){case 2:var l=op;break;case 8:l=cp;break;default:l=Wo}a=l.bind(null,e,a,t),l=void 0,!es||e!=="touchstart"&&e!=="touchmove"&&e!=="wheel"||(l=!0),n?l!==void 0?t.addEventListener(e,a,{capture:!0,passive:l}):t.addEventListener(e,a,!0):l!==void 0?t.addEventListener(e,a,{passive:l}):t.addEventListener(e,a,!1)}function jo(t,e,a,n,l){var i=n;if((e&1)===0&&(e&2)===0&&n!==null)t:for(;;){if(n===null)return;var r=n.tag;if(r===3||r===4){var h=n.stateNode.containerInfo;if(h===l)break;if(r===4)for(r=n.return;r!==null;){var y=r.tag;if((y===3||y===4)&&r.stateNode.containerInfo===l)return;r=r.return}for(;h!==null;){if(r=_n(h),r===null)return;if(y=r.tag,y===5||y===6||y===26||y===27){n=i=r;continue t}h=h.parentNode}}n=n.return}Cc(function(){var O=i,A=Pu(a),_=[];t:{var z=nr.get(t);if(z!==void 0){var D=Ai,H=t;switch(t){case"keypress":if(zi(a)===0)break t;case"keydown":case"keyup":D=Ag;break;case"focusin":H="focus",D=is;break;case"focusout":H="blur",D=is;break;case"beforeblur":case"afterblur":D=is;break;case"click":if(a.button===2)break t;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":D=Rc;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":D=mg;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":D=Mg;break;case Pc:case tr:case er:D=vg;break;case ar:D=Rg;break;case"scroll":case"scrollend":D=hg;break;case"wheel":D=wg;break;case"copy":case"cut":case"paste":D=Sg;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":D=wc;break;case"toggle":case"beforetoggle":D=Lg}var X=(e&4)!==0,zt=!X&&(t==="scroll"||t==="scrollend"),x=X?z!==null?z+"Capture":null:z;X=[];for(var b=O,T;b!==null;){var C=b;if(T=C.stateNode,C=C.tag,C!==5&&C!==26&&C!==27||T===null||x===null||(C=Ol(b,x),C!=null&&X.push(ni(b,C,T))),zt)break;b=b.return}0<X.length&&(z=new D(z,H,null,a,A),_.push({event:z,listeners:X}))}}if((e&7)===0){t:{if(z=t==="mouseover"||t==="pointerover",D=t==="mouseout"||t==="pointerout",z&&a!==Iu&&(H=a.relatedTarget||a.fromElement)&&(_n(H)||H[Mn]))break t;if((D||z)&&(z=A.window===A?A:(z=A.ownerDocument)?z.defaultView||z.parentWindow:window,D?(H=a.relatedTarget||a.toElement,D=O,H=H?_n(H):null,H!==null&&(zt=d(H),X=H.tag,H!==zt||X!==5&&X!==27&&X!==6)&&(H=null)):(D=null,H=O),D!==H)){if(X=Rc,C="onMouseLeave",x="onMouseEnter",b="mouse",(t==="pointerout"||t==="pointerover")&&(X=wc,C="onPointerLeave",x="onPointerEnter",b="pointer"),zt=D==null?z:El(D),T=H==null?z:El(H),z=new X(C,b+"leave",D,a,A),z.target=zt,z.relatedTarget=T,C=null,_n(A)===O&&(X=new X(x,b+"enter",H,a,A),X.target=T,X.relatedTarget=zt,C=X),zt=C,D&&H)e:{for(X=Bm,x=D,b=H,T=0,C=x;C;C=X(C))T++;C=0;for(var G=b;G;G=X(G))C++;for(;0<T-C;)x=X(x),T--;for(;0<C-T;)b=X(b),C--;for(;T--;){if(x===b||b!==null&&x===b.alternate){X=x;break e}x=X(x),b=X(b)}X=null}else X=null;D!==null&&Dd(_,z,D,X,!1),H!==null&&zt!==null&&Dd(_,zt,H,X,!0)}}t:{if(z=O?El(O):window,D=z.nodeName&&z.nodeName.toLowerCase(),D==="select"||D==="input"&&z.type==="file")var gt=Gc;else if(Yc(z))if(Qc)gt=Zg;else{gt=Xg;var Y=Qg}else D=z.nodeName,!D||D.toLowerCase()!=="input"||z.type!=="checkbox"&&z.type!=="radio"?O&&Wu(O.elementType)&&(gt=Gc):gt=Kg;if(gt&&(gt=gt(t,O))){Vc(_,gt,a,A);break t}Y&&Y(t,z,O),t==="focusout"&&O&&z.type==="number"&&O.memoizedProps.value!=null&&$u(z,"number",z.value)}switch(Y=O?El(O):window,t){case"focusin":(Yc(Y)||Y.contentEditable==="true")&&(Yn=Y,fs=O,Rl=null);break;case"focusout":Rl=fs=Yn=null;break;case"mousedown":ds=!0;break;case"contextmenu":case"mouseup":case"dragend":ds=!1,Wc(_,a,A);break;case"selectionchange":if(Jg)break;case"keydown":case"keyup":Wc(_,a,A)}var P;if(ss)t:{switch(t){case"compositionstart":var rt="onCompositionStart";break t;case"compositionend":rt="onCompositionEnd";break t;case"compositionupdate":rt="onCompositionUpdate";break t}rt=void 0}else qn?Hc(t,a)&&(rt="onCompositionEnd"):t==="keydown"&&a.keyCode===229&&(rt="onCompositionStart");rt&&(Bc&&a.locale!=="ko"&&(qn||rt!=="onCompositionStart"?rt==="onCompositionEnd"&&qn&&(P=Mc()):(_a=A,as="value"in _a?_a.value:_a.textContent,qn=!0)),Y=yu(O,rt),0<Y.length&&(rt=new Uc(rt,t,null,a,A),_.push({event:rt,listeners:Y}),P?rt.data=P:(P=qc(a),P!==null&&(rt.data=P)))),(P=Hg?qg(t,a):Yg(t,a))&&(rt=yu(O,"onBeforeInput"),0<rt.length&&(Y=new Uc("onBeforeInput","beforeinput",null,a,A),_.push({event:Y,listeners:rt}),Y.data=P)),_m(_,t,O,a,A)}Od(_,e)})}function ni(t,e,a){return{instance:t,listener:e,currentTarget:a}}function yu(t,e){for(var a=e+"Capture",n=[];t!==null;){var l=t,i=l.stateNode;if(l=l.tag,l!==5&&l!==26&&l!==27||i===null||(l=Ol(t,a),l!=null&&n.unshift(ni(t,l,i)),l=Ol(t,e),l!=null&&n.push(ni(t,l,i))),t.tag===3)return n;t=t.return}return[]}function Bm(t){if(t===null)return null;do t=t.return;while(t&&t.tag!==5&&t.tag!==27);return t||null}function Dd(t,e,a,n,l){for(var i=e._reactName,r=[];a!==null&&a!==n;){var h=a,y=h.alternate,O=h.stateNode;if(h=h.tag,y!==null&&y===n)break;h!==5&&h!==26&&h!==27||O===null||(y=O,l?(O=Ol(a,i),O!=null&&r.unshift(ni(a,O,y))):l||(O=Ol(a,i),O!=null&&r.push(ni(a,O,y)))),a=a.return}r.length!==0&&t.push({event:e,listeners:r})}var Lm=/\r\n?/g,jm=/\u0000|\uFFFD/g;function Ad(t){return(typeof t=="string"?t:""+t).replace(Lm,`
`).replace(jm,"")}function Nd(t,e){return e=Ad(e),Ad(t)===e}function Ot(t,e,a,n,l,i){switch(a){case"children":typeof n=="string"?e==="body"||e==="textarea"&&n===""||Ln(t,n):(typeof n=="number"||typeof n=="bigint")&&e!=="body"&&Ln(t,""+n);break;case"className":xi(t,"class",n);break;case"tabIndex":xi(t,"tabindex",n);break;case"dir":case"role":case"viewBox":case"width":case"height":xi(t,a,n);break;case"style":Ac(t,n,i);break;case"data":if(e!=="object"){xi(t,"data",n);break}case"src":case"href":if(n===""&&(e!=="a"||a!=="href")){t.removeAttribute(a);break}if(n==null||typeof n=="function"||typeof n=="symbol"||typeof n=="boolean"){t.removeAttribute(a);break}n=Ei(""+n),t.setAttribute(a,n);break;case"action":case"formAction":if(typeof n=="function"){t.setAttribute(a,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof i=="function"&&(a==="formAction"?(e!=="input"&&Ot(t,e,"name",l.name,l,null),Ot(t,e,"formEncType",l.formEncType,l,null),Ot(t,e,"formMethod",l.formMethod,l,null),Ot(t,e,"formTarget",l.formTarget,l,null)):(Ot(t,e,"encType",l.encType,l,null),Ot(t,e,"method",l.method,l,null),Ot(t,e,"target",l.target,l,null)));if(n==null||typeof n=="symbol"||typeof n=="boolean"){t.removeAttribute(a);break}n=Ei(""+n),t.setAttribute(a,n);break;case"onClick":n!=null&&(t.onclick=ca);break;case"onScroll":n!=null&&it("scroll",t);break;case"onScrollEnd":n!=null&&it("scrollend",t);break;case"dangerouslySetInnerHTML":if(n!=null){if(typeof n!="object"||!("__html"in n))throw Error(o(61));if(a=n.__html,a!=null){if(l.children!=null)throw Error(o(60));t.innerHTML=a}}break;case"multiple":t.multiple=n&&typeof n!="function"&&typeof n!="symbol";break;case"muted":t.muted=n&&typeof n!="function"&&typeof n!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(n==null||typeof n=="function"||typeof n=="boolean"||typeof n=="symbol"){t.removeAttribute("xlink:href");break}a=Ei(""+n),t.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",a);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":n!=null&&typeof n!="function"&&typeof n!="symbol"?t.setAttribute(a,""+n):t.removeAttribute(a);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":n&&typeof n!="function"&&typeof n!="symbol"?t.setAttribute(a,""):t.removeAttribute(a);break;case"capture":case"download":n===!0?t.setAttribute(a,""):n!==!1&&n!=null&&typeof n!="function"&&typeof n!="symbol"?t.setAttribute(a,n):t.removeAttribute(a);break;case"cols":case"rows":case"size":case"span":n!=null&&typeof n!="function"&&typeof n!="symbol"&&!isNaN(n)&&1<=n?t.setAttribute(a,n):t.removeAttribute(a);break;case"rowSpan":case"start":n==null||typeof n=="function"||typeof n=="symbol"||isNaN(n)?t.removeAttribute(a):t.setAttribute(a,n);break;case"popover":it("beforetoggle",t),it("toggle",t),Si(t,"popover",n);break;case"xlinkActuate":oa(t,"http://www.w3.org/1999/xlink","xlink:actuate",n);break;case"xlinkArcrole":oa(t,"http://www.w3.org/1999/xlink","xlink:arcrole",n);break;case"xlinkRole":oa(t,"http://www.w3.org/1999/xlink","xlink:role",n);break;case"xlinkShow":oa(t,"http://www.w3.org/1999/xlink","xlink:show",n);break;case"xlinkTitle":oa(t,"http://www.w3.org/1999/xlink","xlink:title",n);break;case"xlinkType":oa(t,"http://www.w3.org/1999/xlink","xlink:type",n);break;case"xmlBase":oa(t,"http://www.w3.org/XML/1998/namespace","xml:base",n);break;case"xmlLang":oa(t,"http://www.w3.org/XML/1998/namespace","xml:lang",n);break;case"xmlSpace":oa(t,"http://www.w3.org/XML/1998/namespace","xml:space",n);break;case"is":Si(t,"is",n);break;case"innerText":case"textContent":break;default:(!(2<a.length)||a[0]!=="o"&&a[0]!=="O"||a[1]!=="n"&&a[1]!=="N")&&(a=fg.get(a)||a,Si(t,a,n))}}function Ho(t,e,a,n,l,i){switch(a){case"style":Ac(t,n,i);break;case"dangerouslySetInnerHTML":if(n!=null){if(typeof n!="object"||!("__html"in n))throw Error(o(61));if(a=n.__html,a!=null){if(l.children!=null)throw Error(o(60));t.innerHTML=a}}break;case"children":typeof n=="string"?Ln(t,n):(typeof n=="number"||typeof n=="bigint")&&Ln(t,""+n);break;case"onScroll":n!=null&&it("scroll",t);break;case"onScrollEnd":n!=null&&it("scrollend",t);break;case"onClick":n!=null&&(t.onclick=ca);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!vc.hasOwnProperty(a))t:{if(a[0]==="o"&&a[1]==="n"&&(l=a.endsWith("Capture"),e=a.slice(2,l?a.length-7:void 0),i=t[de]||null,i=i!=null?i[a]:null,typeof i=="function"&&t.removeEventListener(e,i,l),typeof n=="function")){typeof i!="function"&&i!==null&&(a in t?t[a]=null:t.hasAttribute(a)&&t.removeAttribute(a)),t.addEventListener(e,n,l);break t}a in t?t[a]=n:n===!0?t.setAttribute(a,""):Si(t,a,n)}}}function Pt(t,e,a){switch(e){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":it("error",t),it("load",t);var n=!1,l=!1,i;for(i in a)if(a.hasOwnProperty(i)){var r=a[i];if(r!=null)switch(i){case"src":n=!0;break;case"srcSet":l=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(o(137,e));default:Ot(t,e,i,r,a,null)}}l&&Ot(t,e,"srcSet",a.srcSet,a,null),n&&Ot(t,e,"src",a.src,a,null);return;case"input":it("invalid",t);var h=i=r=l=null,y=null,O=null;for(n in a)if(a.hasOwnProperty(n)){var A=a[n];if(A!=null)switch(n){case"name":l=A;break;case"type":r=A;break;case"checked":y=A;break;case"defaultChecked":O=A;break;case"value":i=A;break;case"defaultValue":h=A;break;case"children":case"dangerouslySetInnerHTML":if(A!=null)throw Error(o(137,e));break;default:Ot(t,e,n,A,a,null)}}Ec(t,i,h,y,O,r,l,!1);return;case"select":it("invalid",t),n=r=i=null;for(l in a)if(a.hasOwnProperty(l)&&(h=a[l],h!=null))switch(l){case"value":i=h;break;case"defaultValue":r=h;break;case"multiple":n=h;default:Ot(t,e,l,h,a,null)}e=i,a=r,t.multiple=!!n,e!=null?Bn(t,!!n,e,!1):a!=null&&Bn(t,!!n,a,!0);return;case"textarea":it("invalid",t),i=l=n=null;for(r in a)if(a.hasOwnProperty(r)&&(h=a[r],h!=null))switch(r){case"value":n=h;break;case"defaultValue":l=h;break;case"children":i=h;break;case"dangerouslySetInnerHTML":if(h!=null)throw Error(o(91));break;default:Ot(t,e,r,h,a,null)}zc(t,n,l,i);return;case"option":for(y in a)if(a.hasOwnProperty(y)&&(n=a[y],n!=null))switch(y){case"selected":t.selected=n&&typeof n!="function"&&typeof n!="symbol";break;default:Ot(t,e,y,n,a,null)}return;case"dialog":it("beforetoggle",t),it("toggle",t),it("cancel",t),it("close",t);break;case"iframe":case"object":it("load",t);break;case"video":case"audio":for(n=0;n<ai.length;n++)it(ai[n],t);break;case"image":it("error",t),it("load",t);break;case"details":it("toggle",t);break;case"embed":case"source":case"link":it("error",t),it("load",t);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(O in a)if(a.hasOwnProperty(O)&&(n=a[O],n!=null))switch(O){case"children":case"dangerouslySetInnerHTML":throw Error(o(137,e));default:Ot(t,e,O,n,a,null)}return;default:if(Wu(e)){for(A in a)a.hasOwnProperty(A)&&(n=a[A],n!==void 0&&Ho(t,e,A,n,a,void 0));return}}for(h in a)a.hasOwnProperty(h)&&(n=a[h],n!=null&&Ot(t,e,h,n,a,null))}function Hm(t,e,a,n){switch(e){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var l=null,i=null,r=null,h=null,y=null,O=null,A=null;for(D in a){var _=a[D];if(a.hasOwnProperty(D)&&_!=null)switch(D){case"checked":break;case"value":break;case"defaultValue":y=_;default:n.hasOwnProperty(D)||Ot(t,e,D,null,n,_)}}for(var z in n){var D=n[z];if(_=a[z],n.hasOwnProperty(z)&&(D!=null||_!=null))switch(z){case"type":i=D;break;case"name":l=D;break;case"checked":O=D;break;case"defaultChecked":A=D;break;case"value":r=D;break;case"defaultValue":h=D;break;case"children":case"dangerouslySetInnerHTML":if(D!=null)throw Error(o(137,e));break;default:D!==_&&Ot(t,e,z,D,n,_)}}Fu(t,r,h,y,O,A,i,l);return;case"select":D=r=h=z=null;for(i in a)if(y=a[i],a.hasOwnProperty(i)&&y!=null)switch(i){case"value":break;case"multiple":D=y;default:n.hasOwnProperty(i)||Ot(t,e,i,null,n,y)}for(l in n)if(i=n[l],y=a[l],n.hasOwnProperty(l)&&(i!=null||y!=null))switch(l){case"value":z=i;break;case"defaultValue":h=i;break;case"multiple":r=i;default:i!==y&&Ot(t,e,l,i,n,y)}e=h,a=r,n=D,z!=null?Bn(t,!!a,z,!1):!!n!=!!a&&(e!=null?Bn(t,!!a,e,!0):Bn(t,!!a,a?[]:"",!1));return;case"textarea":D=z=null;for(h in a)if(l=a[h],a.hasOwnProperty(h)&&l!=null&&!n.hasOwnProperty(h))switch(h){case"value":break;case"children":break;default:Ot(t,e,h,null,n,l)}for(r in n)if(l=n[r],i=a[r],n.hasOwnProperty(r)&&(l!=null||i!=null))switch(r){case"value":z=l;break;case"defaultValue":D=l;break;case"children":break;case"dangerouslySetInnerHTML":if(l!=null)throw Error(o(91));break;default:l!==i&&Ot(t,e,r,l,n,i)}Oc(t,z,D);return;case"option":for(var H in a)if(z=a[H],a.hasOwnProperty(H)&&z!=null&&!n.hasOwnProperty(H))switch(H){case"selected":t.selected=!1;break;default:Ot(t,e,H,null,n,z)}for(y in n)if(z=n[y],D=a[y],n.hasOwnProperty(y)&&z!==D&&(z!=null||D!=null))switch(y){case"selected":t.selected=z&&typeof z!="function"&&typeof z!="symbol";break;default:Ot(t,e,y,z,n,D)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var X in a)z=a[X],a.hasOwnProperty(X)&&z!=null&&!n.hasOwnProperty(X)&&Ot(t,e,X,null,n,z);for(O in n)if(z=n[O],D=a[O],n.hasOwnProperty(O)&&z!==D&&(z!=null||D!=null))switch(O){case"children":case"dangerouslySetInnerHTML":if(z!=null)throw Error(o(137,e));break;default:Ot(t,e,O,z,n,D)}return;default:if(Wu(e)){for(var zt in a)z=a[zt],a.hasOwnProperty(zt)&&z!==void 0&&!n.hasOwnProperty(zt)&&Ho(t,e,zt,void 0,n,z);for(A in n)z=n[A],D=a[A],!n.hasOwnProperty(A)||z===D||z===void 0&&D===void 0||Ho(t,e,A,z,n,D);return}}for(var x in a)z=a[x],a.hasOwnProperty(x)&&z!=null&&!n.hasOwnProperty(x)&&Ot(t,e,x,null,n,z);for(_ in n)z=n[_],D=a[_],!n.hasOwnProperty(_)||z===D||z==null&&D==null||Ot(t,e,_,z,n,D)}function Cd(t){switch(t){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function qm(){if(typeof performance.getEntriesByType=="function"){for(var t=0,e=0,a=performance.getEntriesByType("resource"),n=0;n<a.length;n++){var l=a[n],i=l.transferSize,r=l.initiatorType,h=l.duration;if(i&&h&&Cd(r)){for(r=0,h=l.responseEnd,n+=1;n<a.length;n++){var y=a[n],O=y.startTime;if(O>h)break;var A=y.transferSize,_=y.initiatorType;A&&Cd(_)&&(y=y.responseEnd,r+=A*(y<h?1:(h-O)/(y-O)))}if(--n,e+=8*(i+r)/(l.duration/1e3),t++,10<t)break}}if(0<t)return e/t/1e6}return navigator.connection&&(t=navigator.connection.downlink,typeof t=="number")?t:5}var qo=null,Yo=null;function vu(t){return t.nodeType===9?t:t.ownerDocument}function Md(t){switch(t){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function _d(t,e){if(t===0)switch(e){case"svg":return 1;case"math":return 2;default:return 0}return t===1&&e==="foreignObject"?0:t}function Vo(t,e){return t==="textarea"||t==="noscript"||typeof e.children=="string"||typeof e.children=="number"||typeof e.children=="bigint"||typeof e.dangerouslySetInnerHTML=="object"&&e.dangerouslySetInnerHTML!==null&&e.dangerouslySetInnerHTML.__html!=null}var Go=null;function Ym(){var t=window.event;return t&&t.type==="popstate"?t===Go?!1:(Go=t,!0):(Go=null,!1)}var Rd=typeof setTimeout=="function"?setTimeout:void 0,Vm=typeof clearTimeout=="function"?clearTimeout:void 0,Ud=typeof Promise=="function"?Promise:void 0,Gm=typeof queueMicrotask=="function"?queueMicrotask:typeof Ud<"u"?function(t){return Ud.resolve(null).then(t).catch(Qm)}:Rd;function Qm(t){setTimeout(function(){throw t})}function Ja(t){return t==="head"}function wd(t,e){var a=e,n=0;do{var l=a.nextSibling;if(t.removeChild(a),l&&l.nodeType===8)if(a=l.data,a==="/$"||a==="/&"){if(n===0){t.removeChild(l),hl(e);return}n--}else if(a==="$"||a==="$?"||a==="$~"||a==="$!"||a==="&")n++;else if(a==="html")li(t.ownerDocument.documentElement);else if(a==="head"){a=t.ownerDocument.head,li(a);for(var i=a.firstChild;i;){var r=i.nextSibling,h=i.nodeName;i[Tl]||h==="SCRIPT"||h==="STYLE"||h==="LINK"&&i.rel.toLowerCase()==="stylesheet"||a.removeChild(i),i=r}}else a==="body"&&li(t.ownerDocument.body);a=l}while(a);hl(e)}function Bd(t,e){var a=t;t=0;do{var n=a.nextSibling;if(a.nodeType===1?e?(a._stashedDisplay=a.style.display,a.style.display="none"):(a.style.display=a._stashedDisplay||"",a.getAttribute("style")===""&&a.removeAttribute("style")):a.nodeType===3&&(e?(a._stashedText=a.nodeValue,a.nodeValue=""):a.nodeValue=a._stashedText||""),n&&n.nodeType===8)if(a=n.data,a==="/$"){if(t===0)break;t--}else a!=="$"&&a!=="$?"&&a!=="$~"&&a!=="$!"||t++;a=n}while(a)}function Qo(t){var e=t.firstChild;for(e&&e.nodeType===10&&(e=e.nextSibling);e;){var a=e;switch(e=e.nextSibling,a.nodeName){case"HTML":case"HEAD":case"BODY":Qo(a),ku(a);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(a.rel.toLowerCase()==="stylesheet")continue}t.removeChild(a)}}function Xm(t,e,a,n){for(;t.nodeType===1;){var l=a;if(t.nodeName.toLowerCase()!==e.toLowerCase()){if(!n&&(t.nodeName!=="INPUT"||t.type!=="hidden"))break}else if(n){if(!t[Tl])switch(e){case"meta":if(!t.hasAttribute("itemprop"))break;return t;case"link":if(i=t.getAttribute("rel"),i==="stylesheet"&&t.hasAttribute("data-precedence"))break;if(i!==l.rel||t.getAttribute("href")!==(l.href==null||l.href===""?null:l.href)||t.getAttribute("crossorigin")!==(l.crossOrigin==null?null:l.crossOrigin)||t.getAttribute("title")!==(l.title==null?null:l.title))break;return t;case"style":if(t.hasAttribute("data-precedence"))break;return t;case"script":if(i=t.getAttribute("src"),(i!==(l.src==null?null:l.src)||t.getAttribute("type")!==(l.type==null?null:l.type)||t.getAttribute("crossorigin")!==(l.crossOrigin==null?null:l.crossOrigin))&&i&&t.hasAttribute("async")&&!t.hasAttribute("itemprop"))break;return t;default:return t}}else if(e==="input"&&t.type==="hidden"){var i=l.name==null?null:""+l.name;if(l.type==="hidden"&&t.getAttribute("name")===i)return t}else return t;if(t=qe(t.nextSibling),t===null)break}return null}function Km(t,e,a){if(e==="")return null;for(;t.nodeType!==3;)if((t.nodeType!==1||t.nodeName!=="INPUT"||t.type!=="hidden")&&!a||(t=qe(t.nextSibling),t===null))return null;return t}function Ld(t,e){for(;t.nodeType!==8;)if((t.nodeType!==1||t.nodeName!=="INPUT"||t.type!=="hidden")&&!e||(t=qe(t.nextSibling),t===null))return null;return t}function Xo(t){return t.data==="$?"||t.data==="$~"}function Ko(t){return t.data==="$!"||t.data==="$?"&&t.ownerDocument.readyState!=="loading"}function Zm(t,e){var a=t.ownerDocument;if(t.data==="$~")t._reactRetry=e;else if(t.data!=="$?"||a.readyState!=="loading")e();else{var n=function(){e(),a.removeEventListener("DOMContentLoaded",n)};a.addEventListener("DOMContentLoaded",n),t._reactRetry=n}}function qe(t){for(;t!=null;t=t.nextSibling){var e=t.nodeType;if(e===1||e===3)break;if(e===8){if(e=t.data,e==="$"||e==="$!"||e==="$?"||e==="$~"||e==="&"||e==="F!"||e==="F")break;if(e==="/$"||e==="/&")return null}}return t}var Zo=null;function jd(t){t=t.nextSibling;for(var e=0;t;){if(t.nodeType===8){var a=t.data;if(a==="/$"||a==="/&"){if(e===0)return qe(t.nextSibling);e--}else a!=="$"&&a!=="$!"&&a!=="$?"&&a!=="$~"&&a!=="&"||e++}t=t.nextSibling}return null}function Hd(t){t=t.previousSibling;for(var e=0;t;){if(t.nodeType===8){var a=t.data;if(a==="$"||a==="$!"||a==="$?"||a==="$~"||a==="&"){if(e===0)return t;e--}else a!=="/$"&&a!=="/&"||e++}t=t.previousSibling}return null}function qd(t,e,a){switch(e=vu(a),t){case"html":if(t=e.documentElement,!t)throw Error(o(452));return t;case"head":if(t=e.head,!t)throw Error(o(453));return t;case"body":if(t=e.body,!t)throw Error(o(454));return t;default:throw Error(o(451))}}function li(t){for(var e=t.attributes;e.length;)t.removeAttributeNode(e[0]);ku(t)}var Ye=new Map,Yd=new Set;function bu(t){return typeof t.getRootNode=="function"?t.getRootNode():t.nodeType===9?t:t.ownerDocument}var za=U.d;U.d={f:km,r:Jm,D:Fm,C:$m,L:Wm,m:Im,X:tp,S:Pm,M:ep};function km(){var t=za.f(),e=ru();return t||e}function Jm(t){var e=Rn(t);e!==null&&e.tag===5&&e.type==="form"?af(e):za.r(t)}var rl=typeof document>"u"?null:document;function Vd(t,e,a){var n=rl;if(n&&typeof e=="string"&&e){var l=Re(e);l='link[rel="'+t+'"][href="'+l+'"]',typeof a=="string"&&(l+='[crossorigin="'+a+'"]'),Yd.has(l)||(Yd.add(l),t={rel:t,crossOrigin:a,href:e},n.querySelector(l)===null&&(e=n.createElement("link"),Pt(e,"link",t),kt(e),n.head.appendChild(e)))}}function Fm(t){za.D(t),Vd("dns-prefetch",t,null)}function $m(t,e){za.C(t,e),Vd("preconnect",t,e)}function Wm(t,e,a){za.L(t,e,a);var n=rl;if(n&&t&&e){var l='link[rel="preload"][as="'+Re(e)+'"]';e==="image"&&a&&a.imageSrcSet?(l+='[imagesrcset="'+Re(a.imageSrcSet)+'"]',typeof a.imageSizes=="string"&&(l+='[imagesizes="'+Re(a.imageSizes)+'"]')):l+='[href="'+Re(t)+'"]';var i=l;switch(e){case"style":i=fl(t);break;case"script":i=dl(t)}Ye.has(i)||(t=g({rel:"preload",href:e==="image"&&a&&a.imageSrcSet?void 0:t,as:e},a),Ye.set(i,t),n.querySelector(l)!==null||e==="style"&&n.querySelector(ii(i))||e==="script"&&n.querySelector(ui(i))||(e=n.createElement("link"),Pt(e,"link",t),kt(e),n.head.appendChild(e)))}}function Im(t,e){za.m(t,e);var a=rl;if(a&&t){var n=e&&typeof e.as=="string"?e.as:"script",l='link[rel="modulepreload"][as="'+Re(n)+'"][href="'+Re(t)+'"]',i=l;switch(n){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":i=dl(t)}if(!Ye.has(i)&&(t=g({rel:"modulepreload",href:t},e),Ye.set(i,t),a.querySelector(l)===null)){switch(n){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(a.querySelector(ui(i)))return}n=a.createElement("link"),Pt(n,"link",t),kt(n),a.head.appendChild(n)}}}function Pm(t,e,a){za.S(t,e,a);var n=rl;if(n&&t){var l=Un(n).hoistableStyles,i=fl(t);e=e||"default";var r=l.get(i);if(!r){var h={loading:0,preload:null};if(r=n.querySelector(ii(i)))h.loading=5;else{t=g({rel:"stylesheet",href:t,"data-precedence":e},a),(a=Ye.get(i))&&ko(t,a);var y=r=n.createElement("link");kt(y),Pt(y,"link",t),y._p=new Promise(function(O,A){y.onload=O,y.onerror=A}),y.addEventListener("load",function(){h.loading|=1}),y.addEventListener("error",function(){h.loading|=2}),h.loading|=4,Su(r,e,n)}r={type:"stylesheet",instance:r,count:1,state:h},l.set(i,r)}}}function tp(t,e){za.X(t,e);var a=rl;if(a&&t){var n=Un(a).hoistableScripts,l=dl(t),i=n.get(l);i||(i=a.querySelector(ui(l)),i||(t=g({src:t,async:!0},e),(e=Ye.get(l))&&Jo(t,e),i=a.createElement("script"),kt(i),Pt(i,"link",t),a.head.appendChild(i)),i={type:"script",instance:i,count:1,state:null},n.set(l,i))}}function ep(t,e){za.M(t,e);var a=rl;if(a&&t){var n=Un(a).hoistableScripts,l=dl(t),i=n.get(l);i||(i=a.querySelector(ui(l)),i||(t=g({src:t,async:!0,type:"module"},e),(e=Ye.get(l))&&Jo(t,e),i=a.createElement("script"),kt(i),Pt(i,"link",t),a.head.appendChild(i)),i={type:"script",instance:i,count:1,state:null},n.set(l,i))}}function Gd(t,e,a,n){var l=(l=Ht.current)?bu(l):null;if(!l)throw Error(o(446));switch(t){case"meta":case"title":return null;case"style":return typeof a.precedence=="string"&&typeof a.href=="string"?(e=fl(a.href),a=Un(l).hoistableStyles,n=a.get(e),n||(n={type:"style",instance:null,count:0,state:null},a.set(e,n)),n):{type:"void",instance:null,count:0,state:null};case"link":if(a.rel==="stylesheet"&&typeof a.href=="string"&&typeof a.precedence=="string"){t=fl(a.href);var i=Un(l).hoistableStyles,r=i.get(t);if(r||(l=l.ownerDocument||l,r={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},i.set(t,r),(i=l.querySelector(ii(t)))&&!i._p&&(r.instance=i,r.state.loading=5),Ye.has(t)||(a={rel:"preload",as:"style",href:a.href,crossOrigin:a.crossOrigin,integrity:a.integrity,media:a.media,hrefLang:a.hrefLang,referrerPolicy:a.referrerPolicy},Ye.set(t,a),i||ap(l,t,a,r.state))),e&&n===null)throw Error(o(528,""));return r}if(e&&n!==null)throw Error(o(529,""));return null;case"script":return e=a.async,a=a.src,typeof a=="string"&&e&&typeof e!="function"&&typeof e!="symbol"?(e=dl(a),a=Un(l).hoistableScripts,n=a.get(e),n||(n={type:"script",instance:null,count:0,state:null},a.set(e,n)),n):{type:"void",instance:null,count:0,state:null};default:throw Error(o(444,t))}}function fl(t){return'href="'+Re(t)+'"'}function ii(t){return'link[rel="stylesheet"]['+t+"]"}function Qd(t){return g({},t,{"data-precedence":t.precedence,precedence:null})}function ap(t,e,a,n){t.querySelector('link[rel="preload"][as="style"]['+e+"]")?n.loading=1:(e=t.createElement("link"),n.preload=e,e.addEventListener("load",function(){return n.loading|=1}),e.addEventListener("error",function(){return n.loading|=2}),Pt(e,"link",a),kt(e),t.head.appendChild(e))}function dl(t){return'[src="'+Re(t)+'"]'}function ui(t){return"script[async]"+t}function Xd(t,e,a){if(e.count++,e.instance===null)switch(e.type){case"style":var n=t.querySelector('style[data-href~="'+Re(a.href)+'"]');if(n)return e.instance=n,kt(n),n;var l=g({},a,{"data-href":a.href,"data-precedence":a.precedence,href:null,precedence:null});return n=(t.ownerDocument||t).createElement("style"),kt(n),Pt(n,"style",l),Su(n,a.precedence,t),e.instance=n;case"stylesheet":l=fl(a.href);var i=t.querySelector(ii(l));if(i)return e.state.loading|=4,e.instance=i,kt(i),i;n=Qd(a),(l=Ye.get(l))&&ko(n,l),i=(t.ownerDocument||t).createElement("link"),kt(i);var r=i;return r._p=new Promise(function(h,y){r.onload=h,r.onerror=y}),Pt(i,"link",n),e.state.loading|=4,Su(i,a.precedence,t),e.instance=i;case"script":return i=dl(a.src),(l=t.querySelector(ui(i)))?(e.instance=l,kt(l),l):(n=a,(l=Ye.get(i))&&(n=g({},a),Jo(n,l)),t=t.ownerDocument||t,l=t.createElement("script"),kt(l),Pt(l,"link",n),t.head.appendChild(l),e.instance=l);case"void":return null;default:throw Error(o(443,e.type))}else e.type==="stylesheet"&&(e.state.loading&4)===0&&(n=e.instance,e.state.loading|=4,Su(n,a.precedence,t));return e.instance}function Su(t,e,a){for(var n=a.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),l=n.length?n[n.length-1]:null,i=l,r=0;r<n.length;r++){var h=n[r];if(h.dataset.precedence===e)i=h;else if(i!==l)break}i?i.parentNode.insertBefore(t,i.nextSibling):(e=a.nodeType===9?a.head:a,e.insertBefore(t,e.firstChild))}function ko(t,e){t.crossOrigin==null&&(t.crossOrigin=e.crossOrigin),t.referrerPolicy==null&&(t.referrerPolicy=e.referrerPolicy),t.title==null&&(t.title=e.title)}function Jo(t,e){t.crossOrigin==null&&(t.crossOrigin=e.crossOrigin),t.referrerPolicy==null&&(t.referrerPolicy=e.referrerPolicy),t.integrity==null&&(t.integrity=e.integrity)}var xu=null;function Kd(t,e,a){if(xu===null){var n=new Map,l=xu=new Map;l.set(a,n)}else l=xu,n=l.get(a),n||(n=new Map,l.set(a,n));if(n.has(t))return n;for(n.set(t,null),a=a.getElementsByTagName(t),l=0;l<a.length;l++){var i=a[l];if(!(i[Tl]||i[Ft]||t==="link"&&i.getAttribute("rel")==="stylesheet")&&i.namespaceURI!=="http://www.w3.org/2000/svg"){var r=i.getAttribute(e)||"";r=t+r;var h=n.get(r);h?h.push(i):n.set(r,[i])}}return n}function Zd(t,e,a){t=t.ownerDocument||t,t.head.insertBefore(a,e==="title"?t.querySelector("head > title"):null)}function np(t,e,a){if(a===1||e.itemProp!=null)return!1;switch(t){case"meta":case"title":return!0;case"style":if(typeof e.precedence!="string"||typeof e.href!="string"||e.href==="")break;return!0;case"link":if(typeof e.rel!="string"||typeof e.href!="string"||e.href===""||e.onLoad||e.onError)break;switch(e.rel){case"stylesheet":return t=e.disabled,typeof e.precedence=="string"&&t==null;default:return!0}case"script":if(e.async&&typeof e.async!="function"&&typeof e.async!="symbol"&&!e.onLoad&&!e.onError&&e.src&&typeof e.src=="string")return!0}return!1}function kd(t){return!(t.type==="stylesheet"&&(t.state.loading&3)===0)}function lp(t,e,a,n){if(a.type==="stylesheet"&&(typeof n.media!="string"||matchMedia(n.media).matches!==!1)&&(a.state.loading&4)===0){if(a.instance===null){var l=fl(n.href),i=e.querySelector(ii(l));if(i){e=i._p,e!==null&&typeof e=="object"&&typeof e.then=="function"&&(t.count++,t=Tu.bind(t),e.then(t,t)),a.state.loading|=4,a.instance=i,kt(i);return}i=e.ownerDocument||e,n=Qd(n),(l=Ye.get(l))&&ko(n,l),i=i.createElement("link"),kt(i);var r=i;r._p=new Promise(function(h,y){r.onload=h,r.onerror=y}),Pt(i,"link",n),a.instance=i}t.stylesheets===null&&(t.stylesheets=new Map),t.stylesheets.set(a,e),(e=a.state.preload)&&(a.state.loading&3)===0&&(t.count++,a=Tu.bind(t),e.addEventListener("load",a),e.addEventListener("error",a))}}var Fo=0;function ip(t,e){return t.stylesheets&&t.count===0&&Ou(t,t.stylesheets),0<t.count||0<t.imgCount?function(a){var n=setTimeout(function(){if(t.stylesheets&&Ou(t,t.stylesheets),t.unsuspend){var i=t.unsuspend;t.unsuspend=null,i()}},6e4+e);0<t.imgBytes&&Fo===0&&(Fo=62500*qm());var l=setTimeout(function(){if(t.waitingForImages=!1,t.count===0&&(t.stylesheets&&Ou(t,t.stylesheets),t.unsuspend)){var i=t.unsuspend;t.unsuspend=null,i()}},(t.imgBytes>Fo?50:800)+e);return t.unsuspend=a,function(){t.unsuspend=null,clearTimeout(n),clearTimeout(l)}}:null}function Tu(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)Ou(this,this.stylesheets);else if(this.unsuspend){var t=this.unsuspend;this.unsuspend=null,t()}}}var Eu=null;function Ou(t,e){t.stylesheets=null,t.unsuspend!==null&&(t.count++,Eu=new Map,e.forEach(up,t),Eu=null,Tu.call(t))}function up(t,e){if(!(e.state.loading&4)){var a=Eu.get(t);if(a)var n=a.get(null);else{a=new Map,Eu.set(t,a);for(var l=t.querySelectorAll("link[data-precedence],style[data-precedence]"),i=0;i<l.length;i++){var r=l[i];(r.nodeName==="LINK"||r.getAttribute("media")!=="not all")&&(a.set(r.dataset.precedence,r),n=r)}n&&a.set(null,n)}l=e.instance,r=l.getAttribute("data-precedence"),i=a.get(r)||n,i===n&&a.set(null,l),a.set(r,l),this.count++,n=Tu.bind(this),l.addEventListener("load",n),l.addEventListener("error",n),i?i.parentNode.insertBefore(l,i.nextSibling):(t=t.nodeType===9?t.head:t,t.insertBefore(l,t.firstChild)),e.state.loading|=4}}var si={$$typeof:ft,Provider:null,Consumer:null,_currentValue:q,_currentValue2:q,_threadCount:0};function sp(t,e,a,n,l,i,r,h,y){this.tag=1,this.containerInfo=t,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Ca(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Ca(0),this.hiddenUpdates=Ca(null),this.identifierPrefix=n,this.onUncaughtError=l,this.onCaughtError=i,this.onRecoverableError=r,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=y,this.incompleteTransitions=new Map}function Jd(t,e,a,n,l,i,r,h,y,O,A,_){return t=new sp(t,e,a,r,y,O,A,_,h),e=1,i===!0&&(e|=24),i=Ee(3,null,null,e),t.current=i,i.stateNode=t,e=As(),e.refCount++,t.pooledCache=e,e.refCount++,i.memoizedState={element:n,isDehydrated:a,cache:e},_s(i),t}function Fd(t){return t?(t=Qn,t):Qn}function $d(t,e,a,n,l,i){l=Fd(l),n.context===null?n.context=l:n.pendingContext=l,n=ja(e),n.payload={element:a},i=i===void 0?null:i,i!==null&&(n.callback=i),a=Ha(t,n,e),a!==null&&(ve(a,t,e),ql(a,t,e))}function Wd(t,e){if(t=t.memoizedState,t!==null&&t.dehydrated!==null){var a=t.retryLane;t.retryLane=a!==0&&a<e?a:e}}function $o(t,e){Wd(t,e),(t=t.alternate)&&Wd(t,e)}function Id(t){if(t.tag===13||t.tag===31){var e=fn(t,67108864);e!==null&&ve(e,t,67108864),$o(t,67108864)}}function Pd(t){if(t.tag===13||t.tag===31){var e=Ne();e=Cn(e);var a=fn(t,e);a!==null&&ve(a,t,e),$o(t,e)}}var zu=!0;function op(t,e,a,n){var l=E.T;E.T=null;var i=U.p;try{U.p=2,Wo(t,e,a,n)}finally{U.p=i,E.T=l}}function cp(t,e,a,n){var l=E.T;E.T=null;var i=U.p;try{U.p=8,Wo(t,e,a,n)}finally{U.p=i,E.T=l}}function Wo(t,e,a,n){if(zu){var l=Io(n);if(l===null)jo(t,e,n,Du,a),eh(t,n);else if(fp(l,t,e,a,n))n.stopPropagation();else if(eh(t,n),e&4&&-1<rp.indexOf(t)){for(;l!==null;){var i=Rn(l);if(i!==null)switch(i.tag){case 3:if(i=i.stateNode,i.current.memoizedState.isDehydrated){var r=We(i.pendingLanes);if(r!==0){var h=i;for(h.pendingLanes|=2,h.entangledLanes|=2;r;){var y=1<<31-te(r);h.entanglements[1]|=y,r&=~y}ea(i),(pt&6)===0&&(ou=le()+500,ei(0))}}break;case 31:case 13:h=fn(i,2),h!==null&&ve(h,i,2),ru(),$o(i,2)}if(i=Io(n),i===null&&jo(t,e,n,Du,a),i===l)break;l=i}l!==null&&n.stopPropagation()}else jo(t,e,n,null,a)}}function Io(t){return t=Pu(t),Po(t)}var Du=null;function Po(t){if(Du=null,t=_n(t),t!==null){var e=d(t);if(e===null)t=null;else{var a=e.tag;if(a===13){if(t=m(e),t!==null)return t;t=null}else if(a===31){if(t=p(e),t!==null)return t;t=null}else if(a===3){if(e.stateNode.current.memoizedState.isDehydrated)return e.tag===3?e.stateNode.containerInfo:null;t=null}else e!==t&&(t=null)}}return Du=t,null}function th(t){switch(t){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Qu()){case en:return 2;case vi:return 8;case an:case Sl:return 32;case sa:return 268435456;default:return 32}default:return 32}}var tc=!1,Fa=null,$a=null,Wa=null,oi=new Map,ci=new Map,Ia=[],rp="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function eh(t,e){switch(t){case"focusin":case"focusout":Fa=null;break;case"dragenter":case"dragleave":$a=null;break;case"mouseover":case"mouseout":Wa=null;break;case"pointerover":case"pointerout":oi.delete(e.pointerId);break;case"gotpointercapture":case"lostpointercapture":ci.delete(e.pointerId)}}function ri(t,e,a,n,l,i){return t===null||t.nativeEvent!==i?(t={blockedOn:e,domEventName:a,eventSystemFlags:n,nativeEvent:i,targetContainers:[l]},e!==null&&(e=Rn(e),e!==null&&Id(e)),t):(t.eventSystemFlags|=n,e=t.targetContainers,l!==null&&e.indexOf(l)===-1&&e.push(l),t)}function fp(t,e,a,n,l){switch(e){case"focusin":return Fa=ri(Fa,t,e,a,n,l),!0;case"dragenter":return $a=ri($a,t,e,a,n,l),!0;case"mouseover":return Wa=ri(Wa,t,e,a,n,l),!0;case"pointerover":var i=l.pointerId;return oi.set(i,ri(oi.get(i)||null,t,e,a,n,l)),!0;case"gotpointercapture":return i=l.pointerId,ci.set(i,ri(ci.get(i)||null,t,e,a,n,l)),!0}return!1}function ah(t){var e=_n(t.target);if(e!==null){var a=d(e);if(a!==null){if(e=a.tag,e===13){if(e=m(a),e!==null){t.blockedOn=e,mc(t.priority,function(){Pd(a)});return}}else if(e===31){if(e=p(a),e!==null){t.blockedOn=e,mc(t.priority,function(){Pd(a)});return}}else if(e===3&&a.stateNode.current.memoizedState.isDehydrated){t.blockedOn=a.tag===3?a.stateNode.containerInfo:null;return}}}t.blockedOn=null}function Au(t){if(t.blockedOn!==null)return!1;for(var e=t.targetContainers;0<e.length;){var a=Io(t.nativeEvent);if(a===null){a=t.nativeEvent;var n=new a.constructor(a.type,a);Iu=n,a.target.dispatchEvent(n),Iu=null}else return e=Rn(a),e!==null&&Id(e),t.blockedOn=a,!1;e.shift()}return!0}function nh(t,e,a){Au(t)&&a.delete(e)}function dp(){tc=!1,Fa!==null&&Au(Fa)&&(Fa=null),$a!==null&&Au($a)&&($a=null),Wa!==null&&Au(Wa)&&(Wa=null),oi.forEach(nh),ci.forEach(nh)}function Nu(t,e){t.blockedOn===e&&(t.blockedOn=null,tc||(tc=!0,c.unstable_scheduleCallback(c.unstable_NormalPriority,dp)))}var Cu=null;function lh(t){Cu!==t&&(Cu=t,c.unstable_scheduleCallback(c.unstable_NormalPriority,function(){Cu===t&&(Cu=null);for(var e=0;e<t.length;e+=3){var a=t[e],n=t[e+1],l=t[e+2];if(typeof n!="function"){if(Po(n||a)===null)continue;break}var i=Rn(a);i!==null&&(t.splice(e,3),e-=3,Ws(i,{pending:!0,data:l,method:a.method,action:n},n,l))}}))}function hl(t){function e(y){return Nu(y,t)}Fa!==null&&Nu(Fa,t),$a!==null&&Nu($a,t),Wa!==null&&Nu(Wa,t),oi.forEach(e),ci.forEach(e);for(var a=0;a<Ia.length;a++){var n=Ia[a];n.blockedOn===t&&(n.blockedOn=null)}for(;0<Ia.length&&(a=Ia[0],a.blockedOn===null);)ah(a),a.blockedOn===null&&Ia.shift();if(a=(t.ownerDocument||t).$$reactFormReplay,a!=null)for(n=0;n<a.length;n+=3){var l=a[n],i=a[n+1],r=l[de]||null;if(typeof i=="function")r||lh(a);else if(r){var h=null;if(i&&i.hasAttribute("formAction")){if(l=i,r=i[de]||null)h=r.formAction;else if(Po(l)!==null)continue}else h=r.action;typeof h=="function"?a[n+1]=h:(a.splice(n,3),n-=3),lh(a)}}}function ih(){function t(i){i.canIntercept&&i.info==="react-transition"&&i.intercept({handler:function(){return new Promise(function(r){return l=r})},focusReset:"manual",scroll:"manual"})}function e(){l!==null&&(l(),l=null),n||setTimeout(a,20)}function a(){if(!n&&!navigation.transition){var i=navigation.currentEntry;i&&i.url!=null&&navigation.navigate(i.url,{state:i.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var n=!1,l=null;return navigation.addEventListener("navigate",t),navigation.addEventListener("navigatesuccess",e),navigation.addEventListener("navigateerror",e),setTimeout(a,100),function(){n=!0,navigation.removeEventListener("navigate",t),navigation.removeEventListener("navigatesuccess",e),navigation.removeEventListener("navigateerror",e),l!==null&&(l(),l=null)}}}function ec(t){this._internalRoot=t}Mu.prototype.render=ec.prototype.render=function(t){var e=this._internalRoot;if(e===null)throw Error(o(409));var a=e.current,n=Ne();$d(a,n,t,e,null,null)},Mu.prototype.unmount=ec.prototype.unmount=function(){var t=this._internalRoot;if(t!==null){this._internalRoot=null;var e=t.containerInfo;$d(t.current,2,null,t,null,null),ru(),e[Mn]=null}};function Mu(t){this._internalRoot=t}Mu.prototype.unstable_scheduleHydration=function(t){if(t){var e=Ku();t={blockedOn:null,target:t,priority:e};for(var a=0;a<Ia.length&&e!==0&&e<Ia[a].priority;a++);Ia.splice(a,0,t),a===0&&ah(t)}};var uh=u.version;if(uh!=="19.2.4")throw Error(o(527,uh,"19.2.4"));U.findDOMNode=function(t){var e=t._reactInternals;if(e===void 0)throw typeof t.render=="function"?Error(o(188)):(t=Object.keys(t).join(","),Error(o(268,t)));return t=v(e),t=t!==null?N(t):null,t=t===null?null:t.stateNode,t};var hp={bundleType:0,version:"19.2.4",rendererPackageName:"react-dom",currentDispatcherRef:E,reconcilerVersion:"19.2.4"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var _u=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!_u.isDisabled&&_u.supportsFiber)try{nn=_u.inject(hp),ie=_u}catch{}}return fi.createRoot=function(t,e){if(!f(t))throw Error(o(299));var a=!1,n="",l=hf,i=gf,r=mf;return e!=null&&(e.unstable_strictMode===!0&&(a=!0),e.identifierPrefix!==void 0&&(n=e.identifierPrefix),e.onUncaughtError!==void 0&&(l=e.onUncaughtError),e.onCaughtError!==void 0&&(i=e.onCaughtError),e.onRecoverableError!==void 0&&(r=e.onRecoverableError)),e=Jd(t,1,!1,null,null,a,n,null,l,i,r,ih),t[Mn]=e.current,Lo(t),new ec(e)},fi.hydrateRoot=function(t,e,a){if(!f(t))throw Error(o(299));var n=!1,l="",i=hf,r=gf,h=mf,y=null;return a!=null&&(a.unstable_strictMode===!0&&(n=!0),a.identifierPrefix!==void 0&&(l=a.identifierPrefix),a.onUncaughtError!==void 0&&(i=a.onUncaughtError),a.onCaughtError!==void 0&&(r=a.onCaughtError),a.onRecoverableError!==void 0&&(h=a.onRecoverableError),a.formState!==void 0&&(y=a.formState)),e=Jd(t,1,!0,e,a??null,n,l,y,i,r,h,ih),e.context=Fd(null),a=e.current,n=Ne(),n=Cn(n),l=ja(n),l.callback=null,Ha(a,l,n),a=n,e.current.lanes=a,Bt(e,a),ea(e),t[Mn]=e.current,Lo(t),new Mu(e)},fi.version="19.2.4",fi}var fh;function Fp(){if(fh)return ac.exports;fh=1;function c(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(c)}catch(u){console.error(u)}}return c(),ac.exports=Jp(),ac.exports}var $p=Fp();function Wp(c){if(typeof document>"u")return;let u=document.head||document.getElementsByTagName("head")[0],s=document.createElement("style");s.type="text/css",u.appendChild(s),s.styleSheet?s.styleSheet.cssText=c:s.appendChild(document.createTextNode(c))}const Ip=c=>{switch(c){case"success":return ey;case"info":return ny;case"warning":return ay;case"error":return ly;default:return null}},Pp=Array(12).fill(0),ty=({visible:c,className:u})=>L.createElement("div",{className:["sonner-loading-wrapper",u].filter(Boolean).join(" "),"data-visible":c},L.createElement("div",{className:"sonner-spinner"},Pp.map((s,o)=>L.createElement("div",{className:"sonner-loading-bar",key:`spinner-bar-${o}`})))),ey=L.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},L.createElement("path",{fillRule:"evenodd",d:"M10 18a8 8 0 100-16 8 8 0 000 16zm3.857-9.809a.75.75 0 00-1.214-.882l-3.483 4.79-1.88-1.88a.75.75 0 10-1.06 1.061l2.5 2.5a.75.75 0 001.137-.089l4-5.5z",clipRule:"evenodd"})),ay=L.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24",fill:"currentColor",height:"20",width:"20"},L.createElement("path",{fillRule:"evenodd",d:"M9.401 3.003c1.155-2 4.043-2 5.197 0l7.355 12.748c1.154 2-.29 4.5-2.599 4.5H4.645c-2.309 0-3.752-2.5-2.598-4.5L9.4 3.003zM12 8.25a.75.75 0 01.75.75v3.75a.75.75 0 01-1.5 0V9a.75.75 0 01.75-.75zm0 8.25a.75.75 0 100-1.5.75.75 0 000 1.5z",clipRule:"evenodd"})),ny=L.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},L.createElement("path",{fillRule:"evenodd",d:"M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-7-4a1 1 0 11-2 0 1 1 0 012 0zM9 9a.75.75 0 000 1.5h.253a.25.25 0 01.244.304l-.459 2.066A1.75 1.75 0 0010.747 15H11a.75.75 0 000-1.5h-.253a.25.25 0 01-.244-.304l.459-2.066A1.75 1.75 0 009.253 9H9z",clipRule:"evenodd"})),ly=L.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},L.createElement("path",{fillRule:"evenodd",d:"M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-8-5a.75.75 0 01.75.75v4.5a.75.75 0 01-1.5 0v-4.5A.75.75 0 0110 5zm0 10a1 1 0 100-2 1 1 0 000 2z",clipRule:"evenodd"})),iy=L.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"12",height:"12",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"1.5",strokeLinecap:"round",strokeLinejoin:"round"},L.createElement("line",{x1:"18",y1:"6",x2:"6",y2:"18"}),L.createElement("line",{x1:"6",y1:"6",x2:"18",y2:"18"})),uy=()=>{const[c,u]=L.useState(document.hidden);return L.useEffect(()=>{const s=()=>{u(document.hidden)};return document.addEventListener("visibilitychange",s),()=>window.removeEventListener("visibilitychange",s)},[]),c};let rc=1;class sy{constructor(){this.subscribe=u=>(this.subscribers.push(u),()=>{const s=this.subscribers.indexOf(u);this.subscribers.splice(s,1)}),this.publish=u=>{this.subscribers.forEach(s=>s(u))},this.addToast=u=>{this.publish(u),this.toasts=[...this.toasts,u]},this.create=u=>{var s;const{message:o,...f}=u,d=typeof(u==null?void 0:u.id)=="number"||((s=u.id)==null?void 0:s.length)>0?u.id:rc++,m=this.toasts.find(S=>S.id===d),p=u.dismissible===void 0?!0:u.dismissible;return this.dismissedToasts.has(d)&&this.dismissedToasts.delete(d),m?this.toasts=this.toasts.map(S=>S.id===d?(this.publish({...S,...u,id:d,title:o}),{...S,...u,id:d,dismissible:p,title:o}):S):this.addToast({title:o,...f,dismissible:p,id:d}),d},this.dismiss=u=>(u?(this.dismissedToasts.add(u),requestAnimationFrame(()=>this.subscribers.forEach(s=>s({id:u,dismiss:!0})))):this.toasts.forEach(s=>{this.subscribers.forEach(o=>o({id:s.id,dismiss:!0}))}),u),this.message=(u,s)=>this.create({...s,message:u}),this.error=(u,s)=>this.create({...s,message:u,type:"error"}),this.success=(u,s)=>this.create({...s,type:"success",message:u}),this.info=(u,s)=>this.create({...s,type:"info",message:u}),this.warning=(u,s)=>this.create({...s,type:"warning",message:u}),this.loading=(u,s)=>this.create({...s,type:"loading",message:u}),this.promise=(u,s)=>{if(!s)return;let o;s.loading!==void 0&&(o=this.create({...s,promise:u,type:"loading",message:s.loading,description:typeof s.description!="function"?s.description:void 0}));const f=Promise.resolve(u instanceof Function?u():u);let d=o!==void 0,m;const p=f.then(async v=>{if(m=["resolve",v],L.isValidElement(v))d=!1,this.create({id:o,type:"default",message:v});else if(cy(v)&&!v.ok){d=!1;const g=typeof s.error=="function"?await s.error(`HTTP error! status: ${v.status}`):s.error,R=typeof s.description=="function"?await s.description(`HTTP error! status: ${v.status}`):s.description,M=typeof g=="object"&&!L.isValidElement(g)?g:{message:g};this.create({id:o,type:"error",description:R,...M})}else if(v instanceof Error){d=!1;const g=typeof s.error=="function"?await s.error(v):s.error,R=typeof s.description=="function"?await s.description(v):s.description,M=typeof g=="object"&&!L.isValidElement(g)?g:{message:g};this.create({id:o,type:"error",description:R,...M})}else if(s.success!==void 0){d=!1;const g=typeof s.success=="function"?await s.success(v):s.success,R=typeof s.description=="function"?await s.description(v):s.description,M=typeof g=="object"&&!L.isValidElement(g)?g:{message:g};this.create({id:o,type:"success",description:R,...M})}}).catch(async v=>{if(m=["reject",v],s.error!==void 0){d=!1;const N=typeof s.error=="function"?await s.error(v):s.error,g=typeof s.description=="function"?await s.description(v):s.description,B=typeof N=="object"&&!L.isValidElement(N)?N:{message:N};this.create({id:o,type:"error",description:g,...B})}}).finally(()=>{d&&(this.dismiss(o),o=void 0),s.finally==null||s.finally.call(s)}),S=()=>new Promise((v,N)=>p.then(()=>m[0]==="reject"?N(m[1]):v(m[1])).catch(N));return typeof o!="string"&&typeof o!="number"?{unwrap:S}:Object.assign(o,{unwrap:S})},this.custom=(u,s)=>{const o=(s==null?void 0:s.id)||rc++;return this.create({jsx:u(o),id:o,...s}),o},this.getActiveToasts=()=>this.toasts.filter(u=>!this.dismissedToasts.has(u.id)),this.subscribers=[],this.toasts=[],this.dismissedToasts=new Set}}const be=new sy,oy=(c,u)=>{const s=(u==null?void 0:u.id)||rc++;return be.addToast({title:c,...u,id:s}),s},cy=c=>c&&typeof c=="object"&&"ok"in c&&typeof c.ok=="boolean"&&"status"in c&&typeof c.status=="number",ry=oy,fy=()=>be.toasts,dy=()=>be.getActiveToasts(),Kv=Object.assign(ry,{success:be.success,info:be.info,warning:be.warning,error:be.error,custom:be.custom,message:be.message,promise:be.promise,dismiss:be.dismiss,loading:be.loading},{getHistory:fy,getToasts:dy});Wp("[data-sonner-toaster][dir=ltr],html[dir=ltr]{--toast-icon-margin-start:-3px;--toast-icon-margin-end:4px;--toast-svg-margin-start:-1px;--toast-svg-margin-end:0px;--toast-button-margin-start:auto;--toast-button-margin-end:0;--toast-close-button-start:0;--toast-close-button-end:unset;--toast-close-button-transform:translate(-35%, -35%)}[data-sonner-toaster][dir=rtl],html[dir=rtl]{--toast-icon-margin-start:4px;--toast-icon-margin-end:-3px;--toast-svg-margin-start:0px;--toast-svg-margin-end:-1px;--toast-button-margin-start:0;--toast-button-margin-end:auto;--toast-close-button-start:unset;--toast-close-button-end:0;--toast-close-button-transform:translate(35%, -35%)}[data-sonner-toaster]{position:fixed;width:var(--width);font-family:ui-sans-serif,system-ui,-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica Neue,Arial,Noto Sans,sans-serif,Apple Color Emoji,Segoe UI Emoji,Segoe UI Symbol,Noto Color Emoji;--gray1:hsl(0, 0%, 99%);--gray2:hsl(0, 0%, 97.3%);--gray3:hsl(0, 0%, 95.1%);--gray4:hsl(0, 0%, 93%);--gray5:hsl(0, 0%, 90.9%);--gray6:hsl(0, 0%, 88.7%);--gray7:hsl(0, 0%, 85.8%);--gray8:hsl(0, 0%, 78%);--gray9:hsl(0, 0%, 56.1%);--gray10:hsl(0, 0%, 52.3%);--gray11:hsl(0, 0%, 43.5%);--gray12:hsl(0, 0%, 9%);--border-radius:8px;box-sizing:border-box;padding:0;margin:0;list-style:none;outline:0;z-index:999999999;transition:transform .4s ease}@media (hover:none) and (pointer:coarse){[data-sonner-toaster][data-lifted=true]{transform:none}}[data-sonner-toaster][data-x-position=right]{right:var(--offset-right)}[data-sonner-toaster][data-x-position=left]{left:var(--offset-left)}[data-sonner-toaster][data-x-position=center]{left:50%;transform:translateX(-50%)}[data-sonner-toaster][data-y-position=top]{top:var(--offset-top)}[data-sonner-toaster][data-y-position=bottom]{bottom:var(--offset-bottom)}[data-sonner-toast]{--y:translateY(100%);--lift-amount:calc(var(--lift) * var(--gap));z-index:var(--z-index);position:absolute;opacity:0;transform:var(--y);touch-action:none;transition:transform .4s,opacity .4s,height .4s,box-shadow .2s;box-sizing:border-box;outline:0;overflow-wrap:anywhere}[data-sonner-toast][data-styled=true]{padding:16px;background:var(--normal-bg);border:1px solid var(--normal-border);color:var(--normal-text);border-radius:var(--border-radius);box-shadow:0 4px 12px rgba(0,0,0,.1);width:var(--width);font-size:13px;display:flex;align-items:center;gap:6px}[data-sonner-toast]:focus-visible{box-shadow:0 4px 12px rgba(0,0,0,.1),0 0 0 2px rgba(0,0,0,.2)}[data-sonner-toast][data-y-position=top]{top:0;--y:translateY(-100%);--lift:1;--lift-amount:calc(1 * var(--gap))}[data-sonner-toast][data-y-position=bottom]{bottom:0;--y:translateY(100%);--lift:-1;--lift-amount:calc(var(--lift) * var(--gap))}[data-sonner-toast][data-styled=true] [data-description]{font-weight:400;line-height:1.4;color:#3f3f3f}[data-rich-colors=true][data-sonner-toast][data-styled=true] [data-description]{color:inherit}[data-sonner-toaster][data-sonner-theme=dark] [data-description]{color:#e8e8e8}[data-sonner-toast][data-styled=true] [data-title]{font-weight:500;line-height:1.5;color:inherit}[data-sonner-toast][data-styled=true] [data-icon]{display:flex;height:16px;width:16px;position:relative;justify-content:flex-start;align-items:center;flex-shrink:0;margin-left:var(--toast-icon-margin-start);margin-right:var(--toast-icon-margin-end)}[data-sonner-toast][data-promise=true] [data-icon]>svg{opacity:0;transform:scale(.8);transform-origin:center;animation:sonner-fade-in .3s ease forwards}[data-sonner-toast][data-styled=true] [data-icon]>*{flex-shrink:0}[data-sonner-toast][data-styled=true] [data-icon] svg{margin-left:var(--toast-svg-margin-start);margin-right:var(--toast-svg-margin-end)}[data-sonner-toast][data-styled=true] [data-content]{display:flex;flex-direction:column;gap:2px}[data-sonner-toast][data-styled=true] [data-button]{border-radius:4px;padding-left:8px;padding-right:8px;height:24px;font-size:12px;color:var(--normal-bg);background:var(--normal-text);margin-left:var(--toast-button-margin-start);margin-right:var(--toast-button-margin-end);border:none;font-weight:500;cursor:pointer;outline:0;display:flex;align-items:center;flex-shrink:0;transition:opacity .4s,box-shadow .2s}[data-sonner-toast][data-styled=true] [data-button]:focus-visible{box-shadow:0 0 0 2px rgba(0,0,0,.4)}[data-sonner-toast][data-styled=true] [data-button]:first-of-type{margin-left:var(--toast-button-margin-start);margin-right:var(--toast-button-margin-end)}[data-sonner-toast][data-styled=true] [data-cancel]{color:var(--normal-text);background:rgba(0,0,0,.08)}[data-sonner-toaster][data-sonner-theme=dark] [data-sonner-toast][data-styled=true] [data-cancel]{background:rgba(255,255,255,.3)}[data-sonner-toast][data-styled=true] [data-close-button]{position:absolute;left:var(--toast-close-button-start);right:var(--toast-close-button-end);top:0;height:20px;width:20px;display:flex;justify-content:center;align-items:center;padding:0;color:var(--gray12);background:var(--normal-bg);border:1px solid var(--gray4);transform:var(--toast-close-button-transform);border-radius:50%;cursor:pointer;z-index:1;transition:opacity .1s,background .2s,border-color .2s}[data-sonner-toast][data-styled=true] [data-close-button]:focus-visible{box-shadow:0 4px 12px rgba(0,0,0,.1),0 0 0 2px rgba(0,0,0,.2)}[data-sonner-toast][data-styled=true] [data-disabled=true]{cursor:not-allowed}[data-sonner-toast][data-styled=true]:hover [data-close-button]:hover{background:var(--gray2);border-color:var(--gray5)}[data-sonner-toast][data-swiping=true]::before{content:'';position:absolute;left:-100%;right:-100%;height:100%;z-index:-1}[data-sonner-toast][data-y-position=top][data-swiping=true]::before{bottom:50%;transform:scaleY(3) translateY(50%)}[data-sonner-toast][data-y-position=bottom][data-swiping=true]::before{top:50%;transform:scaleY(3) translateY(-50%)}[data-sonner-toast][data-swiping=false][data-removed=true]::before{content:'';position:absolute;inset:0;transform:scaleY(2)}[data-sonner-toast][data-expanded=true]::after{content:'';position:absolute;left:0;height:calc(var(--gap) + 1px);bottom:100%;width:100%}[data-sonner-toast][data-mounted=true]{--y:translateY(0);opacity:1}[data-sonner-toast][data-expanded=false][data-front=false]{--scale:var(--toasts-before) * 0.05 + 1;--y:translateY(calc(var(--lift-amount) * var(--toasts-before))) scale(calc(-1 * var(--scale)));height:var(--front-toast-height)}[data-sonner-toast]>*{transition:opacity .4s}[data-sonner-toast][data-x-position=right]{right:0}[data-sonner-toast][data-x-position=left]{left:0}[data-sonner-toast][data-expanded=false][data-front=false][data-styled=true]>*{opacity:0}[data-sonner-toast][data-visible=false]{opacity:0;pointer-events:none}[data-sonner-toast][data-mounted=true][data-expanded=true]{--y:translateY(calc(var(--lift) * var(--offset)));height:var(--initial-height)}[data-sonner-toast][data-removed=true][data-front=true][data-swipe-out=false]{--y:translateY(calc(var(--lift) * -100%));opacity:0}[data-sonner-toast][data-removed=true][data-front=false][data-swipe-out=false][data-expanded=true]{--y:translateY(calc(var(--lift) * var(--offset) + var(--lift) * -100%));opacity:0}[data-sonner-toast][data-removed=true][data-front=false][data-swipe-out=false][data-expanded=false]{--y:translateY(40%);opacity:0;transition:transform .5s,opacity .2s}[data-sonner-toast][data-removed=true][data-front=false]::before{height:calc(var(--initial-height) + 20%)}[data-sonner-toast][data-swiping=true]{transform:var(--y) translateY(var(--swipe-amount-y,0)) translateX(var(--swipe-amount-x,0));transition:none}[data-sonner-toast][data-swiped=true]{user-select:none}[data-sonner-toast][data-swipe-out=true][data-y-position=bottom],[data-sonner-toast][data-swipe-out=true][data-y-position=top]{animation-duration:.2s;animation-timing-function:ease-out;animation-fill-mode:forwards}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=left]{animation-name:swipe-out-left}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=right]{animation-name:swipe-out-right}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=up]{animation-name:swipe-out-up}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=down]{animation-name:swipe-out-down}@keyframes swipe-out-left{from{transform:var(--y) translateX(var(--swipe-amount-x));opacity:1}to{transform:var(--y) translateX(calc(var(--swipe-amount-x) - 100%));opacity:0}}@keyframes swipe-out-right{from{transform:var(--y) translateX(var(--swipe-amount-x));opacity:1}to{transform:var(--y) translateX(calc(var(--swipe-amount-x) + 100%));opacity:0}}@keyframes swipe-out-up{from{transform:var(--y) translateY(var(--swipe-amount-y));opacity:1}to{transform:var(--y) translateY(calc(var(--swipe-amount-y) - 100%));opacity:0}}@keyframes swipe-out-down{from{transform:var(--y) translateY(var(--swipe-amount-y));opacity:1}to{transform:var(--y) translateY(calc(var(--swipe-amount-y) + 100%));opacity:0}}@media (max-width:600px){[data-sonner-toaster]{position:fixed;right:var(--mobile-offset-right);left:var(--mobile-offset-left);width:100%}[data-sonner-toaster][dir=rtl]{left:calc(var(--mobile-offset-left) * -1)}[data-sonner-toaster] [data-sonner-toast]{left:0;right:0;width:calc(100% - var(--mobile-offset-left) * 2)}[data-sonner-toaster][data-x-position=left]{left:var(--mobile-offset-left)}[data-sonner-toaster][data-y-position=bottom]{bottom:var(--mobile-offset-bottom)}[data-sonner-toaster][data-y-position=top]{top:var(--mobile-offset-top)}[data-sonner-toaster][data-x-position=center]{left:var(--mobile-offset-left);right:var(--mobile-offset-right);transform:none}}[data-sonner-toaster][data-sonner-theme=light]{--normal-bg:#fff;--normal-border:var(--gray4);--normal-text:var(--gray12);--success-bg:hsl(143, 85%, 96%);--success-border:hsl(145, 92%, 87%);--success-text:hsl(140, 100%, 27%);--info-bg:hsl(208, 100%, 97%);--info-border:hsl(221, 91%, 93%);--info-text:hsl(210, 92%, 45%);--warning-bg:hsl(49, 100%, 97%);--warning-border:hsl(49, 91%, 84%);--warning-text:hsl(31, 92%, 45%);--error-bg:hsl(359, 100%, 97%);--error-border:hsl(359, 100%, 94%);--error-text:hsl(360, 100%, 45%)}[data-sonner-toaster][data-sonner-theme=light] [data-sonner-toast][data-invert=true]{--normal-bg:#000;--normal-border:hsl(0, 0%, 20%);--normal-text:var(--gray1)}[data-sonner-toaster][data-sonner-theme=dark] [data-sonner-toast][data-invert=true]{--normal-bg:#fff;--normal-border:var(--gray3);--normal-text:var(--gray12)}[data-sonner-toaster][data-sonner-theme=dark]{--normal-bg:#000;--normal-bg-hover:hsl(0, 0%, 12%);--normal-border:hsl(0, 0%, 20%);--normal-border-hover:hsl(0, 0%, 25%);--normal-text:var(--gray1);--success-bg:hsl(150, 100%, 6%);--success-border:hsl(147, 100%, 12%);--success-text:hsl(150, 86%, 65%);--info-bg:hsl(215, 100%, 6%);--info-border:hsl(223, 43%, 17%);--info-text:hsl(216, 87%, 65%);--warning-bg:hsl(64, 100%, 6%);--warning-border:hsl(60, 100%, 9%);--warning-text:hsl(46, 87%, 65%);--error-bg:hsl(358, 76%, 10%);--error-border:hsl(357, 89%, 16%);--error-text:hsl(358, 100%, 81%)}[data-sonner-toaster][data-sonner-theme=dark] [data-sonner-toast] [data-close-button]{background:var(--normal-bg);border-color:var(--normal-border);color:var(--normal-text)}[data-sonner-toaster][data-sonner-theme=dark] [data-sonner-toast] [data-close-button]:hover{background:var(--normal-bg-hover);border-color:var(--normal-border-hover)}[data-rich-colors=true][data-sonner-toast][data-type=success]{background:var(--success-bg);border-color:var(--success-border);color:var(--success-text)}[data-rich-colors=true][data-sonner-toast][data-type=success] [data-close-button]{background:var(--success-bg);border-color:var(--success-border);color:var(--success-text)}[data-rich-colors=true][data-sonner-toast][data-type=info]{background:var(--info-bg);border-color:var(--info-border);color:var(--info-text)}[data-rich-colors=true][data-sonner-toast][data-type=info] [data-close-button]{background:var(--info-bg);border-color:var(--info-border);color:var(--info-text)}[data-rich-colors=true][data-sonner-toast][data-type=warning]{background:var(--warning-bg);border-color:var(--warning-border);color:var(--warning-text)}[data-rich-colors=true][data-sonner-toast][data-type=warning] [data-close-button]{background:var(--warning-bg);border-color:var(--warning-border);color:var(--warning-text)}[data-rich-colors=true][data-sonner-toast][data-type=error]{background:var(--error-bg);border-color:var(--error-border);color:var(--error-text)}[data-rich-colors=true][data-sonner-toast][data-type=error] [data-close-button]{background:var(--error-bg);border-color:var(--error-border);color:var(--error-text)}.sonner-loading-wrapper{--size:16px;height:var(--size);width:var(--size);position:absolute;inset:0;z-index:10}.sonner-loading-wrapper[data-visible=false]{transform-origin:center;animation:sonner-fade-out .2s ease forwards}.sonner-spinner{position:relative;top:50%;left:50%;height:var(--size);width:var(--size)}.sonner-loading-bar{animation:sonner-spin 1.2s linear infinite;background:var(--gray11);border-radius:6px;height:8%;left:-10%;position:absolute;top:-3.9%;width:24%}.sonner-loading-bar:first-child{animation-delay:-1.2s;transform:rotate(.0001deg) translate(146%)}.sonner-loading-bar:nth-child(2){animation-delay:-1.1s;transform:rotate(30deg) translate(146%)}.sonner-loading-bar:nth-child(3){animation-delay:-1s;transform:rotate(60deg) translate(146%)}.sonner-loading-bar:nth-child(4){animation-delay:-.9s;transform:rotate(90deg) translate(146%)}.sonner-loading-bar:nth-child(5){animation-delay:-.8s;transform:rotate(120deg) translate(146%)}.sonner-loading-bar:nth-child(6){animation-delay:-.7s;transform:rotate(150deg) translate(146%)}.sonner-loading-bar:nth-child(7){animation-delay:-.6s;transform:rotate(180deg) translate(146%)}.sonner-loading-bar:nth-child(8){animation-delay:-.5s;transform:rotate(210deg) translate(146%)}.sonner-loading-bar:nth-child(9){animation-delay:-.4s;transform:rotate(240deg) translate(146%)}.sonner-loading-bar:nth-child(10){animation-delay:-.3s;transform:rotate(270deg) translate(146%)}.sonner-loading-bar:nth-child(11){animation-delay:-.2s;transform:rotate(300deg) translate(146%)}.sonner-loading-bar:nth-child(12){animation-delay:-.1s;transform:rotate(330deg) translate(146%)}@keyframes sonner-fade-in{0%{opacity:0;transform:scale(.8)}100%{opacity:1;transform:scale(1)}}@keyframes sonner-fade-out{0%{opacity:1;transform:scale(1)}100%{opacity:0;transform:scale(.8)}}@keyframes sonner-spin{0%{opacity:1}100%{opacity:.15}}@media (prefers-reduced-motion){.sonner-loading-bar,[data-sonner-toast],[data-sonner-toast]>*{transition:none!important;animation:none!important}}.sonner-loader{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);transform-origin:center;transition:opacity .2s,transform .2s}.sonner-loader[data-visible=false]{opacity:0;transform:scale(.8) translate(-50%,-50%)}");function Ru(c){return c.label!==void 0}const hy=3,gy="24px",my="16px",dh=4e3,py=356,yy=14,vy=45,by=200;function aa(...c){return c.filter(Boolean).join(" ")}function Sy(c){const[u,s]=c.split("-"),o=[];return u&&o.push(u),s&&o.push(s),o}const xy=c=>{var u,s,o,f,d,m,p,S,v;const{invert:N,toast:g,unstyled:R,interacting:B,setHeights:M,visibleToasts:V,heights:et,index:Q,toasts:Dt,expanded:ft,removeToast:ht,defaultRichColors:At,closeButton:vt,style:Tt,cancelButtonStyle:Nt,actionButtonStyle:Ct,className:yt="",descriptionClassName:ae="",duration:k,position:Z,gap:W,expandByDefault:ut,classNames:E,icons:U,closeButtonAriaLabel:q="Close toast"}=c,[at,tt]=L.useState(null),[nt,st]=L.useState(null),[j,$]=L.useState(!1),[ot,Ht]=L.useState(!1),[Ge,bt]=L.useState(!1),[Se,Da]=L.useState(!1),[ua,Fe]=L.useState(!1),[yi,Qe]=L.useState(0),[pl,Dn]=L.useState(0),tn=L.useRef(g.duration||k||dh),yl=L.useRef(null),xe=L.useRef(null),vl=Q===0,bl=Q+1<=V,ne=g.type,Aa=g.dismissible!==!1,le=g.className||"",Qu=g.descriptionClassName||"",en=L.useMemo(()=>et.findIndex(J=>J.toastId===g.id)||0,[et,g.id]),vi=L.useMemo(()=>{var J;return(J=g.closeButton)!=null?J:vt},[g.closeButton,vt]),an=L.useMemo(()=>g.duration||k||dh,[g.duration,k]),Sl=L.useRef(0),sa=L.useRef(0),bi=L.useRef(0),Na=L.useRef(null),[nn,ie]=Z.split("-"),Xe=L.useMemo(()=>et.reduce((J,Ut,Zt)=>Zt>=en?J:J+Ut.height,0),[et,en]),te=uy(),Xu=g.invert||N,xl=ne==="loading";sa.current=L.useMemo(()=>en*W+Xe,[en,Xe]),L.useEffect(()=>{tn.current=an},[an]),L.useEffect(()=>{$(!0)},[]),L.useEffect(()=>{const J=xe.current;if(J){const Ut=J.getBoundingClientRect().height;return Dn(Ut),M(Zt=>[{toastId:g.id,height:Ut,position:g.position},...Zt]),()=>M(Zt=>Zt.filter(ee=>ee.toastId!==g.id))}},[M,g.id]),L.useLayoutEffect(()=>{if(!j)return;const J=xe.current,Ut=J.style.height;J.style.height="auto";const Zt=J.getBoundingClientRect().height;J.style.height=Ut,Dn(Zt),M(ee=>ee.find(Bt=>Bt.toastId===g.id)?ee.map(Bt=>Bt.toastId===g.id?{...Bt,height:Zt}:Bt):[{toastId:g.id,height:Zt,position:g.position},...ee])},[j,g.title,g.description,M,g.id,g.jsx,g.action,g.cancel]);const $e=L.useCallback(()=>{Ht(!0),Qe(sa.current),M(J=>J.filter(Ut=>Ut.toastId!==g.id)),setTimeout(()=>{ht(g)},by)},[g,ht,M,sa]);L.useEffect(()=>{if(g.promise&&ne==="loading"||g.duration===1/0||g.type==="loading")return;let J;return ft||B||te?(()=>{if(bi.current<Sl.current){const ee=new Date().getTime()-Sl.current;tn.current=tn.current-ee}bi.current=new Date().getTime()})():(()=>{tn.current!==1/0&&(Sl.current=new Date().getTime(),J=setTimeout(()=>{g.onAutoClose==null||g.onAutoClose.call(g,g),$e()},tn.current))})(),()=>clearTimeout(J)},[ft,B,g,ne,te,$e]),L.useEffect(()=>{g.delete&&($e(),g.onDismiss==null||g.onDismiss.call(g,g))},[$e,g.delete]);function An(){var J;if(U!=null&&U.loading){var Ut;return L.createElement("div",{className:aa(E==null?void 0:E.loader,g==null||(Ut=g.classNames)==null?void 0:Ut.loader,"sonner-loader"),"data-visible":ne==="loading"},U.loading)}return L.createElement(ty,{className:aa(E==null?void 0:E.loader,g==null||(J=g.classNames)==null?void 0:J.loader),visible:ne==="loading"})}const Nn=g.icon||(U==null?void 0:U[ne])||Ip(ne);var ln,We;return L.createElement("li",{tabIndex:0,ref:xe,className:aa(yt,le,E==null?void 0:E.toast,g==null||(u=g.classNames)==null?void 0:u.toast,E==null?void 0:E.default,E==null?void 0:E[ne],g==null||(s=g.classNames)==null?void 0:s[ne]),"data-sonner-toast":"","data-rich-colors":(ln=g.richColors)!=null?ln:At,"data-styled":!(g.jsx||g.unstyled||R),"data-mounted":j,"data-promise":!!g.promise,"data-swiped":ua,"data-removed":ot,"data-visible":bl,"data-y-position":nn,"data-x-position":ie,"data-index":Q,"data-front":vl,"data-swiping":Ge,"data-dismissible":Aa,"data-type":ne,"data-invert":Xu,"data-swipe-out":Se,"data-swipe-direction":nt,"data-expanded":!!(ft||ut&&j),"data-testid":g.testId,style:{"--index":Q,"--toasts-before":Q,"--z-index":Dt.length-Q,"--offset":`${ot?yi:sa.current}px`,"--initial-height":ut?"auto":`${pl}px`,...Tt,...g.style},onDragEnd:()=>{bt(!1),tt(null),Na.current=null},onPointerDown:J=>{J.button!==2&&(xl||!Aa||(yl.current=new Date,Qe(sa.current),J.target.setPointerCapture(J.pointerId),J.target.tagName!=="BUTTON"&&(bt(!0),Na.current={x:J.clientX,y:J.clientY})))},onPointerUp:()=>{var J,Ut,Zt;if(Se||!Aa)return;Na.current=null;const ee=Number(((J=xe.current)==null?void 0:J.style.getPropertyValue("--swipe-amount-x").replace("px",""))||0),Ca=Number(((Ut=xe.current)==null?void 0:Ut.style.getPropertyValue("--swipe-amount-y").replace("px",""))||0),Bt=new Date().getTime()-((Zt=yl.current)==null?void 0:Zt.getTime()),ce=at==="x"?ee:Ca,un=Math.abs(ce)/Bt;if(Math.abs(ce)>=vy||un>.11){Qe(sa.current),g.onDismiss==null||g.onDismiss.call(g,g),st(at==="x"?ee>0?"right":"left":Ca>0?"down":"up"),$e(),Da(!0);return}else{var re,fe;(re=xe.current)==null||re.style.setProperty("--swipe-amount-x","0px"),(fe=xe.current)==null||fe.style.setProperty("--swipe-amount-y","0px")}Fe(!1),bt(!1),tt(null)},onPointerMove:J=>{var Ut,Zt,ee;if(!Na.current||!Aa||((Ut=window.getSelection())==null?void 0:Ut.toString().length)>0)return;const Bt=J.clientY-Na.current.y,ce=J.clientX-Na.current.x;var un;const re=(un=c.swipeDirections)!=null?un:Sy(Z);!at&&(Math.abs(ce)>1||Math.abs(Bt)>1)&&tt(Math.abs(ce)>Math.abs(Bt)?"x":"y");let fe={x:0,y:0};const Cn=Ke=>1/(1.5+Math.abs(Ke)/20);if(at==="y"){if(re.includes("top")||re.includes("bottom"))if(re.includes("top")&&Bt<0||re.includes("bottom")&&Bt>0)fe.y=Bt;else{const Ke=Bt*Cn(Bt);fe.y=Math.abs(Ke)<Math.abs(Bt)?Ke:Bt}}else if(at==="x"&&(re.includes("left")||re.includes("right")))if(re.includes("left")&&ce<0||re.includes("right")&&ce>0)fe.x=ce;else{const Ke=ce*Cn(ce);fe.x=Math.abs(Ke)<Math.abs(ce)?Ke:ce}(Math.abs(fe.x)>0||Math.abs(fe.y)>0)&&Fe(!0),(Zt=xe.current)==null||Zt.style.setProperty("--swipe-amount-x",`${fe.x}px`),(ee=xe.current)==null||ee.style.setProperty("--swipe-amount-y",`${fe.y}px`)}},vi&&!g.jsx&&ne!=="loading"?L.createElement("button",{"aria-label":q,"data-disabled":xl,"data-close-button":!0,onClick:xl||!Aa?()=>{}:()=>{$e(),g.onDismiss==null||g.onDismiss.call(g,g)},className:aa(E==null?void 0:E.closeButton,g==null||(o=g.classNames)==null?void 0:o.closeButton)},(We=U==null?void 0:U.close)!=null?We:iy):null,(ne||g.icon||g.promise)&&g.icon!==null&&((U==null?void 0:U[ne])!==null||g.icon)?L.createElement("div",{"data-icon":"",className:aa(E==null?void 0:E.icon,g==null||(f=g.classNames)==null?void 0:f.icon)},g.promise||g.type==="loading"&&!g.icon?g.icon||An():null,g.type!=="loading"?Nn:null):null,L.createElement("div",{"data-content":"",className:aa(E==null?void 0:E.content,g==null||(d=g.classNames)==null?void 0:d.content)},L.createElement("div",{"data-title":"",className:aa(E==null?void 0:E.title,g==null||(m=g.classNames)==null?void 0:m.title)},g.jsx?g.jsx:typeof g.title=="function"?g.title():g.title),g.description?L.createElement("div",{"data-description":"",className:aa(ae,Qu,E==null?void 0:E.description,g==null||(p=g.classNames)==null?void 0:p.description)},typeof g.description=="function"?g.description():g.description):null),L.isValidElement(g.cancel)?g.cancel:g.cancel&&Ru(g.cancel)?L.createElement("button",{"data-button":!0,"data-cancel":!0,style:g.cancelButtonStyle||Nt,onClick:J=>{Ru(g.cancel)&&Aa&&(g.cancel.onClick==null||g.cancel.onClick.call(g.cancel,J),$e())},className:aa(E==null?void 0:E.cancelButton,g==null||(S=g.classNames)==null?void 0:S.cancelButton)},g.cancel.label):null,L.isValidElement(g.action)?g.action:g.action&&Ru(g.action)?L.createElement("button",{"data-button":!0,"data-action":!0,style:g.actionButtonStyle||Ct,onClick:J=>{Ru(g.action)&&(g.action.onClick==null||g.action.onClick.call(g.action,J),!J.defaultPrevented&&$e())},className:aa(E==null?void 0:E.actionButton,g==null||(v=g.classNames)==null?void 0:v.actionButton)},g.action.label):null)};function hh(){if(typeof window>"u"||typeof document>"u")return"ltr";const c=document.documentElement.getAttribute("dir");return c==="auto"||!c?window.getComputedStyle(document.documentElement).direction:c}function Ty(c,u){const s={};return[c,u].forEach((o,f)=>{const d=f===1,m=d?"--mobile-offset":"--offset",p=d?my:gy;function S(v){["top","right","bottom","left"].forEach(N=>{s[`${m}-${N}`]=typeof v=="number"?`${v}px`:v})}typeof o=="number"||typeof o=="string"?S(o):typeof o=="object"?["top","right","bottom","left"].forEach(v=>{o[v]===void 0?s[`${m}-${v}`]=p:s[`${m}-${v}`]=typeof o[v]=="number"?`${o[v]}px`:o[v]}):S(p)}),s}const Ey=L.forwardRef(function(u,s){const{id:o,invert:f,position:d="bottom-right",hotkey:m=["altKey","KeyT"],expand:p,closeButton:S,className:v,offset:N,mobileOffset:g,theme:R="light",richColors:B,duration:M,style:V,visibleToasts:et=hy,toastOptions:Q,dir:Dt=hh(),gap:ft=yy,icons:ht,containerAriaLabel:At="Notifications"}=u,[vt,Tt]=L.useState([]),Nt=L.useMemo(()=>o?vt.filter(j=>j.toasterId===o):vt.filter(j=>!j.toasterId),[vt,o]),Ct=L.useMemo(()=>Array.from(new Set([d].concat(Nt.filter(j=>j.position).map(j=>j.position)))),[Nt,d]),[yt,ae]=L.useState([]),[k,Z]=L.useState(!1),[W,ut]=L.useState(!1),[E,U]=L.useState(R!=="system"?R:typeof window<"u"&&window.matchMedia&&window.matchMedia("(prefers-color-scheme: dark)").matches?"dark":"light"),q=L.useRef(null),at=m.join("+").replace(/Key/g,"").replace(/Digit/g,""),tt=L.useRef(null),nt=L.useRef(!1),st=L.useCallback(j=>{Tt($=>{var ot;return(ot=$.find(Ht=>Ht.id===j.id))!=null&&ot.delete||be.dismiss(j.id),$.filter(({id:Ht})=>Ht!==j.id)})},[]);return L.useEffect(()=>be.subscribe(j=>{if(j.dismiss){requestAnimationFrame(()=>{Tt($=>$.map(ot=>ot.id===j.id?{...ot,delete:!0}:ot))});return}setTimeout(()=>{Sp.flushSync(()=>{Tt($=>{const ot=$.findIndex(Ht=>Ht.id===j.id);return ot!==-1?[...$.slice(0,ot),{...$[ot],...j},...$.slice(ot+1)]:[j,...$]})})})}),[vt]),L.useEffect(()=>{if(R!=="system"){U(R);return}if(R==="system"&&(window.matchMedia&&window.matchMedia("(prefers-color-scheme: dark)").matches?U("dark"):U("light")),typeof window>"u")return;const j=window.matchMedia("(prefers-color-scheme: dark)");try{j.addEventListener("change",({matches:$})=>{U($?"dark":"light")})}catch{j.addListener(({matches:ot})=>{try{U(ot?"dark":"light")}catch(Ht){console.error(Ht)}})}},[R]),L.useEffect(()=>{vt.length<=1&&Z(!1)},[vt]),L.useEffect(()=>{const j=$=>{var ot;if(m.every(bt=>$[bt]||$.code===bt)){var Ge;Z(!0),(Ge=q.current)==null||Ge.focus()}$.code==="Escape"&&(document.activeElement===q.current||(ot=q.current)!=null&&ot.contains(document.activeElement))&&Z(!1)};return document.addEventListener("keydown",j),()=>document.removeEventListener("keydown",j)},[m]),L.useEffect(()=>{if(q.current)return()=>{tt.current&&(tt.current.focus({preventScroll:!0}),tt.current=null,nt.current=!1)}},[q.current]),L.createElement("section",{ref:s,"aria-label":`${At} ${at}`,tabIndex:-1,"aria-live":"polite","aria-relevant":"additions text","aria-atomic":"false",suppressHydrationWarning:!0},Ct.map((j,$)=>{var ot;const[Ht,Ge]=j.split("-");return Nt.length?L.createElement("ol",{key:j,dir:Dt==="auto"?hh():Dt,tabIndex:-1,ref:q,className:v,"data-sonner-toaster":!0,"data-sonner-theme":E,"data-y-position":Ht,"data-x-position":Ge,style:{"--front-toast-height":`${((ot=yt[0])==null?void 0:ot.height)||0}px`,"--width":`${py}px`,"--gap":`${ft}px`,...V,...Ty(N,g)},onBlur:bt=>{nt.current&&!bt.currentTarget.contains(bt.relatedTarget)&&(nt.current=!1,tt.current&&(tt.current.focus({preventScroll:!0}),tt.current=null))},onFocus:bt=>{bt.target instanceof HTMLElement&&bt.target.dataset.dismissible==="false"||nt.current||(nt.current=!0,tt.current=bt.relatedTarget)},onMouseEnter:()=>Z(!0),onMouseMove:()=>Z(!0),onMouseLeave:()=>{W||Z(!1)},onDragEnd:()=>Z(!1),onPointerDown:bt=>{bt.target instanceof HTMLElement&&bt.target.dataset.dismissible==="false"||ut(!0)},onPointerUp:()=>ut(!1)},Nt.filter(bt=>!bt.position&&$===0||bt.position===j).map((bt,Se)=>{var Da,ua;return L.createElement(xy,{key:bt.id,icons:ht,index:Se,toast:bt,defaultRichColors:B,duration:(Da=Q==null?void 0:Q.duration)!=null?Da:M,className:Q==null?void 0:Q.className,descriptionClassName:Q==null?void 0:Q.descriptionClassName,invert:f,visibleToasts:et,closeButton:(ua=Q==null?void 0:Q.closeButton)!=null?ua:S,interacting:W,position:j,style:Q==null?void 0:Q.style,unstyled:Q==null?void 0:Q.unstyled,classNames:Q==null?void 0:Q.classNames,cancelButtonStyle:Q==null?void 0:Q.cancelButtonStyle,actionButtonStyle:Q==null?void 0:Q.actionButtonStyle,closeButtonAriaLabel:Q==null?void 0:Q.closeButtonAriaLabel,removeToast:st,toasts:Nt.filter(Fe=>Fe.position==bt.position),heights:yt.filter(Fe=>Fe.position==bt.position),setHeights:ae,expandByDefault:p,gap:ft,expanded:k,swipeDirections:u.swipeDirections})})):null}))}),Oy="modulepreload",zy=function(c){return"/"+c},gh={},ia=function(u,s,o){let f=Promise.resolve();if(s&&s.length>0){let m=function(v){return Promise.all(v.map(N=>Promise.resolve(N).then(g=>({status:"fulfilled",value:g}),g=>({status:"rejected",reason:g}))))};document.getElementsByTagName("link");const p=document.querySelector("meta[property=csp-nonce]"),S=(p==null?void 0:p.nonce)||(p==null?void 0:p.getAttribute("nonce"));f=m(s.map(v=>{if(v=zy(v),v in gh)return;gh[v]=!0;const N=v.endsWith(".css"),g=N?'[rel="stylesheet"]':"";if(document.querySelector(`link[href="${v}"]${g}`))return;const R=document.createElement("link");if(R.rel=N?"stylesheet":Oy,N||(R.as="script"),R.crossOrigin="",R.href=v,S&&R.setAttribute("nonce",S),document.head.appendChild(R),N)return new Promise((B,M)=>{R.addEventListener("load",B),R.addEventListener("error",()=>M(new Error(`Unable to preload CSS for ${v}`)))})}))}function d(m){const p=new Event("vite:preloadError",{cancelable:!0});if(p.payload=m,window.dispatchEvent(p),!p.defaultPrevented)throw m}return f.then(m=>{for(const p of m||[])p.status==="rejected"&&d(p.reason);return u().catch(d)})};function mi(...c){return Ap(Np(c))}const mh=c=>{let u;const s=new Set,o=(v,N)=>{const g=typeof v=="function"?v(u):v;if(!Object.is(g,u)){const R=u;u=N??(typeof g!="object"||g===null)?g:Object.assign({},u,g),s.forEach(B=>B(u,R))}},f=()=>u,p={setState:o,getState:f,getInitialState:()=>S,subscribe:v=>(s.add(v),()=>s.delete(v))},S=u=c(o,f,p);return p},Dy=(c=>c?mh(c):mh),Ay=c=>c;function Ny(c,u=Ay){const s=L.useSyncExternalStore(c.subscribe,L.useCallback(()=>u(c.getState()),[c,u]),L.useCallback(()=>u(c.getInitialState()),[c,u]));return L.useDebugValue(s),s}const ph=c=>{const u=Dy(c),s=o=>Ny(u,o);return Object.assign(s,u),s},Xh=(c=>c?ph(c):ph);function Kh(){if(typeof window>"u")return"system";const c=localStorage.getItem("nm-theme");return c==="light"||c==="dark"||c==="system"?c:"system"}function Lu(c){const u=document.documentElement,s=c==="dark"||c==="system"&&window.matchMedia("(prefers-color-scheme: dark)").matches;u.classList.toggle("dark",s),localStorage.setItem("nm-theme",c)}Lu(Kh());const Vu=Xh((c,u)=>({sidebarOpen:!0,theme:Kh(),toggleSidebar:()=>c(s=>({sidebarOpen:!s.sidebarOpen})),setSidebarOpen:s=>c({sidebarOpen:s}),setTheme:s=>{Lu(s),c({theme:s})},cycleTheme:()=>{const s=["light","dark","system"],o=u().theme,f=s[(s.indexOf(o)+1)%s.length];Lu(f),c({theme:f})}}));typeof window<"u"&&window.matchMedia("(prefers-color-scheme: dark)").addEventListener("change",()=>{const{theme:c}=Vu.getState();c==="system"&&Lu("system")});const F=c=>typeof c=="string",di=()=>{let c,u;const s=new Promise((o,f)=>{c=o,u=f});return s.resolve=c,s.reject=u,s},yh=c=>c==null?"":""+c,Cy=(c,u,s)=>{c.forEach(o=>{u[o]&&(s[o]=u[o])})},My=/###/g,vh=c=>c&&c.indexOf("###")>-1?c.replace(My,"."):c,bh=c=>!c||F(c),hi=(c,u,s)=>{const o=F(u)?u.split("."):u;let f=0;for(;f<o.length-1;){if(bh(c))return{};const d=vh(o[f]);!c[d]&&s&&(c[d]=new s),Object.prototype.hasOwnProperty.call(c,d)?c=c[d]:c={},++f}return bh(c)?{}:{obj:c,k:vh(o[f])}},Sh=(c,u,s)=>{const{obj:o,k:f}=hi(c,u,Object);if(o!==void 0||u.length===1){o[f]=s;return}let d=u[u.length-1],m=u.slice(0,u.length-1),p=hi(c,m,Object);for(;p.obj===void 0&&m.length;)d=`${m[m.length-1]}.${d}`,m=m.slice(0,m.length-1),p=hi(c,m,Object),p!=null&&p.obj&&typeof p.obj[`${p.k}.${d}`]<"u"&&(p.obj=void 0);p.obj[`${p.k}.${d}`]=s},_y=(c,u,s,o)=>{const{obj:f,k:d}=hi(c,u,Object);f[d]=f[d]||[],f[d].push(s)},ju=(c,u)=>{const{obj:s,k:o}=hi(c,u);if(s&&Object.prototype.hasOwnProperty.call(s,o))return s[o]},Ry=(c,u,s)=>{const o=ju(c,s);return o!==void 0?o:ju(u,s)},Zh=(c,u,s)=>{for(const o in u)o!=="__proto__"&&o!=="constructor"&&(o in c?F(c[o])||c[o]instanceof String||F(u[o])||u[o]instanceof String?s&&(c[o]=u[o]):Zh(c[o],u[o],s):c[o]=u[o]);return c},On=c=>c.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g,"\\$&");var Uy={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;","/":"&#x2F;"};const wy=c=>F(c)?c.replace(/[&<>"'\/]/g,u=>Uy[u]):c;class By{constructor(u){this.capacity=u,this.regExpMap=new Map,this.regExpQueue=[]}getRegExp(u){const s=this.regExpMap.get(u);if(s!==void 0)return s;const o=new RegExp(u);return this.regExpQueue.length===this.capacity&&this.regExpMap.delete(this.regExpQueue.shift()),this.regExpMap.set(u,o),this.regExpQueue.push(u),o}}const Ly=[" ",",","?","!",";"],jy=new By(20),Hy=(c,u,s)=>{u=u||"",s=s||"";const o=Ly.filter(m=>u.indexOf(m)<0&&s.indexOf(m)<0);if(o.length===0)return!0;const f=jy.getRegExp(`(${o.map(m=>m==="?"?"\\?":m).join("|")})`);let d=!f.test(c);if(!d){const m=c.indexOf(s);m>0&&!f.test(c.substring(0,m))&&(d=!0)}return d},fc=(c,u,s=".")=>{if(!c)return;if(c[u])return Object.prototype.hasOwnProperty.call(c,u)?c[u]:void 0;const o=u.split(s);let f=c;for(let d=0;d<o.length;){if(!f||typeof f!="object")return;let m,p="";for(let S=d;S<o.length;++S)if(S!==d&&(p+=s),p+=o[S],m=f[p],m!==void 0){if(["string","number","boolean"].indexOf(typeof m)>-1&&S<o.length-1)continue;d+=S-d+1;break}f=m}return f},pi=c=>c==null?void 0:c.replace(/_/g,"-"),qy={type:"logger",log(c){this.output("log",c)},warn(c){this.output("warn",c)},error(c){this.output("error",c)},output(c,u){var s,o;(o=(s=console==null?void 0:console[c])==null?void 0:s.apply)==null||o.call(s,console,u)}};class Hu{constructor(u,s={}){this.init(u,s)}init(u,s={}){this.prefix=s.prefix||"i18next:",this.logger=u||qy,this.options=s,this.debug=s.debug}log(...u){return this.forward(u,"log","",!0)}warn(...u){return this.forward(u,"warn","",!0)}error(...u){return this.forward(u,"error","")}deprecate(...u){return this.forward(u,"warn","WARNING DEPRECATED: ",!0)}forward(u,s,o,f){return f&&!this.debug?null:(F(u[0])&&(u[0]=`${o}${this.prefix} ${u[0]}`),this.logger[s](u))}create(u){return new Hu(this.logger,{prefix:`${this.prefix}:${u}:`,...this.options})}clone(u){return u=u||this.options,u.prefix=u.prefix||this.prefix,new Hu(this.logger,u)}}var la=new Hu;class Gu{constructor(){this.observers={}}on(u,s){return u.split(" ").forEach(o=>{this.observers[o]||(this.observers[o]=new Map);const f=this.observers[o].get(s)||0;this.observers[o].set(s,f+1)}),this}off(u,s){if(this.observers[u]){if(!s){delete this.observers[u];return}this.observers[u].delete(s)}}emit(u,...s){this.observers[u]&&Array.from(this.observers[u].entries()).forEach(([f,d])=>{for(let m=0;m<d;m++)f(...s)}),this.observers["*"]&&Array.from(this.observers["*"].entries()).forEach(([f,d])=>{for(let m=0;m<d;m++)f.apply(f,[u,...s])})}}class xh extends Gu{constructor(u,s={ns:["translation"],defaultNS:"translation"}){super(),this.data=u||{},this.options=s,this.options.keySeparator===void 0&&(this.options.keySeparator="."),this.options.ignoreJSONStructure===void 0&&(this.options.ignoreJSONStructure=!0)}addNamespaces(u){this.options.ns.indexOf(u)<0&&this.options.ns.push(u)}removeNamespaces(u){const s=this.options.ns.indexOf(u);s>-1&&this.options.ns.splice(s,1)}getResource(u,s,o,f={}){var v,N;const d=f.keySeparator!==void 0?f.keySeparator:this.options.keySeparator,m=f.ignoreJSONStructure!==void 0?f.ignoreJSONStructure:this.options.ignoreJSONStructure;let p;u.indexOf(".")>-1?p=u.split("."):(p=[u,s],o&&(Array.isArray(o)?p.push(...o):F(o)&&d?p.push(...o.split(d)):p.push(o)));const S=ju(this.data,p);return!S&&!s&&!o&&u.indexOf(".")>-1&&(u=p[0],s=p[1],o=p.slice(2).join(".")),S||!m||!F(o)?S:fc((N=(v=this.data)==null?void 0:v[u])==null?void 0:N[s],o,d)}addResource(u,s,o,f,d={silent:!1}){const m=d.keySeparator!==void 0?d.keySeparator:this.options.keySeparator;let p=[u,s];o&&(p=p.concat(m?o.split(m):o)),u.indexOf(".")>-1&&(p=u.split("."),f=s,s=p[1]),this.addNamespaces(s),Sh(this.data,p,f),d.silent||this.emit("added",u,s,o,f)}addResources(u,s,o,f={silent:!1}){for(const d in o)(F(o[d])||Array.isArray(o[d]))&&this.addResource(u,s,d,o[d],{silent:!0});f.silent||this.emit("added",u,s,o)}addResourceBundle(u,s,o,f,d,m={silent:!1,skipCopy:!1}){let p=[u,s];u.indexOf(".")>-1&&(p=u.split("."),f=o,o=s,s=p[1]),this.addNamespaces(s);let S=ju(this.data,p)||{};m.skipCopy||(o=JSON.parse(JSON.stringify(o))),f?Zh(S,o,d):S={...S,...o},Sh(this.data,p,S),m.silent||this.emit("added",u,s,o)}removeResourceBundle(u,s){this.hasResourceBundle(u,s)&&delete this.data[u][s],this.removeNamespaces(s),this.emit("removed",u,s)}hasResourceBundle(u,s){return this.getResource(u,s)!==void 0}getResourceBundle(u,s){return s||(s=this.options.defaultNS),this.getResource(u,s)}getDataByLanguage(u){return this.data[u]}hasLanguageSomeTranslations(u){const s=this.getDataByLanguage(u);return!!(s&&Object.keys(s)||[]).find(f=>s[f]&&Object.keys(s[f]).length>0)}toJSON(){return this.data}}var kh={processors:{},addPostProcessor(c){this.processors[c.name]=c},handle(c,u,s,o,f){return c.forEach(d=>{var m;u=((m=this.processors[d])==null?void 0:m.process(u,s,o,f))??u}),u}};const Jh=Symbol("i18next/PATH_KEY");function Yy(){const c=[],u=Object.create(null);let s;return u.get=(o,f)=>{var d;return(d=s==null?void 0:s.revoke)==null||d.call(s),f===Jh?c:(c.push(f),s=Proxy.revocable(o,u),s.proxy)},Proxy.revocable(Object.create(null),u).proxy}function dc(c,u){const{[Jh]:s}=c(Yy());return s.join((u==null?void 0:u.keySeparator)??".")}const Th={},ic=c=>!F(c)&&typeof c!="boolean"&&typeof c!="number";class qu extends Gu{constructor(u,s={}){super(),Cy(["resourceStore","languageUtils","pluralResolver","interpolator","backendConnector","i18nFormat","utils"],u,this),this.options=s,this.options.keySeparator===void 0&&(this.options.keySeparator="."),this.logger=la.create("translator")}changeLanguage(u){u&&(this.language=u)}exists(u,s={interpolation:{}}){const o={...s};if(u==null)return!1;const f=this.resolve(u,o);if((f==null?void 0:f.res)===void 0)return!1;const d=ic(f.res);return!(o.returnObjects===!1&&d)}extractFromKey(u,s){let o=s.nsSeparator!==void 0?s.nsSeparator:this.options.nsSeparator;o===void 0&&(o=":");const f=s.keySeparator!==void 0?s.keySeparator:this.options.keySeparator;let d=s.ns||this.options.defaultNS||[];const m=o&&u.indexOf(o)>-1,p=!this.options.userDefinedKeySeparator&&!s.keySeparator&&!this.options.userDefinedNsSeparator&&!s.nsSeparator&&!Hy(u,o,f);if(m&&!p){const S=u.match(this.interpolator.nestingRegexp);if(S&&S.length>0)return{key:u,namespaces:F(d)?[d]:d};const v=u.split(o);(o!==f||o===f&&this.options.ns.indexOf(v[0])>-1)&&(d=v.shift()),u=v.join(f)}return{key:u,namespaces:F(d)?[d]:d}}translate(u,s,o){let f=typeof s=="object"?{...s}:s;if(typeof f!="object"&&this.options.overloadTranslationOptionHandler&&(f=this.options.overloadTranslationOptionHandler(arguments)),typeof f=="object"&&(f={...f}),f||(f={}),u==null)return"";typeof u=="function"&&(u=dc(u,{...this.options,...f})),Array.isArray(u)||(u=[String(u)]);const d=f.returnDetails!==void 0?f.returnDetails:this.options.returnDetails,m=f.keySeparator!==void 0?f.keySeparator:this.options.keySeparator,{key:p,namespaces:S}=this.extractFromKey(u[u.length-1],f),v=S[S.length-1];let N=f.nsSeparator!==void 0?f.nsSeparator:this.options.nsSeparator;N===void 0&&(N=":");const g=f.lng||this.language,R=f.appendNamespaceToCIMode||this.options.appendNamespaceToCIMode;if((g==null?void 0:g.toLowerCase())==="cimode")return R?d?{res:`${v}${N}${p}`,usedKey:p,exactUsedKey:p,usedLng:g,usedNS:v,usedParams:this.getUsedParamsDetails(f)}:`${v}${N}${p}`:d?{res:p,usedKey:p,exactUsedKey:p,usedLng:g,usedNS:v,usedParams:this.getUsedParamsDetails(f)}:p;const B=this.resolve(u,f);let M=B==null?void 0:B.res;const V=(B==null?void 0:B.usedKey)||p,et=(B==null?void 0:B.exactUsedKey)||p,Q=["[object Number]","[object Function]","[object RegExp]"],Dt=f.joinArrays!==void 0?f.joinArrays:this.options.joinArrays,ft=!this.i18nFormat||this.i18nFormat.handleAsObject,ht=f.count!==void 0&&!F(f.count),At=qu.hasDefaultValue(f),vt=ht?this.pluralResolver.getSuffix(g,f.count,f):"",Tt=f.ordinal&&ht?this.pluralResolver.getSuffix(g,f.count,{ordinal:!1}):"",Nt=ht&&!f.ordinal&&f.count===0,Ct=Nt&&f[`defaultValue${this.options.pluralSeparator}zero`]||f[`defaultValue${vt}`]||f[`defaultValue${Tt}`]||f.defaultValue;let yt=M;ft&&!M&&At&&(yt=Ct);const ae=ic(yt),k=Object.prototype.toString.apply(yt);if(ft&&yt&&ae&&Q.indexOf(k)<0&&!(F(Dt)&&Array.isArray(yt))){if(!f.returnObjects&&!this.options.returnObjects){this.options.returnedObjectHandler||this.logger.warn("accessing an object - but returnObjects options is not enabled!");const Z=this.options.returnedObjectHandler?this.options.returnedObjectHandler(V,yt,{...f,ns:S}):`key '${p} (${this.language})' returned an object instead of string.`;return d?(B.res=Z,B.usedParams=this.getUsedParamsDetails(f),B):Z}if(m){const Z=Array.isArray(yt),W=Z?[]:{},ut=Z?et:V;for(const E in yt)if(Object.prototype.hasOwnProperty.call(yt,E)){const U=`${ut}${m}${E}`;At&&!M?W[E]=this.translate(U,{...f,defaultValue:ic(Ct)?Ct[E]:void 0,joinArrays:!1,ns:S}):W[E]=this.translate(U,{...f,joinArrays:!1,ns:S}),W[E]===U&&(W[E]=yt[E])}M=W}}else if(ft&&F(Dt)&&Array.isArray(M))M=M.join(Dt),M&&(M=this.extendTranslation(M,u,f,o));else{let Z=!1,W=!1;!this.isValidLookup(M)&&At&&(Z=!0,M=Ct),this.isValidLookup(M)||(W=!0,M=p);const E=(f.missingKeyNoValueFallbackToKey||this.options.missingKeyNoValueFallbackToKey)&&W?void 0:M,U=At&&Ct!==M&&this.options.updateMissing;if(W||Z||U){if(this.logger.log(U?"updateKey":"missingKey",g,v,p,U?Ct:M),m){const nt=this.resolve(p,{...f,keySeparator:!1});nt&&nt.res&&this.logger.warn("Seems the loaded translations were in flat JSON format instead of nested. Either set keySeparator: false on init or make sure your translations are published in nested format.")}let q=[];const at=this.languageUtils.getFallbackCodes(this.options.fallbackLng,f.lng||this.language);if(this.options.saveMissingTo==="fallback"&&at&&at[0])for(let nt=0;nt<at.length;nt++)q.push(at[nt]);else this.options.saveMissingTo==="all"?q=this.languageUtils.toResolveHierarchy(f.lng||this.language):q.push(f.lng||this.language);const tt=(nt,st,j)=>{var ot;const $=At&&j!==M?j:E;this.options.missingKeyHandler?this.options.missingKeyHandler(nt,v,st,$,U,f):(ot=this.backendConnector)!=null&&ot.saveMissing&&this.backendConnector.saveMissing(nt,v,st,$,U,f),this.emit("missingKey",nt,v,st,M)};this.options.saveMissing&&(this.options.saveMissingPlurals&&ht?q.forEach(nt=>{const st=this.pluralResolver.getSuffixes(nt,f);Nt&&f[`defaultValue${this.options.pluralSeparator}zero`]&&st.indexOf(`${this.options.pluralSeparator}zero`)<0&&st.push(`${this.options.pluralSeparator}zero`),st.forEach(j=>{tt([nt],p+j,f[`defaultValue${j}`]||Ct)})}):tt(q,p,Ct))}M=this.extendTranslation(M,u,f,B,o),W&&M===p&&this.options.appendNamespaceToMissingKey&&(M=`${v}${N}${p}`),(W||Z)&&this.options.parseMissingKeyHandler&&(M=this.options.parseMissingKeyHandler(this.options.appendNamespaceToMissingKey?`${v}${N}${p}`:p,Z?M:void 0,f))}return d?(B.res=M,B.usedParams=this.getUsedParamsDetails(f),B):M}extendTranslation(u,s,o,f,d){var S,v;if((S=this.i18nFormat)!=null&&S.parse)u=this.i18nFormat.parse(u,{...this.options.interpolation.defaultVariables,...o},o.lng||this.language||f.usedLng,f.usedNS,f.usedKey,{resolved:f});else if(!o.skipInterpolation){o.interpolation&&this.interpolator.init({...o,interpolation:{...this.options.interpolation,...o.interpolation}});const N=F(u)&&(((v=o==null?void 0:o.interpolation)==null?void 0:v.skipOnVariables)!==void 0?o.interpolation.skipOnVariables:this.options.interpolation.skipOnVariables);let g;if(N){const B=u.match(this.interpolator.nestingRegexp);g=B&&B.length}let R=o.replace&&!F(o.replace)?o.replace:o;if(this.options.interpolation.defaultVariables&&(R={...this.options.interpolation.defaultVariables,...R}),u=this.interpolator.interpolate(u,R,o.lng||this.language||f.usedLng,o),N){const B=u.match(this.interpolator.nestingRegexp),M=B&&B.length;g<M&&(o.nest=!1)}!o.lng&&f&&f.res&&(o.lng=this.language||f.usedLng),o.nest!==!1&&(u=this.interpolator.nest(u,(...B)=>(d==null?void 0:d[0])===B[0]&&!o.context?(this.logger.warn(`It seems you are nesting recursively key: ${B[0]} in key: ${s[0]}`),null):this.translate(...B,s),o)),o.interpolation&&this.interpolator.reset()}const m=o.postProcess||this.options.postProcess,p=F(m)?[m]:m;return u!=null&&(p!=null&&p.length)&&o.applyPostProcessor!==!1&&(u=kh.handle(p,u,s,this.options&&this.options.postProcessPassResolved?{i18nResolved:{...f,usedParams:this.getUsedParamsDetails(o)},...o}:o,this)),u}resolve(u,s={}){let o,f,d,m,p;return F(u)&&(u=[u]),u.forEach(S=>{if(this.isValidLookup(o))return;const v=this.extractFromKey(S,s),N=v.key;f=N;let g=v.namespaces;this.options.fallbackNS&&(g=g.concat(this.options.fallbackNS));const R=s.count!==void 0&&!F(s.count),B=R&&!s.ordinal&&s.count===0,M=s.context!==void 0&&(F(s.context)||typeof s.context=="number")&&s.context!=="",V=s.lngs?s.lngs:this.languageUtils.toResolveHierarchy(s.lng||this.language,s.fallbackLng);g.forEach(et=>{var Q,Dt;this.isValidLookup(o)||(p=et,!Th[`${V[0]}-${et}`]&&((Q=this.utils)!=null&&Q.hasLoadedNamespace)&&!((Dt=this.utils)!=null&&Dt.hasLoadedNamespace(p))&&(Th[`${V[0]}-${et}`]=!0,this.logger.warn(`key "${f}" for languages "${V.join(", ")}" won't get resolved as namespace "${p}" was not yet loaded`,"This means something IS WRONG in your setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!")),V.forEach(ft=>{var vt;if(this.isValidLookup(o))return;m=ft;const ht=[N];if((vt=this.i18nFormat)!=null&&vt.addLookupKeys)this.i18nFormat.addLookupKeys(ht,N,ft,et,s);else{let Tt;R&&(Tt=this.pluralResolver.getSuffix(ft,s.count,s));const Nt=`${this.options.pluralSeparator}zero`,Ct=`${this.options.pluralSeparator}ordinal${this.options.pluralSeparator}`;if(R&&(s.ordinal&&Tt.indexOf(Ct)===0&&ht.push(N+Tt.replace(Ct,this.options.pluralSeparator)),ht.push(N+Tt),B&&ht.push(N+Nt)),M){const yt=`${N}${this.options.contextSeparator||"_"}${s.context}`;ht.push(yt),R&&(s.ordinal&&Tt.indexOf(Ct)===0&&ht.push(yt+Tt.replace(Ct,this.options.pluralSeparator)),ht.push(yt+Tt),B&&ht.push(yt+Nt))}}let At;for(;At=ht.pop();)this.isValidLookup(o)||(d=At,o=this.getResource(ft,et,At,s))}))})}),{res:o,usedKey:f,exactUsedKey:d,usedLng:m,usedNS:p}}isValidLookup(u){return u!==void 0&&!(!this.options.returnNull&&u===null)&&!(!this.options.returnEmptyString&&u==="")}getResource(u,s,o,f={}){var d;return(d=this.i18nFormat)!=null&&d.getResource?this.i18nFormat.getResource(u,s,o,f):this.resourceStore.getResource(u,s,o,f)}getUsedParamsDetails(u={}){const s=["defaultValue","ordinal","context","replace","lng","lngs","fallbackLng","ns","keySeparator","nsSeparator","returnObjects","returnDetails","joinArrays","postProcess","interpolation"],o=u.replace&&!F(u.replace);let f=o?u.replace:u;if(o&&typeof u.count<"u"&&(f.count=u.count),this.options.interpolation.defaultVariables&&(f={...this.options.interpolation.defaultVariables,...f}),!o){f={...f};for(const d of s)delete f[d]}return f}static hasDefaultValue(u){const s="defaultValue";for(const o in u)if(Object.prototype.hasOwnProperty.call(u,o)&&s===o.substring(0,s.length)&&u[o]!==void 0)return!0;return!1}}class Eh{constructor(u){this.options=u,this.supportedLngs=this.options.supportedLngs||!1,this.logger=la.create("languageUtils")}getScriptPartFromCode(u){if(u=pi(u),!u||u.indexOf("-")<0)return null;const s=u.split("-");return s.length===2||(s.pop(),s[s.length-1].toLowerCase()==="x")?null:this.formatLanguageCode(s.join("-"))}getLanguagePartFromCode(u){if(u=pi(u),!u||u.indexOf("-")<0)return u;const s=u.split("-");return this.formatLanguageCode(s[0])}formatLanguageCode(u){if(F(u)&&u.indexOf("-")>-1){let s;try{s=Intl.getCanonicalLocales(u)[0]}catch{}return s&&this.options.lowerCaseLng&&(s=s.toLowerCase()),s||(this.options.lowerCaseLng?u.toLowerCase():u)}return this.options.cleanCode||this.options.lowerCaseLng?u.toLowerCase():u}isSupportedCode(u){return(this.options.load==="languageOnly"||this.options.nonExplicitSupportedLngs)&&(u=this.getLanguagePartFromCode(u)),!this.supportedLngs||!this.supportedLngs.length||this.supportedLngs.indexOf(u)>-1}getBestMatchFromCodes(u){if(!u)return null;let s;return u.forEach(o=>{if(s)return;const f=this.formatLanguageCode(o);(!this.options.supportedLngs||this.isSupportedCode(f))&&(s=f)}),!s&&this.options.supportedLngs&&u.forEach(o=>{if(s)return;const f=this.getScriptPartFromCode(o);if(this.isSupportedCode(f))return s=f;const d=this.getLanguagePartFromCode(o);if(this.isSupportedCode(d))return s=d;s=this.options.supportedLngs.find(m=>{if(m===d)return m;if(!(m.indexOf("-")<0&&d.indexOf("-")<0)&&(m.indexOf("-")>0&&d.indexOf("-")<0&&m.substring(0,m.indexOf("-"))===d||m.indexOf(d)===0&&d.length>1))return m})}),s||(s=this.getFallbackCodes(this.options.fallbackLng)[0]),s}getFallbackCodes(u,s){if(!u)return[];if(typeof u=="function"&&(u=u(s)),F(u)&&(u=[u]),Array.isArray(u))return u;if(!s)return u.default||[];let o=u[s];return o||(o=u[this.getScriptPartFromCode(s)]),o||(o=u[this.formatLanguageCode(s)]),o||(o=u[this.getLanguagePartFromCode(s)]),o||(o=u.default),o||[]}toResolveHierarchy(u,s){const o=this.getFallbackCodes((s===!1?[]:s)||this.options.fallbackLng||[],u),f=[],d=m=>{m&&(this.isSupportedCode(m)?f.push(m):this.logger.warn(`rejecting language code not found in supportedLngs: ${m}`))};return F(u)&&(u.indexOf("-")>-1||u.indexOf("_")>-1)?(this.options.load!=="languageOnly"&&d(this.formatLanguageCode(u)),this.options.load!=="languageOnly"&&this.options.load!=="currentOnly"&&d(this.getScriptPartFromCode(u)),this.options.load!=="currentOnly"&&d(this.getLanguagePartFromCode(u))):F(u)&&d(this.formatLanguageCode(u)),o.forEach(m=>{f.indexOf(m)<0&&d(this.formatLanguageCode(m))}),f}}const Oh={zero:0,one:1,two:2,few:3,many:4,other:5},zh={select:c=>c===1?"one":"other",resolvedOptions:()=>({pluralCategories:["one","other"]})};class Vy{constructor(u,s={}){this.languageUtils=u,this.options=s,this.logger=la.create("pluralResolver"),this.pluralRulesCache={}}clearCache(){this.pluralRulesCache={}}getRule(u,s={}){const o=pi(u==="dev"?"en":u),f=s.ordinal?"ordinal":"cardinal",d=JSON.stringify({cleanedCode:o,type:f});if(d in this.pluralRulesCache)return this.pluralRulesCache[d];let m;try{m=new Intl.PluralRules(o,{type:f})}catch{if(typeof Intl>"u")return this.logger.error("No Intl support, please use an Intl polyfill!"),zh;if(!u.match(/-|_/))return zh;const S=this.languageUtils.getLanguagePartFromCode(u);m=this.getRule(S,s)}return this.pluralRulesCache[d]=m,m}needsPlural(u,s={}){let o=this.getRule(u,s);return o||(o=this.getRule("dev",s)),(o==null?void 0:o.resolvedOptions().pluralCategories.length)>1}getPluralFormsOfKey(u,s,o={}){return this.getSuffixes(u,o).map(f=>`${s}${f}`)}getSuffixes(u,s={}){let o=this.getRule(u,s);return o||(o=this.getRule("dev",s)),o?o.resolvedOptions().pluralCategories.sort((f,d)=>Oh[f]-Oh[d]).map(f=>`${this.options.prepend}${s.ordinal?`ordinal${this.options.prepend}`:""}${f}`):[]}getSuffix(u,s,o={}){const f=this.getRule(u,o);return f?`${this.options.prepend}${o.ordinal?`ordinal${this.options.prepend}`:""}${f.select(s)}`:(this.logger.warn(`no plural rule found for: ${u}`),this.getSuffix("dev",s,o))}}const Dh=(c,u,s,o=".",f=!0)=>{let d=Ry(c,u,s);return!d&&f&&F(s)&&(d=fc(c,s,o),d===void 0&&(d=fc(u,s,o))),d},uc=c=>c.replace(/\$/g,"$$$$");class Ah{constructor(u={}){var s;this.logger=la.create("interpolator"),this.options=u,this.format=((s=u==null?void 0:u.interpolation)==null?void 0:s.format)||(o=>o),this.init(u)}init(u={}){u.interpolation||(u.interpolation={escapeValue:!0});const{escape:s,escapeValue:o,useRawValueToEscape:f,prefix:d,prefixEscaped:m,suffix:p,suffixEscaped:S,formatSeparator:v,unescapeSuffix:N,unescapePrefix:g,nestingPrefix:R,nestingPrefixEscaped:B,nestingSuffix:M,nestingSuffixEscaped:V,nestingOptionsSeparator:et,maxReplaces:Q,alwaysFormat:Dt}=u.interpolation;this.escape=s!==void 0?s:wy,this.escapeValue=o!==void 0?o:!0,this.useRawValueToEscape=f!==void 0?f:!1,this.prefix=d?On(d):m||"{{",this.suffix=p?On(p):S||"}}",this.formatSeparator=v||",",this.unescapePrefix=N?"":g||"-",this.unescapeSuffix=this.unescapePrefix?"":N||"",this.nestingPrefix=R?On(R):B||On("$t("),this.nestingSuffix=M?On(M):V||On(")"),this.nestingOptionsSeparator=et||",",this.maxReplaces=Q||1e3,this.alwaysFormat=Dt!==void 0?Dt:!1,this.resetRegExp()}reset(){this.options&&this.init(this.options)}resetRegExp(){const u=(s,o)=>(s==null?void 0:s.source)===o?(s.lastIndex=0,s):new RegExp(o,"g");this.regexp=u(this.regexp,`${this.prefix}(.+?)${this.suffix}`),this.regexpUnescape=u(this.regexpUnescape,`${this.prefix}${this.unescapePrefix}(.+?)${this.unescapeSuffix}${this.suffix}`),this.nestingRegexp=u(this.nestingRegexp,`${this.nestingPrefix}((?:[^()"']+|"[^"]*"|'[^']*'|\\((?:[^()]|"[^"]*"|'[^']*')*\\))*?)${this.nestingSuffix}`)}interpolate(u,s,o,f){var B;let d,m,p;const S=this.options&&this.options.interpolation&&this.options.interpolation.defaultVariables||{},v=M=>{if(M.indexOf(this.formatSeparator)<0){const Dt=Dh(s,S,M,this.options.keySeparator,this.options.ignoreJSONStructure);return this.alwaysFormat?this.format(Dt,void 0,o,{...f,...s,interpolationkey:M}):Dt}const V=M.split(this.formatSeparator),et=V.shift().trim(),Q=V.join(this.formatSeparator).trim();return this.format(Dh(s,S,et,this.options.keySeparator,this.options.ignoreJSONStructure),Q,o,{...f,...s,interpolationkey:et})};this.resetRegExp();const N=(f==null?void 0:f.missingInterpolationHandler)||this.options.missingInterpolationHandler,g=((B=f==null?void 0:f.interpolation)==null?void 0:B.skipOnVariables)!==void 0?f.interpolation.skipOnVariables:this.options.interpolation.skipOnVariables;return[{regex:this.regexpUnescape,safeValue:M=>uc(M)},{regex:this.regexp,safeValue:M=>this.escapeValue?uc(this.escape(M)):uc(M)}].forEach(M=>{for(p=0;d=M.regex.exec(u);){const V=d[1].trim();if(m=v(V),m===void 0)if(typeof N=="function"){const Q=N(u,d,f);m=F(Q)?Q:""}else if(f&&Object.prototype.hasOwnProperty.call(f,V))m="";else if(g){m=d[0];continue}else this.logger.warn(`missed to pass in variable ${V} for interpolating ${u}`),m="";else!F(m)&&!this.useRawValueToEscape&&(m=yh(m));const et=M.safeValue(m);if(u=u.replace(d[0],et),g?(M.regex.lastIndex+=m.length,M.regex.lastIndex-=d[0].length):M.regex.lastIndex=0,p++,p>=this.maxReplaces)break}}),u}nest(u,s,o={}){let f,d,m;const p=(S,v)=>{const N=this.nestingOptionsSeparator;if(S.indexOf(N)<0)return S;const g=S.split(new RegExp(`${On(N)}[ ]*{`));let R=`{${g[1]}`;S=g[0],R=this.interpolate(R,m);const B=R.match(/'/g),M=R.match(/"/g);(((B==null?void 0:B.length)??0)%2===0&&!M||((M==null?void 0:M.length)??0)%2!==0)&&(R=R.replace(/'/g,'"'));try{m=JSON.parse(R),v&&(m={...v,...m})}catch(V){return this.logger.warn(`failed parsing options string in nesting for key ${S}`,V),`${S}${N}${R}`}return m.defaultValue&&m.defaultValue.indexOf(this.prefix)>-1&&delete m.defaultValue,S};for(;f=this.nestingRegexp.exec(u);){let S=[];m={...o},m=m.replace&&!F(m.replace)?m.replace:m,m.applyPostProcessor=!1,delete m.defaultValue;const v=/{.*}/.test(f[1])?f[1].lastIndexOf("}")+1:f[1].indexOf(this.formatSeparator);if(v!==-1&&(S=f[1].slice(v).split(this.formatSeparator).map(N=>N.trim()).filter(Boolean),f[1]=f[1].slice(0,v)),d=s(p.call(this,f[1].trim(),m),m),d&&f[0]===u&&!F(d))return d;F(d)||(d=yh(d)),d||(this.logger.warn(`missed to resolve ${f[1]} for nesting ${u}`),d=""),S.length&&(d=S.reduce((N,g)=>this.format(N,g,o.lng,{...o,interpolationkey:f[1].trim()}),d.trim())),u=u.replace(f[0],d),this.regexp.lastIndex=0}return u}}const Gy=c=>{let u=c.toLowerCase().trim();const s={};if(c.indexOf("(")>-1){const o=c.split("(");u=o[0].toLowerCase().trim();const f=o[1].substring(0,o[1].length-1);u==="currency"&&f.indexOf(":")<0?s.currency||(s.currency=f.trim()):u==="relativetime"&&f.indexOf(":")<0?s.range||(s.range=f.trim()):f.split(";").forEach(m=>{if(m){const[p,...S]=m.split(":"),v=S.join(":").trim().replace(/^'+|'+$/g,""),N=p.trim();s[N]||(s[N]=v),v==="false"&&(s[N]=!1),v==="true"&&(s[N]=!0),isNaN(v)||(s[N]=parseInt(v,10))}})}return{formatName:u,formatOptions:s}},Nh=c=>{const u={};return(s,o,f)=>{let d=f;f&&f.interpolationkey&&f.formatParams&&f.formatParams[f.interpolationkey]&&f[f.interpolationkey]&&(d={...d,[f.interpolationkey]:void 0});const m=o+JSON.stringify(d);let p=u[m];return p||(p=c(pi(o),f),u[m]=p),p(s)}},Qy=c=>(u,s,o)=>c(pi(s),o)(u);class Xy{constructor(u={}){this.logger=la.create("formatter"),this.options=u,this.init(u)}init(u,s={interpolation:{}}){this.formatSeparator=s.interpolation.formatSeparator||",";const o=s.cacheInBuiltFormats?Nh:Qy;this.formats={number:o((f,d)=>{const m=new Intl.NumberFormat(f,{...d});return p=>m.format(p)}),currency:o((f,d)=>{const m=new Intl.NumberFormat(f,{...d,style:"currency"});return p=>m.format(p)}),datetime:o((f,d)=>{const m=new Intl.DateTimeFormat(f,{...d});return p=>m.format(p)}),relativetime:o((f,d)=>{const m=new Intl.RelativeTimeFormat(f,{...d});return p=>m.format(p,d.range||"day")}),list:o((f,d)=>{const m=new Intl.ListFormat(f,{...d});return p=>m.format(p)})}}add(u,s){this.formats[u.toLowerCase().trim()]=s}addCached(u,s){this.formats[u.toLowerCase().trim()]=Nh(s)}format(u,s,o,f={}){const d=s.split(this.formatSeparator);if(d.length>1&&d[0].indexOf("(")>1&&d[0].indexOf(")")<0&&d.find(p=>p.indexOf(")")>-1)){const p=d.findIndex(S=>S.indexOf(")")>-1);d[0]=[d[0],...d.splice(1,p)].join(this.formatSeparator)}return d.reduce((p,S)=>{var g;const{formatName:v,formatOptions:N}=Gy(S);if(this.formats[v]){let R=p;try{const B=((g=f==null?void 0:f.formatParams)==null?void 0:g[f.interpolationkey])||{},M=B.locale||B.lng||f.locale||f.lng||o;R=this.formats[v](p,M,{...N,...f,...B})}catch(B){this.logger.warn(B)}return R}else this.logger.warn(`there was no format function for ${v}`);return p},u)}}const Ky=(c,u)=>{c.pending[u]!==void 0&&(delete c.pending[u],c.pendingCount--)};class Zy extends Gu{constructor(u,s,o,f={}){var d,m;super(),this.backend=u,this.store=s,this.services=o,this.languageUtils=o.languageUtils,this.options=f,this.logger=la.create("backendConnector"),this.waitingReads=[],this.maxParallelReads=f.maxParallelReads||10,this.readingCalls=0,this.maxRetries=f.maxRetries>=0?f.maxRetries:5,this.retryTimeout=f.retryTimeout>=1?f.retryTimeout:350,this.state={},this.queue=[],(m=(d=this.backend)==null?void 0:d.init)==null||m.call(d,o,f.backend,f)}queueLoad(u,s,o,f){const d={},m={},p={},S={};return u.forEach(v=>{let N=!0;s.forEach(g=>{const R=`${v}|${g}`;!o.reload&&this.store.hasResourceBundle(v,g)?this.state[R]=2:this.state[R]<0||(this.state[R]===1?m[R]===void 0&&(m[R]=!0):(this.state[R]=1,N=!1,m[R]===void 0&&(m[R]=!0),d[R]===void 0&&(d[R]=!0),S[g]===void 0&&(S[g]=!0)))}),N||(p[v]=!0)}),(Object.keys(d).length||Object.keys(m).length)&&this.queue.push({pending:m,pendingCount:Object.keys(m).length,loaded:{},errors:[],callback:f}),{toLoad:Object.keys(d),pending:Object.keys(m),toLoadLanguages:Object.keys(p),toLoadNamespaces:Object.keys(S)}}loaded(u,s,o){const f=u.split("|"),d=f[0],m=f[1];s&&this.emit("failedLoading",d,m,s),!s&&o&&this.store.addResourceBundle(d,m,o,void 0,void 0,{skipCopy:!0}),this.state[u]=s?-1:2,s&&o&&(this.state[u]=0);const p={};this.queue.forEach(S=>{_y(S.loaded,[d],m),Ky(S,u),s&&S.errors.push(s),S.pendingCount===0&&!S.done&&(Object.keys(S.loaded).forEach(v=>{p[v]||(p[v]={});const N=S.loaded[v];N.length&&N.forEach(g=>{p[v][g]===void 0&&(p[v][g]=!0)})}),S.done=!0,S.errors.length?S.callback(S.errors):S.callback())}),this.emit("loaded",p),this.queue=this.queue.filter(S=>!S.done)}read(u,s,o,f=0,d=this.retryTimeout,m){if(!u.length)return m(null,{});if(this.readingCalls>=this.maxParallelReads){this.waitingReads.push({lng:u,ns:s,fcName:o,tried:f,wait:d,callback:m});return}this.readingCalls++;const p=(v,N)=>{if(this.readingCalls--,this.waitingReads.length>0){const g=this.waitingReads.shift();this.read(g.lng,g.ns,g.fcName,g.tried,g.wait,g.callback)}if(v&&N&&f<this.maxRetries){setTimeout(()=>{this.read.call(this,u,s,o,f+1,d*2,m)},d);return}m(v,N)},S=this.backend[o].bind(this.backend);if(S.length===2){try{const v=S(u,s);v&&typeof v.then=="function"?v.then(N=>p(null,N)).catch(p):p(null,v)}catch(v){p(v)}return}return S(u,s,p)}prepareLoading(u,s,o={},f){if(!this.backend)return this.logger.warn("No backend was added via i18next.use. Will not load resources."),f&&f();F(u)&&(u=this.languageUtils.toResolveHierarchy(u)),F(s)&&(s=[s]);const d=this.queueLoad(u,s,o,f);if(!d.toLoad.length)return d.pending.length||f(),null;d.toLoad.forEach(m=>{this.loadOne(m)})}load(u,s,o){this.prepareLoading(u,s,{},o)}reload(u,s,o){this.prepareLoading(u,s,{reload:!0},o)}loadOne(u,s=""){const o=u.split("|"),f=o[0],d=o[1];this.read(f,d,"read",void 0,void 0,(m,p)=>{m&&this.logger.warn(`${s}loading namespace ${d} for language ${f} failed`,m),!m&&p&&this.logger.log(`${s}loaded namespace ${d} for language ${f}`,p),this.loaded(u,m,p)})}saveMissing(u,s,o,f,d,m={},p=()=>{}){var S,v,N,g,R;if((v=(S=this.services)==null?void 0:S.utils)!=null&&v.hasLoadedNamespace&&!((g=(N=this.services)==null?void 0:N.utils)!=null&&g.hasLoadedNamespace(s))){this.logger.warn(`did not save key "${o}" as the namespace "${s}" was not yet loaded`,"This means something IS WRONG in your setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!");return}if(!(o==null||o==="")){if((R=this.backend)!=null&&R.create){const B={...m,isUpdate:d},M=this.backend.create.bind(this.backend);if(M.length<6)try{let V;M.length===5?V=M(u,s,o,f,B):V=M(u,s,o,f),V&&typeof V.then=="function"?V.then(et=>p(null,et)).catch(p):p(null,V)}catch(V){p(V)}else M(u,s,o,f,p,B)}!u||!u[0]||this.store.addResource(u[0],s,o,f)}}}const sc=()=>({debug:!1,initAsync:!0,ns:["translation"],defaultNS:["translation"],fallbackLng:["dev"],fallbackNS:!1,supportedLngs:!1,nonExplicitSupportedLngs:!1,load:"all",preload:!1,simplifyPluralSuffix:!0,keySeparator:".",nsSeparator:":",pluralSeparator:"_",contextSeparator:"_",partialBundledLanguages:!1,saveMissing:!1,updateMissing:!1,saveMissingTo:"fallback",saveMissingPlurals:!0,missingKeyHandler:!1,missingInterpolationHandler:!1,postProcess:!1,postProcessPassResolved:!1,returnNull:!1,returnEmptyString:!0,returnObjects:!1,joinArrays:!1,returnedObjectHandler:!1,parseMissingKeyHandler:!1,appendNamespaceToMissingKey:!1,appendNamespaceToCIMode:!1,overloadTranslationOptionHandler:c=>{let u={};if(typeof c[1]=="object"&&(u=c[1]),F(c[1])&&(u.defaultValue=c[1]),F(c[2])&&(u.tDescription=c[2]),typeof c[2]=="object"||typeof c[3]=="object"){const s=c[3]||c[2];Object.keys(s).forEach(o=>{u[o]=s[o]})}return u},interpolation:{escapeValue:!0,format:c=>c,prefix:"{{",suffix:"}}",formatSeparator:",",unescapePrefix:"-",nestingPrefix:"$t(",nestingSuffix:")",nestingOptionsSeparator:",",maxReplaces:1e3,skipOnVariables:!0},cacheInBuiltFormats:!0}),Ch=c=>{var u,s;return F(c.ns)&&(c.ns=[c.ns]),F(c.fallbackLng)&&(c.fallbackLng=[c.fallbackLng]),F(c.fallbackNS)&&(c.fallbackNS=[c.fallbackNS]),((s=(u=c.supportedLngs)==null?void 0:u.indexOf)==null?void 0:s.call(u,"cimode"))<0&&(c.supportedLngs=c.supportedLngs.concat(["cimode"])),typeof c.initImmediate=="boolean"&&(c.initAsync=c.initImmediate),c},Uu=()=>{},ky=c=>{Object.getOwnPropertyNames(Object.getPrototypeOf(c)).forEach(s=>{typeof c[s]=="function"&&(c[s]=c[s].bind(c))})},Fh="__i18next_supportNoticeShown",Jy=()=>typeof globalThis<"u"&&!!globalThis[Fh],Fy=()=>{typeof globalThis<"u"&&(globalThis[Fh]=!0)},$y=c=>{var u,s,o,f,d,m,p,S,v,N,g,R,B;return!!(((o=(s=(u=c==null?void 0:c.modules)==null?void 0:u.backend)==null?void 0:s.name)==null?void 0:o.indexOf("Locize"))>0||((p=(m=(d=(f=c==null?void 0:c.modules)==null?void 0:f.backend)==null?void 0:d.constructor)==null?void 0:m.name)==null?void 0:p.indexOf("Locize"))>0||(v=(S=c==null?void 0:c.options)==null?void 0:S.backend)!=null&&v.backends&&c.options.backend.backends.some(M=>{var V,et,Q;return((V=M==null?void 0:M.name)==null?void 0:V.indexOf("Locize"))>0||((Q=(et=M==null?void 0:M.constructor)==null?void 0:et.name)==null?void 0:Q.indexOf("Locize"))>0})||(g=(N=c==null?void 0:c.options)==null?void 0:N.backend)!=null&&g.projectId||(B=(R=c==null?void 0:c.options)==null?void 0:R.backend)!=null&&B.backendOptions&&c.options.backend.backendOptions.some(M=>M==null?void 0:M.projectId))};class gi extends Gu{constructor(u={},s){if(super(),this.options=Ch(u),this.services={},this.logger=la,this.modules={external:[]},ky(this),s&&!this.isInitialized&&!u.isClone){if(!this.options.initAsync)return this.init(u,s),this;setTimeout(()=>{this.init(u,s)},0)}}init(u={},s){this.isInitializing=!0,typeof u=="function"&&(s=u,u={}),u.defaultNS==null&&u.ns&&(F(u.ns)?u.defaultNS=u.ns:u.ns.indexOf("translation")<0&&(u.defaultNS=u.ns[0]));const o=sc();this.options={...o,...this.options,...Ch(u)},this.options.interpolation={...o.interpolation,...this.options.interpolation},u.keySeparator!==void 0&&(this.options.userDefinedKeySeparator=u.keySeparator),u.nsSeparator!==void 0&&(this.options.userDefinedNsSeparator=u.nsSeparator),typeof this.options.overloadTranslationOptionHandler!="function"&&(this.options.overloadTranslationOptionHandler=o.overloadTranslationOptionHandler),this.options.showSupportNotice!==!1&&!$y(this)&&!Jy()&&(typeof console<"u"&&typeof console.info<"u"&&console.info("🌐 i18next is maintained with support from Locize — consider powering your project with managed localization (AI, CDN, integrations): https://locize.com 💙"),Fy());const f=v=>v?typeof v=="function"?new v:v:null;if(!this.options.isClone){this.modules.logger?la.init(f(this.modules.logger),this.options):la.init(null,this.options);let v;this.modules.formatter?v=this.modules.formatter:v=Xy;const N=new Eh(this.options);this.store=new xh(this.options.resources,this.options);const g=this.services;g.logger=la,g.resourceStore=this.store,g.languageUtils=N,g.pluralResolver=new Vy(N,{prepend:this.options.pluralSeparator,simplifyPluralSuffix:this.options.simplifyPluralSuffix}),this.options.interpolation.format&&this.options.interpolation.format!==o.interpolation.format&&this.logger.deprecate("init: you are still using the legacy format function, please use the new approach: https://www.i18next.com/translation-function/formatting"),v&&(!this.options.interpolation.format||this.options.interpolation.format===o.interpolation.format)&&(g.formatter=f(v),g.formatter.init&&g.formatter.init(g,this.options),this.options.interpolation.format=g.formatter.format.bind(g.formatter)),g.interpolator=new Ah(this.options),g.utils={hasLoadedNamespace:this.hasLoadedNamespace.bind(this)},g.backendConnector=new Zy(f(this.modules.backend),g.resourceStore,g,this.options),g.backendConnector.on("*",(B,...M)=>{this.emit(B,...M)}),this.modules.languageDetector&&(g.languageDetector=f(this.modules.languageDetector),g.languageDetector.init&&g.languageDetector.init(g,this.options.detection,this.options)),this.modules.i18nFormat&&(g.i18nFormat=f(this.modules.i18nFormat),g.i18nFormat.init&&g.i18nFormat.init(this)),this.translator=new qu(this.services,this.options),this.translator.on("*",(B,...M)=>{this.emit(B,...M)}),this.modules.external.forEach(B=>{B.init&&B.init(this)})}if(this.format=this.options.interpolation.format,s||(s=Uu),this.options.fallbackLng&&!this.services.languageDetector&&!this.options.lng){const v=this.services.languageUtils.getFallbackCodes(this.options.fallbackLng);v.length>0&&v[0]!=="dev"&&(this.options.lng=v[0])}!this.services.languageDetector&&!this.options.lng&&this.logger.warn("init: no languageDetector is used and no lng is defined"),["getResource","hasResourceBundle","getResourceBundle","getDataByLanguage"].forEach(v=>{this[v]=(...N)=>this.store[v](...N)}),["addResource","addResources","addResourceBundle","removeResourceBundle"].forEach(v=>{this[v]=(...N)=>(this.store[v](...N),this)});const p=di(),S=()=>{const v=(N,g)=>{this.isInitializing=!1,this.isInitialized&&!this.initializedStoreOnce&&this.logger.warn("init: i18next is already initialized. You should call init just once!"),this.isInitialized=!0,this.options.isClone||this.logger.log("initialized",this.options),this.emit("initialized",this.options),p.resolve(g),s(N,g)};if(this.languages&&!this.isInitialized)return v(null,this.t.bind(this));this.changeLanguage(this.options.lng,v)};return this.options.resources||!this.options.initAsync?S():setTimeout(S,0),p}loadResources(u,s=Uu){var d,m;let o=s;const f=F(u)?u:this.language;if(typeof u=="function"&&(o=u),!this.options.resources||this.options.partialBundledLanguages){if((f==null?void 0:f.toLowerCase())==="cimode"&&(!this.options.preload||this.options.preload.length===0))return o();const p=[],S=v=>{if(!v||v==="cimode")return;this.services.languageUtils.toResolveHierarchy(v).forEach(g=>{g!=="cimode"&&p.indexOf(g)<0&&p.push(g)})};f?S(f):this.services.languageUtils.getFallbackCodes(this.options.fallbackLng).forEach(N=>S(N)),(m=(d=this.options.preload)==null?void 0:d.forEach)==null||m.call(d,v=>S(v)),this.services.backendConnector.load(p,this.options.ns,v=>{!v&&!this.resolvedLanguage&&this.language&&this.setResolvedLanguage(this.language),o(v)})}else o(null)}reloadResources(u,s,o){const f=di();return typeof u=="function"&&(o=u,u=void 0),typeof s=="function"&&(o=s,s=void 0),u||(u=this.languages),s||(s=this.options.ns),o||(o=Uu),this.services.backendConnector.reload(u,s,d=>{f.resolve(),o(d)}),f}use(u){if(!u)throw new Error("You are passing an undefined module! Please check the object you are passing to i18next.use()");if(!u.type)throw new Error("You are passing a wrong module! Please check the object you are passing to i18next.use()");return u.type==="backend"&&(this.modules.backend=u),(u.type==="logger"||u.log&&u.warn&&u.error)&&(this.modules.logger=u),u.type==="languageDetector"&&(this.modules.languageDetector=u),u.type==="i18nFormat"&&(this.modules.i18nFormat=u),u.type==="postProcessor"&&kh.addPostProcessor(u),u.type==="formatter"&&(this.modules.formatter=u),u.type==="3rdParty"&&this.modules.external.push(u),this}setResolvedLanguage(u){if(!(!u||!this.languages)&&!(["cimode","dev"].indexOf(u)>-1)){for(let s=0;s<this.languages.length;s++){const o=this.languages[s];if(!(["cimode","dev"].indexOf(o)>-1)&&this.store.hasLanguageSomeTranslations(o)){this.resolvedLanguage=o;break}}!this.resolvedLanguage&&this.languages.indexOf(u)<0&&this.store.hasLanguageSomeTranslations(u)&&(this.resolvedLanguage=u,this.languages.unshift(u))}}changeLanguage(u,s){this.isLanguageChangingTo=u;const o=di();this.emit("languageChanging",u);const f=p=>{this.language=p,this.languages=this.services.languageUtils.toResolveHierarchy(p),this.resolvedLanguage=void 0,this.setResolvedLanguage(p)},d=(p,S)=>{S?this.isLanguageChangingTo===u&&(f(S),this.translator.changeLanguage(S),this.isLanguageChangingTo=void 0,this.emit("languageChanged",S),this.logger.log("languageChanged",S)):this.isLanguageChangingTo=void 0,o.resolve((...v)=>this.t(...v)),s&&s(p,(...v)=>this.t(...v))},m=p=>{var N,g;!u&&!p&&this.services.languageDetector&&(p=[]);const S=F(p)?p:p&&p[0],v=this.store.hasLanguageSomeTranslations(S)?S:this.services.languageUtils.getBestMatchFromCodes(F(p)?[p]:p);v&&(this.language||f(v),this.translator.language||this.translator.changeLanguage(v),(g=(N=this.services.languageDetector)==null?void 0:N.cacheUserLanguage)==null||g.call(N,v)),this.loadResources(v,R=>{d(R,v)})};return!u&&this.services.languageDetector&&!this.services.languageDetector.async?m(this.services.languageDetector.detect()):!u&&this.services.languageDetector&&this.services.languageDetector.async?this.services.languageDetector.detect.length===0?this.services.languageDetector.detect().then(m):this.services.languageDetector.detect(m):m(u),o}getFixedT(u,s,o){const f=(d,m,...p)=>{let S;typeof m!="object"?S=this.options.overloadTranslationOptionHandler([d,m].concat(p)):S={...m},S.lng=S.lng||f.lng,S.lngs=S.lngs||f.lngs,S.ns=S.ns||f.ns,S.keyPrefix!==""&&(S.keyPrefix=S.keyPrefix||o||f.keyPrefix);const v=this.options.keySeparator||".";let N;return S.keyPrefix&&Array.isArray(d)?N=d.map(g=>(typeof g=="function"&&(g=dc(g,{...this.options,...m})),`${S.keyPrefix}${v}${g}`)):(typeof d=="function"&&(d=dc(d,{...this.options,...m})),N=S.keyPrefix?`${S.keyPrefix}${v}${d}`:d),this.t(N,S)};return F(u)?f.lng=u:f.lngs=u,f.ns=s,f.keyPrefix=o,f}t(...u){var s;return(s=this.translator)==null?void 0:s.translate(...u)}exists(...u){var s;return(s=this.translator)==null?void 0:s.exists(...u)}setDefaultNamespace(u){this.options.defaultNS=u}hasLoadedNamespace(u,s={}){if(!this.isInitialized)return this.logger.warn("hasLoadedNamespace: i18next was not initialized",this.languages),!1;if(!this.languages||!this.languages.length)return this.logger.warn("hasLoadedNamespace: i18n.languages were undefined or empty",this.languages),!1;const o=s.lng||this.resolvedLanguage||this.languages[0],f=this.options?this.options.fallbackLng:!1,d=this.languages[this.languages.length-1];if(o.toLowerCase()==="cimode")return!0;const m=(p,S)=>{const v=this.services.backendConnector.state[`${p}|${S}`];return v===-1||v===0||v===2};if(s.precheck){const p=s.precheck(this,m);if(p!==void 0)return p}return!!(this.hasResourceBundle(o,u)||!this.services.backendConnector.backend||this.options.resources&&!this.options.partialBundledLanguages||m(o,u)&&(!f||m(d,u)))}loadNamespaces(u,s){const o=di();return this.options.ns?(F(u)&&(u=[u]),u.forEach(f=>{this.options.ns.indexOf(f)<0&&this.options.ns.push(f)}),this.loadResources(f=>{o.resolve(),s&&s(f)}),o):(s&&s(),Promise.resolve())}loadLanguages(u,s){const o=di();F(u)&&(u=[u]);const f=this.options.preload||[],d=u.filter(m=>f.indexOf(m)<0&&this.services.languageUtils.isSupportedCode(m));return d.length?(this.options.preload=f.concat(d),this.loadResources(m=>{o.resolve(),s&&s(m)}),o):(s&&s(),Promise.resolve())}dir(u){var f,d;if(u||(u=this.resolvedLanguage||(((f=this.languages)==null?void 0:f.length)>0?this.languages[0]:this.language)),!u)return"rtl";try{const m=new Intl.Locale(u);if(m&&m.getTextInfo){const p=m.getTextInfo();if(p&&p.direction)return p.direction}}catch{}const s=["ar","shu","sqr","ssh","xaa","yhd","yud","aao","abh","abv","acm","acq","acw","acx","acy","adf","ads","aeb","aec","afb","ajp","apc","apd","arb","arq","ars","ary","arz","auz","avl","ayh","ayl","ayn","ayp","bbz","pga","he","iw","ps","pbt","pbu","pst","prp","prd","ug","ur","ydd","yds","yih","ji","yi","hbo","men","xmn","fa","jpr","peo","pes","prs","dv","sam","ckb"],o=((d=this.services)==null?void 0:d.languageUtils)||new Eh(sc());return u.toLowerCase().indexOf("-latn")>1?"ltr":s.indexOf(o.getLanguagePartFromCode(u))>-1||u.toLowerCase().indexOf("-arab")>1?"rtl":"ltr"}static createInstance(u={},s){const o=new gi(u,s);return o.createInstance=gi.createInstance,o}cloneInstance(u={},s=Uu){const o=u.forkResourceStore;o&&delete u.forkResourceStore;const f={...this.options,...u,isClone:!0},d=new gi(f);if((u.debug!==void 0||u.prefix!==void 0)&&(d.logger=d.logger.clone(u)),["store","services","language"].forEach(p=>{d[p]=this[p]}),d.services={...this.services},d.services.utils={hasLoadedNamespace:d.hasLoadedNamespace.bind(d)},o){const p=Object.keys(this.store.data).reduce((S,v)=>(S[v]={...this.store.data[v]},S[v]=Object.keys(S[v]).reduce((N,g)=>(N[g]={...S[v][g]},N),S[v]),S),{});d.store=new xh(p,f),d.services.resourceStore=d.store}if(u.interpolation){const S={...sc().interpolation,...this.options.interpolation,...u.interpolation},v={...f,interpolation:S};d.services.interpolator=new Ah(v)}return d.translator=new qu(d.services,f),d.translator.on("*",(p,...S)=>{d.emit(p,...S)}),d.init(f,s),d.translator.options=f,d.translator.backendConnector.services.utils={hasLoadedNamespace:d.hasLoadedNamespace.bind(d)},d}toJSON(){return{options:this.options,store:this.store,language:this.language,languages:this.languages,resolvedLanguage:this.resolvedLanguage}}}const se=gi.createInstance();se.createInstance;se.dir;se.init;se.loadResources;se.reloadResources;se.use;se.changeLanguage;se.getFixedT;se.t;se.exists;se.setDefaultNamespace;se.hasLoadedNamespace;se.loadNamespaces;se.loadLanguages;const Wy=(c,u,s,o)=>{var d,m,p,S;const f=[s,{code:u,...o||{}}];if((m=(d=c==null?void 0:c.services)==null?void 0:d.logger)!=null&&m.forward)return c.services.logger.forward(f,"warn","react-i18next::",!0);zn(f[0])&&(f[0]=`react-i18next:: ${f[0]}`),(S=(p=c==null?void 0:c.services)==null?void 0:p.logger)!=null&&S.warn?c.services.logger.warn(...f):console!=null&&console.warn&&console.warn(...f)},Mh={},$h=(c,u,s,o)=>{zn(s)&&Mh[s]||(zn(s)&&(Mh[s]=new Date),Wy(c,u,s,o))},Wh=(c,u)=>()=>{if(c.isInitialized)u();else{const s=()=>{setTimeout(()=>{c.off("initialized",s)},0),u()};c.on("initialized",s)}},hc=(c,u,s)=>{c.loadNamespaces(u,Wh(c,s))},_h=(c,u,s,o)=>{if(zn(s)&&(s=[s]),c.options.preload&&c.options.preload.indexOf(u)>-1)return hc(c,s,o);s.forEach(f=>{c.options.ns.indexOf(f)<0&&c.options.ns.push(f)}),c.loadLanguages(u,Wh(c,o))},Iy=(c,u,s={})=>!u.languages||!u.languages.length?($h(u,"NO_LANGUAGES","i18n.languages were undefined or empty",{languages:u.languages}),!0):u.hasLoadedNamespace(c,{lng:s.lng,precheck:(o,f)=>{if(s.bindI18n&&s.bindI18n.indexOf("languageChanging")>-1&&o.services.backendConnector.backend&&o.isLanguageChangingTo&&!f(o.isLanguageChangingTo,c))return!1}}),zn=c=>typeof c=="string",Py=c=>typeof c=="object"&&c!==null,t0=/&(?:amp|#38|lt|#60|gt|#62|apos|#39|quot|#34|nbsp|#160|copy|#169|reg|#174|hellip|#8230|#x2F|#47);/g,e0={"&amp;":"&","&#38;":"&","&lt;":"<","&#60;":"<","&gt;":">","&#62;":">","&apos;":"'","&#39;":"'","&quot;":'"',"&#34;":'"',"&nbsp;":" ","&#160;":" ","&copy;":"©","&#169;":"©","&reg;":"®","&#174;":"®","&hellip;":"…","&#8230;":"…","&#x2F;":"/","&#47;":"/"},a0=c=>e0[c],n0=c=>c.replace(t0,a0);let gc={bindI18n:"languageChanged",bindI18nStore:"",transEmptyNodeValue:"",transSupportBasicHtmlNodes:!0,transWrapTextNodes:"",transKeepBasicHtmlNodesFor:["br","strong","i","p"],useSuspense:!0,unescape:n0,transDefaultProps:void 0};const l0=(c={})=>{gc={...gc,...c}},i0=()=>gc;let Ih;const u0=c=>{Ih=c},s0=()=>Ih,o0={type:"3rdParty",init(c){l0(c.options.react),u0(c)}},c0=K.createContext();class r0{constructor(){this.usedNamespaces={}}addUsedNamespaces(u){u.forEach(s=>{this.usedNamespaces[s]||(this.usedNamespaces[s]=!0)})}getUsedNamespaces(){return Object.keys(this.usedNamespaces)}}var oc={exports:{}},cc={};/**
 * @license React
 * use-sync-external-store-shim.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Rh;function f0(){if(Rh)return cc;Rh=1;var c=Gh();function u(g,R){return g===R&&(g!==0||1/g===1/R)||g!==g&&R!==R}var s=typeof Object.is=="function"?Object.is:u,o=c.useState,f=c.useEffect,d=c.useLayoutEffect,m=c.useDebugValue;function p(g,R){var B=R(),M=o({inst:{value:B,getSnapshot:R}}),V=M[0].inst,et=M[1];return d(function(){V.value=B,V.getSnapshot=R,S(V)&&et({inst:V})},[g,B,R]),f(function(){return S(V)&&et({inst:V}),g(function(){S(V)&&et({inst:V})})},[g]),m(B),B}function S(g){var R=g.getSnapshot;g=g.value;try{var B=R();return!s(g,B)}catch{return!0}}function v(g,R){return R()}var N=typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"?v:p;return cc.useSyncExternalStore=c.useSyncExternalStore!==void 0?c.useSyncExternalStore:N,cc}var Uh;function d0(){return Uh||(Uh=1,oc.exports=f0()),oc.exports}var h0=d0();const g0=(c,u)=>zn(u)?u:Py(u)&&zn(u.defaultValue)?u.defaultValue:Array.isArray(c)?c[c.length-1]:c,m0={t:g0,ready:!1},p0=()=>()=>{},Ph=(c,u={})=>{var Ct,yt,ae;const{i18n:s}=u,{i18n:o,defaultNS:f}=K.useContext(c0)||{},d=s||o||s0();d&&!d.reportNamespaces&&(d.reportNamespaces=new r0),d||$h(d,"NO_I18NEXT_INSTANCE","useTranslation: You will need to pass in an i18next instance by using initReactI18next");const m=K.useMemo(()=>{var k;return{...i0(),...(k=d==null?void 0:d.options)==null?void 0:k.react,...u}},[d,u]),{useSuspense:p,keyPrefix:S}=m,v=f||((Ct=d==null?void 0:d.options)==null?void 0:Ct.defaultNS),N=zn(v)?[v]:v||["translation"],g=K.useMemo(()=>N,N);(ae=(yt=d==null?void 0:d.reportNamespaces)==null?void 0:yt.addUsedNamespaces)==null||ae.call(yt,g);const R=K.useRef(0),B=K.useCallback(k=>{if(!d)return p0;const{bindI18n:Z,bindI18nStore:W}=m,ut=()=>{R.current+=1,k()};return Z&&d.on(Z,ut),W&&d.store.on(W,ut),()=>{Z&&Z.split(" ").forEach(E=>d.off(E,ut)),W&&W.split(" ").forEach(E=>d.store.off(E,ut))}},[d,m]),M=K.useRef(),V=K.useCallback(()=>{if(!d)return m0;const k=!!(d.isInitialized||d.initializedStoreOnce)&&g.every(q=>Iy(q,d,m)),Z=u.lng||d.language,W=R.current,ut=M.current;if(ut&&ut.ready===k&&ut.lng===Z&&ut.keyPrefix===S&&ut.revision===W)return ut;const U={t:d.getFixedT(Z,m.nsMode==="fallback"?g:g[0],S),ready:k,lng:Z,keyPrefix:S,revision:W};return M.current=U,U},[d,g,S,m,u.lng]),[et,Q]=K.useState(0),{t:Dt,ready:ft}=h0.useSyncExternalStore(B,V,V);K.useEffect(()=>{if(d&&!ft&&!p){const k=()=>Q(Z=>Z+1);u.lng?_h(d,u.lng,g,k):hc(d,g,k)}},[d,u.lng,g,ft,p,et]);const ht=d||{},At=K.useRef(null),vt=K.useRef(),Tt=k=>{const Z=Object.getOwnPropertyDescriptors(k);Z.__original&&delete Z.__original;const W=Object.create(Object.getPrototypeOf(k),Z);if(!Object.prototype.hasOwnProperty.call(W,"__original"))try{Object.defineProperty(W,"__original",{value:k,writable:!1,enumerable:!1,configurable:!1})}catch{}return W},Nt=K.useMemo(()=>{const k=ht,Z=k==null?void 0:k.language;let W=k;k&&(At.current&&At.current.__original===k?vt.current!==Z?(W=Tt(k),At.current=W,vt.current=Z):W=At.current:(W=Tt(k),At.current=W,vt.current=Z));const ut=[Dt,W,ft];return ut.t=Dt,ut.i18n=W,ut.ready=ft,ut},[Dt,ht,ft,ht.resolvedLanguage,ht.language,ht.languages]);if(d&&p&&!ft)throw new Promise(k=>{const Z=()=>k();u.lng?_h(d,u.lng,g,Z):hc(d,g,Z)});return Nt},y0=[{to:"/",icon:Mp,labelKey:"nav.overview"},{to:"/health",icon:_p,labelKey:"nav.health"},{to:"/graph",icon:Rp,labelKey:"nav.graph"},{to:"/timeline",icon:Up,labelKey:"nav.timeline"},{to:"/evolution",icon:wp,labelKey:"nav.evolution"},{to:"/diagrams",icon:Bp,labelKey:"nav.mindmap"},{to:"/sync",icon:Lp,labelKey:"nav.sync"},{to:"/oracle",icon:jp,labelKey:"nav.oracle"},{to:"/tool-stats",icon:Hp,labelKey:"nav.toolStats"},{to:"/settings",icon:qp,labelKey:"nav.settings"}];function v0(){const c=Vu(s=>s.sidebarOpen),{t:u}=Ph();return w.jsxs("aside",{className:mi("fixed inset-y-0 left-0 z-30 flex flex-col border-r border-sidebar-border bg-sidebar transition-all duration-[var(--transition-normal)]",c?"w-56":"w-16"),children:[w.jsxs("div",{className:"flex h-14 items-center gap-3 border-b border-sidebar-border px-4",children:[w.jsx(Cp,{className:"size-6 shrink-0 text-sidebar-primary"}),c&&w.jsx("span",{className:"font-display text-base font-bold text-sidebar-foreground truncate",children:"Pug Brain"})]}),w.jsx("nav",{className:"flex-1 space-y-1 p-2","aria-label":u("common.mainNavigation"),children:y0.map(({to:s,icon:o,labelKey:f})=>{const d=u(f);return w.jsxs(xp,{to:s,end:s==="/",className:({isActive:m})=>mi("flex items-center gap-3 rounded-lg px-3 py-2 text-sm font-medium transition-colors cursor-pointer",m?"bg-sidebar-accent text-sidebar-primary":"text-sidebar-foreground/70 hover:bg-sidebar-accent hover:text-sidebar-foreground",!c&&"justify-center px-0"),title:d,children:[w.jsx(o,{className:"size-5 shrink-0","aria-hidden":"true"}),c&&w.jsx("span",{children:d})]},s)})}),w.jsx("div",{className:"border-t border-sidebar-border p-3",children:c&&w.jsx("p",{className:"text-xs text-sidebar-foreground/50 text-center",children:"Pug Brain"})})]})}function wh(c,u){if(typeof c=="function")return c(u);c!=null&&(c.current=u)}function b0(...c){return u=>{let s=!1;const o=c.map(f=>{const d=wh(f,u);return!s&&typeof d=="function"&&(s=!0),d});if(s)return()=>{for(let f=0;f<o.length;f++){const d=o[f];typeof d=="function"?d():wh(c[f],null)}}}}var S0=Symbol.for("react.lazy"),Yu=Tp[" use ".trim().toString()];function x0(c){return typeof c=="object"&&c!==null&&"then"in c}function tg(c){return c!=null&&typeof c=="object"&&"$$typeof"in c&&c.$$typeof===S0&&"_payload"in c&&x0(c._payload)}function T0(c){const u=O0(c),s=K.forwardRef((o,f)=>{let{children:d,...m}=o;tg(d)&&typeof Yu=="function"&&(d=Yu(d._payload));const p=K.Children.toArray(d),S=p.find(D0);if(S){const v=S.props.children,N=p.map(g=>g===S?K.Children.count(v)>1?K.Children.only(null):K.isValidElement(v)?v.props.children:null:g);return w.jsx(u,{...m,ref:f,children:K.isValidElement(v)?K.cloneElement(v,void 0,N):null})}return w.jsx(u,{...m,ref:f,children:d})});return s.displayName=`${c}.Slot`,s}var E0=T0("Slot");function O0(c){const u=K.forwardRef((s,o)=>{let{children:f,...d}=s;if(tg(f)&&typeof Yu=="function"&&(f=Yu(f._payload)),K.isValidElement(f)){const m=N0(f),p=A0(d,f.props);return f.type!==K.Fragment&&(p.ref=o?b0(o,m):m),K.cloneElement(f,p)}return K.Children.count(f)>1?K.Children.only(null):null});return u.displayName=`${c}.SlotClone`,u}var z0=Symbol("radix.slottable");function D0(c){return K.isValidElement(c)&&typeof c.type=="function"&&"__radixId"in c.type&&c.type.__radixId===z0}function A0(c,u){const s={...u};for(const o in u){const f=c[o],d=u[o];/^on[A-Z]/.test(o)?f&&d?s[o]=(...p)=>{const S=d(...p);return f(...p),S}:f&&(s[o]=f):o==="style"?s[o]={...f,...d}:o==="className"&&(s[o]=[f,d].filter(Boolean).join(" "))}return{...c,...s}}function N0(c){var o,f;let u=(o=Object.getOwnPropertyDescriptor(c.props,"ref"))==null?void 0:o.get,s=u&&"isReactWarning"in u&&u.isReactWarning;return s?c.ref:(u=(f=Object.getOwnPropertyDescriptor(c,"ref"))==null?void 0:f.get,s=u&&"isReactWarning"in u&&u.isReactWarning,s?c.props.ref:c.props.ref||c.ref)}const C0=Qh("inline-flex items-center justify-center gap-2 whitespace-nowrap rounded-lg text-sm font-medium transition-colors focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-ring disabled:pointer-events-none disabled:opacity-50 cursor-pointer [&_svg]:pointer-events-none [&_svg]:size-4 [&_svg]:shrink-0",{variants:{variant:{default:"bg-primary text-primary-foreground shadow-sm hover:bg-primary/90",destructive:"bg-destructive text-destructive-foreground shadow-sm hover:bg-destructive/90",outline:"border border-border bg-background shadow-sm hover:bg-accent hover:text-accent-foreground",secondary:"bg-secondary text-secondary-foreground shadow-sm hover:bg-secondary/80",ghost:"hover:bg-accent hover:text-accent-foreground",link:"text-primary underline-offset-4 hover:underline"},size:{default:"h-9 px-4 py-2",sm:"h-8 rounded-md px-3 text-xs",lg:"h-10 rounded-lg px-8",icon:"h-9 w-9"}},defaultVariants:{variant:"default",size:"default"}}),Bu=K.forwardRef(({className:c,variant:u,size:s,asChild:o=!1,...f},d)=>{const m=o?E0:"button";return w.jsx(m,{className:mi(C0({variant:u,size:s,className:c})),ref:d,...f})});Bu.displayName="Button";const M0="";class _0 extends Error{constructor(s,o){super(o);sh(this,"status");this.name="ApiError",this.status=s}}async function wu(c,u={}){const{brain:s,...o}=u,f=new Headers(o.headers);s&&f.set("X-Brain-ID",s),o.body&&!f.has("Content-Type")&&f.set("Content-Type","application/json");const d=await fetch(`${M0}${c}`,{...o,headers:f});if(!d.ok){const m=await d.text().catch(()=>"Unknown error");throw new _0(d.status,m)}return d.json()}const oe={get:(c,u)=>wu(c,{...u,method:"GET"}),post:(c,u,s)=>wu(c,{...s,method:"POST",body:u?JSON.stringify(u):void 0}),put:(c,u,s)=>wu(c,{...s,method:"PUT",body:u?JSON.stringify(u):void 0}),delete:(c,u)=>wu(c,{...u,method:"DELETE"})},Me={stats:["dashboard","stats"],brains:["dashboard","brains"],health:["dashboard","health"],healthCheck:["health"],toolStats:c=>["dashboard","tool-stats",c],timeline:(c,u)=>["dashboard","timeline",c,u],dailyStats:c=>["dashboard","timeline","daily-stats",c],evolution:["dashboard","evolution"],fibers:["dashboard","fibers"],fiberDiagram:c=>["dashboard","fiber",c,"diagram"],graph:c=>["graph",c],brainFiles:["dashboard","brain-files"],configStatus:["dashboard","config-status"]};function R0(){return Ce({queryKey:Me.stats,queryFn:()=>oe.get("/api/dashboard/stats")})}function U0(){return Ce({queryKey:Me.healthCheck,queryFn:()=>oe.get("/health"),staleTime:3e5})}function w0(){return Ce({queryKey:Me.brains,queryFn:()=>oe.get("/api/dashboard/brains")})}function Zv(){const c=Yh();return Vh({mutationFn:u=>oe.post("/api/dashboard/brains/switch",{brain_name:u}),onSuccess:()=>{c.invalidateQueries()}})}function kv(){return Ce({queryKey:Me.health,queryFn:()=>oe.get("/api/dashboard/health")})}function Jv(c=100,u=0){return Ce({queryKey:Me.timeline(c,u),queryFn:()=>oe.get(`/api/dashboard/timeline?limit=${c}&offset=${u}`)})}function Fv(c=30){return Ce({queryKey:Me.dailyStats(c),queryFn:()=>oe.get(`/api/dashboard/timeline/daily-stats?days=${c}`)})}function $v(){return Ce({queryKey:Me.evolution,queryFn:()=>oe.get("/api/dashboard/evolution")})}function Wv(){return Ce({queryKey:Me.fibers,queryFn:()=>oe.get("/api/dashboard/fibers")})}function Iv(c){return Ce({queryKey:Me.fiberDiagram(c),queryFn:()=>oe.get(`/api/dashboard/fiber/${c}/diagram`),enabled:!!c})}function Pv(c=500){return Ce({queryKey:Me.graph(c),queryFn:()=>oe.get(`/api/graph?limit=${c}`)})}function tb(){const c=Yh();return Vh({mutationFn:u=>oe.delete(`/brain/${u}`),onSuccess:()=>{c.invalidateQueries()}})}function eb(c=30){return Ce({queryKey:Me.toolStats(c),queryFn:()=>oe.get(`/api/dashboard/tool-stats?days=${c}`)})}function ab(){return Ce({queryKey:Me.brainFiles,queryFn:()=>oe.get("/api/dashboard/brain-files")})}function nb(){return Ce({queryKey:Me.configStatus,queryFn:()=>oe.get("/api/dashboard/config-status"),staleTime:6e4})}const B0=Qh("inline-flex items-center rounded-md border px-2.5 py-0.5 text-xs font-semibold transition-colors focus:outline-2 focus:outline-offset-2 focus:outline-ring",{variants:{variant:{default:"border-transparent bg-primary text-primary-foreground shadow",secondary:"border-transparent bg-secondary text-secondary-foreground",destructive:"border-transparent bg-destructive text-destructive-foreground shadow",outline:"text-foreground",success:"border-transparent bg-health-good/10 text-health-good",warning:"border-transparent bg-health-warn/10 text-health-warn"}},defaultVariants:{variant:"default"}});function L0({className:c,variant:u,...s}){return w.jsx("div",{className:mi(B0({variant:u}),c),...s})}const j0={light:Kp,dark:Xp,system:Qp},Bh={light:"common.lightMode",dark:"common.darkMode",system:"common.systemTheme"};function H0(){var g;const{sidebarOpen:c,toggleSidebar:u,theme:s,cycleTheme:o}=Vu(),{data:f}=R0(),{data:d}=U0(),{t:m,i18n:p}=Ph(),S=j0[s],v=(g=p.language)!=null&&g.startsWith("vi")?"vi":"en",N=()=>{const R=v==="vi"?"en":"vi";p.changeLanguage(R)};return w.jsxs("header",{className:"sticky top-0 z-20 flex h-14 items-center gap-4 border-b border-border bg-background/80 px-4 backdrop-blur-sm",children:[w.jsx(Bu,{variant:"ghost",size:"icon",onClick:u,"aria-label":m(c?"common.collapseSidebar":"common.expandSidebar"),children:c?w.jsx(Yp,{className:"size-5"}):w.jsx(Vp,{className:"size-5"})}),(f==null?void 0:f.active_brain)&&w.jsxs("div",{className:"flex items-center gap-2",children:[w.jsxs("span",{className:"text-sm text-muted-foreground",children:[m("common.brain"),":"]}),w.jsx(L0,{variant:"secondary",className:"font-mono text-xs",children:f.active_brain})]}),w.jsx("div",{className:"flex-1"}),w.jsxs(Bu,{variant:"ghost",size:"sm",onClick:N,className:"gap-1.5 px-2 text-xs font-medium","aria-label":"Switch language",children:[w.jsx(Gp,{className:"size-3.5"}),v==="vi"?"VI":"EN"]}),w.jsx(Bu,{variant:"ghost",size:"icon",onClick:o,"aria-label":m(Bh[s]),title:m(Bh[s]),children:w.jsx(S,{className:"size-4"})}),(d==null?void 0:d.version)&&w.jsxs("span",{className:"text-xs text-muted-foreground font-mono",children:["v",d.version]})]})}function q0(){const c=Vu(u=>u.sidebarOpen);return w.jsxs("div",{className:"min-h-screen bg-background relative",children:[w.jsx("div",{className:"fixed inset-0 tech-grid pointer-events-none z-0"}),w.jsx(v0,{}),w.jsxs("div",{className:mi("flex flex-col transition-all duration-[var(--transition-normal)] relative z-10",c?"ml-56":"ml-16"),children:[w.jsx(H0,{}),w.jsx("main",{className:"flex-1",children:w.jsx(Ep,{})})]})]})}function na(){return w.jsxs("div",{className:"space-y-6 p-6 animate-pulse",children:[w.jsx("div",{className:"h-8 w-48 rounded-lg bg-muted"}),w.jsx("div",{className:"grid grid-cols-1 gap-4 sm:grid-cols-2 lg:grid-cols-4",children:Array.from({length:4}).map((c,u)=>w.jsx("div",{className:"h-28 rounded-xl bg-muted"},u))}),w.jsxs("div",{className:"grid grid-cols-1 gap-6 lg:grid-cols-2",children:[w.jsx("div",{className:"h-64 rounded-xl bg-muted"}),w.jsx("div",{className:"h-64 rounded-xl bg-muted"})]})]})}const Y0=Xh(c=>({activeBrain:null,initialized:!1,setActiveBrain:u=>c({activeBrain:u}),setInitialized:u=>c({initialized:u})})),V0=K.lazy(()=>ia(()=>import("./OverviewPage-DMeHa7oG.js"),__vite__mapDeps([0,1,2,3,4,5]))),G0=K.lazy(()=>ia(()=>import("./HealthPage-DlixN64H.js"),__vite__mapDeps([6,1,2,3,4,7,5]))),Q0=K.lazy(()=>ia(()=>import("./GraphPage-OYcaWfTG.js"),__vite__mapDeps([8,1,2,3,4,5]))),X0=K.lazy(()=>ia(()=>import("./TimelinePage-Bi56EYGw.js"),__vite__mapDeps([9,1,2,3,4,5,7]))),K0=K.lazy(()=>ia(()=>import("./EvolutionPage-gBW1Q5Su.js"),__vite__mapDeps([10,1,2,3,4,7,5]))),Z0=K.lazy(()=>ia(()=>import("./DiagramsPage-CpiaiL7z.js"),__vite__mapDeps([11,1,2,3,4,7,5,12]))),k0=K.lazy(()=>ia(()=>import("./SettingsPage-DVxiNWC1.js"),__vite__mapDeps([13,1,2,3,5]))),J0=K.lazy(()=>ia(()=>import("./SyncPage-D3717Xlh.js"),__vite__mapDeps([14,1,2,3,5]))),F0=K.lazy(()=>ia(()=>import("./OraclePage-BL0_Z9Bu.js"),__vite__mapDeps([15,1,2,5]))),$0=K.lazy(()=>ia(()=>import("./ToolStatsPage-Dr1i9c83.js"),__vite__mapDeps([16,1,2,3,4,7,5])));function W0(){const{setActiveBrain:c,initialized:u,setInitialized:s}=Y0(),{data:o}=w0();return K.useEffect(()=>{if(u||!o||o.length===0)return;const f=o.find(d=>d.is_active);if(f)c(f.name);else{const d=o.find(m=>m.name==="default");c((d==null?void 0:d.name)??o[0].name)}s(!0)},[o,u,c,s]),w.jsx(Op,{children:w.jsxs(Ve,{element:w.jsx(q0,{}),children:[w.jsx(Ve,{index:!0,element:w.jsx(K.Suspense,{fallback:w.jsx(na,{}),children:w.jsx(V0,{})})}),w.jsx(Ve,{path:"health",element:w.jsx(K.Suspense,{fallback:w.jsx(na,{}),children:w.jsx(G0,{})})}),w.jsx(Ve,{path:"graph",element:w.jsx(K.Suspense,{fallback:w.jsx(na,{}),children:w.jsx(Q0,{})})}),w.jsx(Ve,{path:"timeline",element:w.jsx(K.Suspense,{fallback:w.jsx(na,{}),children:w.jsx(X0,{})})}),w.jsx(Ve,{path:"evolution",element:w.jsx(K.Suspense,{fallback:w.jsx(na,{}),children:w.jsx(K0,{})})}),w.jsx(Ve,{path:"diagrams",element:w.jsx(K.Suspense,{fallback:w.jsx(na,{}),children:w.jsx(Z0,{})})}),w.jsx(Ve,{path:"settings",element:w.jsx(K.Suspense,{fallback:w.jsx(na,{}),children:w.jsx(k0,{})})}),w.jsx(Ve,{path:"sync",element:w.jsx(K.Suspense,{fallback:w.jsx(na,{}),children:w.jsx(J0,{})})}),w.jsx(Ve,{path:"oracle",element:w.jsx(K.Suspense,{fallback:w.jsx(na,{}),children:w.jsx(F0,{})})}),w.jsx(Ve,{path:"tool-stats",element:w.jsx(K.Suspense,{fallback:w.jsx(na,{}),children:w.jsx($0,{})})}),w.jsx(Ve,{path:"*",element:w.jsx(zp,{to:"/",replace:!0})})]})})}const{slice:I0,forEach:P0}=[];function tv(c){return P0.call(I0.call(arguments,1),u=>{if(u)for(const s in u)c[s]===void 0&&(c[s]=u[s])}),c}function ev(c){return typeof c!="string"?!1:[/<\s*script.*?>/i,/<\s*\/\s*script\s*>/i,/<\s*img.*?on\w+\s*=/i,/<\s*\w+\s*on\w+\s*=.*?>/i,/javascript\s*:/i,/vbscript\s*:/i,/expression\s*\(/i,/eval\s*\(/i,/alert\s*\(/i,/document\.cookie/i,/document\.write\s*\(/i,/window\.location/i,/innerHTML/i].some(s=>s.test(c))}const Lh=/^[\u0009\u0020-\u007e\u0080-\u00ff]+$/,av=function(c,u){const o=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{path:"/"},f=encodeURIComponent(u);let d=`${c}=${f}`;if(o.maxAge>0){const m=o.maxAge-0;if(Number.isNaN(m))throw new Error("maxAge should be a Number");d+=`; Max-Age=${Math.floor(m)}`}if(o.domain){if(!Lh.test(o.domain))throw new TypeError("option domain is invalid");d+=`; Domain=${o.domain}`}if(o.path){if(!Lh.test(o.path))throw new TypeError("option path is invalid");d+=`; Path=${o.path}`}if(o.expires){if(typeof o.expires.toUTCString!="function")throw new TypeError("option expires is invalid");d+=`; Expires=${o.expires.toUTCString()}`}if(o.httpOnly&&(d+="; HttpOnly"),o.secure&&(d+="; Secure"),o.sameSite)switch(typeof o.sameSite=="string"?o.sameSite.toLowerCase():o.sameSite){case!0:d+="; SameSite=Strict";break;case"lax":d+="; SameSite=Lax";break;case"strict":d+="; SameSite=Strict";break;case"none":d+="; SameSite=None";break;default:throw new TypeError("option sameSite is invalid")}return o.partitioned&&(d+="; Partitioned"),d},jh={create(c,u,s,o){let f=arguments.length>4&&arguments[4]!==void 0?arguments[4]:{path:"/",sameSite:"strict"};s&&(f.expires=new Date,f.expires.setTime(f.expires.getTime()+s*60*1e3)),o&&(f.domain=o),document.cookie=av(c,u,f)},read(c){const u=`${c}=`,s=document.cookie.split(";");for(let o=0;o<s.length;o++){let f=s[o];for(;f.charAt(0)===" ";)f=f.substring(1,f.length);if(f.indexOf(u)===0)return f.substring(u.length,f.length)}return null},remove(c,u){this.create(c,"",-1,u)}};var nv={name:"cookie",lookup(c){let{lookupCookie:u}=c;if(u&&typeof document<"u")return jh.read(u)||void 0},cacheUserLanguage(c,u){let{lookupCookie:s,cookieMinutes:o,cookieDomain:f,cookieOptions:d}=u;s&&typeof document<"u"&&jh.create(s,c,o,f,d)}},lv={name:"querystring",lookup(c){var o;let{lookupQuerystring:u}=c,s;if(typeof window<"u"){let{search:f}=window.location;!window.location.search&&((o=window.location.hash)==null?void 0:o.indexOf("?"))>-1&&(f=window.location.hash.substring(window.location.hash.indexOf("?")));const m=f.substring(1).split("&");for(let p=0;p<m.length;p++){const S=m[p].indexOf("=");S>0&&m[p].substring(0,S)===u&&(s=m[p].substring(S+1))}}return s}},iv={name:"hash",lookup(c){var f;let{lookupHash:u,lookupFromHashIndex:s}=c,o;if(typeof window<"u"){const{hash:d}=window.location;if(d&&d.length>2){const m=d.substring(1);if(u){const p=m.split("&");for(let S=0;S<p.length;S++){const v=p[S].indexOf("=");v>0&&p[S].substring(0,v)===u&&(o=p[S].substring(v+1))}}if(o)return o;if(!o&&s>-1){const p=d.match(/\/([a-zA-Z-]*)/g);return Array.isArray(p)?(f=p[typeof s=="number"?s:0])==null?void 0:f.replace("/",""):void 0}}}return o}};let gl=null;const Hh=()=>{if(gl!==null)return gl;try{if(gl=typeof window<"u"&&window.localStorage!==null,!gl)return!1;const c="i18next.translate.boo";window.localStorage.setItem(c,"foo"),window.localStorage.removeItem(c)}catch{gl=!1}return gl};var uv={name:"localStorage",lookup(c){let{lookupLocalStorage:u}=c;if(u&&Hh())return window.localStorage.getItem(u)||void 0},cacheUserLanguage(c,u){let{lookupLocalStorage:s}=u;s&&Hh()&&window.localStorage.setItem(s,c)}};let ml=null;const qh=()=>{if(ml!==null)return ml;try{if(ml=typeof window<"u"&&window.sessionStorage!==null,!ml)return!1;const c="i18next.translate.boo";window.sessionStorage.setItem(c,"foo"),window.sessionStorage.removeItem(c)}catch{ml=!1}return ml};var sv={name:"sessionStorage",lookup(c){let{lookupSessionStorage:u}=c;if(u&&qh())return window.sessionStorage.getItem(u)||void 0},cacheUserLanguage(c,u){let{lookupSessionStorage:s}=u;s&&qh()&&window.sessionStorage.setItem(s,c)}},ov={name:"navigator",lookup(c){const u=[];if(typeof navigator<"u"){const{languages:s,userLanguage:o,language:f}=navigator;if(s)for(let d=0;d<s.length;d++)u.push(s[d]);o&&u.push(o),f&&u.push(f)}return u.length>0?u:void 0}},cv={name:"htmlTag",lookup(c){let{htmlTag:u}=c,s;const o=u||(typeof document<"u"?document.documentElement:null);return o&&typeof o.getAttribute=="function"&&(s=o.getAttribute("lang")),s}},rv={name:"path",lookup(c){var f;let{lookupFromPathIndex:u}=c;if(typeof window>"u")return;const s=window.location.pathname.match(/\/([a-zA-Z-]*)/g);return Array.isArray(s)?(f=s[typeof u=="number"?u:0])==null?void 0:f.replace("/",""):void 0}},fv={name:"subdomain",lookup(c){var f,d;let{lookupFromSubdomainIndex:u}=c;const s=typeof u=="number"?u+1:1,o=typeof window<"u"&&((d=(f=window.location)==null?void 0:f.hostname)==null?void 0:d.match(/^(\w{2,5})\.(([a-z0-9-]{1,63}\.[a-z]{2,6})|localhost)/i));if(o)return o[s]}};let eg=!1;try{document.cookie,eg=!0}catch{}const ag=["querystring","cookie","localStorage","sessionStorage","navigator","htmlTag"];eg||ag.splice(1,1);const dv=()=>({order:ag,lookupQuerystring:"lng",lookupCookie:"i18next",lookupLocalStorage:"i18nextLng",lookupSessionStorage:"i18nextLng",caches:["localStorage"],excludeCacheFor:["cimode"],convertDetectedLanguage:c=>c});class ng{constructor(u){let s=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};this.type="languageDetector",this.detectors={},this.init(u,s)}init(){let u=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{languageUtils:{}},s=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},o=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{};this.services=u,this.options=tv(s,this.options||{},dv()),typeof this.options.convertDetectedLanguage=="string"&&this.options.convertDetectedLanguage.indexOf("15897")>-1&&(this.options.convertDetectedLanguage=f=>f.replace("-","_")),this.options.lookupFromUrlIndex&&(this.options.lookupFromPathIndex=this.options.lookupFromUrlIndex),this.i18nOptions=o,this.addDetector(nv),this.addDetector(lv),this.addDetector(uv),this.addDetector(sv),this.addDetector(ov),this.addDetector(cv),this.addDetector(rv),this.addDetector(fv),this.addDetector(iv)}addDetector(u){return this.detectors[u.name]=u,this}detect(){let u=arguments.length>0&&arguments[0]!==void 0?arguments[0]:this.options.order,s=[];return u.forEach(o=>{if(this.detectors[o]){let f=this.detectors[o].lookup(this.options);f&&typeof f=="string"&&(f=[f]),f&&(s=s.concat(f))}}),s=s.filter(o=>o!=null&&!ev(o)).map(o=>this.options.convertDetectedLanguage(o)),this.services&&this.services.languageUtils&&this.services.languageUtils.getBestMatchFromCodes?s:s.length>0?s[0]:null}cacheUserLanguage(u){let s=arguments.length>1&&arguments[1]!==void 0?arguments[1]:this.options.caches;s&&(this.options.excludeCacheFor&&this.options.excludeCacheFor.indexOf(u)>-1||s.forEach(o=>{this.detectors[o]&&this.detectors[o].cacheUserLanguage(u,this.options)}))}}ng.type="languageDetector";const hv={overview:"Tổng quan",health:"Sức khỏe",graph:"Đồ thị",timeline:"Dòng thời gian",evolution:"Tiến hóa",mindmap:"Sơ đồ tư duy",oracle:"Tiên tri",toolStats:"Thống kê công cụ",sync:"Đồng bộ",settings:"Cài đặt"},gv={confirm:"Xác nhận",cancel:"Hủy",delete:"Xóa",loading:"Đang tải...",active:"Đang dùng",yes:"Có",no:"Không",none:"(trống)",neurons:"neuron",brain:"Bộ não",collapseSidebar:"Thu gọn thanh bên",expandSidebar:"Mở rộng thanh bên",mainNavigation:"Điều hướng chính",lightMode:"Chế độ sáng",darkMode:"Chế độ tối",systemTheme:"Theo hệ thống"},mv={title:"Tổng quan",neurons:"Neuron",synapses:"Synapse",fibers:"Fiber",brains:"Bộ não",brainList:"Danh sách bộ não",name:"Tên",grade:"Hạng",status:"Trạng thái",actions:"Thao tác",currentBrain:"Bộ não đang dùng",switchTo:"Nhấn để chuyển sang {{name}}",deleteBrain:"Xóa bộ não {{name}}",noBrains:"Không tìm thấy bộ não nào.",deleteBrainTitle:"Xóa bộ não",deleteBrainDesc:'Xóa bộ não "{{name}}"? Tất cả neuron, synapse và fiber sẽ bị xóa vĩnh viễn. Không thể hoàn tác.',switchedTo:"Đã chuyển sang: {{name}}",switchFailed:"Chuyển bộ não thất bại",deleted:"Đã xóa bộ não: {{name}}",deleteFailed:"Xóa bộ não thất bại"},pv={title:"Sức khỏe",brainMetrics:"Chỉ số bộ não",purity:"Độ tinh khiết",freshness:"Độ mới",connectivity:"Kết nối",diversity:"Đa dạng",consolidation:"Tổng hợp",activation:"Kích hoạt",recall:"Nhớ lại",orphanRate:"Tỷ lệ mồ côi",radarName:"Sức khỏe",warnings:"Cảnh báo & Khuyến nghị",noWarnings:"Không có cảnh báo. Bộ não khỏe mạnh!",recommendations:"Khuyến nghị",enrichTitle:"Cách làm giàu bộ não",enrichDesc:"Bộ não càng phong phú thì khả năng nhớ lại càng tốt. Đây là cách xây dựng neuron chi tiết và synapse mạnh mẽ.",collapseTips:"Thu gọn mẹo",expandTips:"Mở rộng mẹo",less:"Ít hơn",more:"Thêm",topPenalties:"Vấn đề chính ảnh hưởng điểm số",noPenalties:"Không có vấn đề đáng kể. Tiếp tục phát huy!",penaltyPoints:"Mất {{points}} điểm",estimatedGain:"+{{gain}} điểm nếu sửa",currentScore:"Hiện tại: {{score}}%",weight:"Trọng số: {{weight}}%",fixAction:"Cách sửa"},yv={rememberTitle:"Yêu cầu agent ghi nhớ thường xuyên",rememberTips:['Sau mỗi quyết định: "Nhớ rằng chúng ta chọn PostgreSQL thay vì MongoDB cho user service"','Sau khi debug: "Nhớ nguyên nhân gốc là race condition trong WebSocket handler"','Sau cuộc họp: "Nhớ Alice đề xuất rate limiting ở tầng API gateway"','Sau khi học: "Nhớ Vite HMR yêu cầu export default cho React component"'],causalTitle:"Dùng ngôn ngữ nhân quả, phong phú",causalTips:['TỆ: "PostgreSQL" → chỉ tạo một neuron phẳng','TỐT: "Chúng ta chọn PostgreSQL thay MongoDB vì cần ACID transaction cho xử lý thanh toán" → tạo neuron concept + entity + decision với synapse CAUSED_BY',"Nói TẠI SAO, không chỉ CÁI GÌ — chuỗi nhân quả tạo kết nối neural phong phú hơn","Đề cập người, ngày, bối cảnh — chúng trở thành neuron riêng liên kết qua synapse"],diverseTitle:"Đa dạng loại bộ nhớ = nhớ lại tốt hơn",diverseTips:['Sự kiện: "API rate limit là 1000 req/phút mỗi user"','Quyết định: "Chúng ta chọn JWT thay session vì kiến trúc microservice"',`Lỗi: "Import thất bại vì cột 'email' đổi thành 'user_email' trong v3"`,'Insight: "Pattern: luôn xác thực webhook signature trước khi xử lý payload"','Workflow: "Quy trình deploy: lint → test → build → push → kiểm tra health check"'],trainTitle:"Huấn luyện từ tài liệu để có kiến thức vĩnh viễn",trainTips:["Dùng pugbrain_train để import tài liệu (PDF, DOCX, MD) — bộ nhớ được huấn luyện không bao giờ suy giảm","Dùng pugbrain_index để index codebase — cho phép recall nhận biết code","Ghim bộ nhớ quan trọng bằng pugbrain_pin — bỏ qua suy giảm và tổng hợp","Dùng pugbrain_eternal cho context dự án cần lưu trữ xuyên suốt các phiên"]},vv={title:"Đồ thị Neural",nodes:"Nút:",networkVisualization:"Trực quan hóa mạng",nodesCount:"{{nodes}} nút, {{edges}} cạnh",noNeurons:"Không tìm thấy neuron nào trong bộ não này.",concept:"khái niệm",entity:"thực thể",time:"thời gian",action:"hành động",state:"trạng thái",other:"khác"},bv={title:"Dòng thời gian",memoryTimeline:"Dòng thời gian bộ nhớ",entries:"{{total}} mục",noEntries:"Không có mục nào.",range7d:"7 ngày",range30d:"30 ngày",range90d:"90 ngày",rangeAll:"Tất cả",todayMemories:"Hôm nay",totalPeriod:"Tổng",avgPerDay:"TB/Ngày",activeDays:"Ngày hoạt động",activityTrend:"Xu hướng hoạt động",neuronDistribution:"Phân bố Neuron",recentActivity:"Hoạt động gần đây",neurons:"Neuron",fibers:"Fiber",synapses:"Synapse"},Sv={title:"Tiến hóa",brainMetrics:"Chỉ số bộ não",maturity:"Trưởng thành",plasticity:"Linh hoạt",semanticRatio:"Tỷ lệ ngữ nghĩa",totalFibers:"Tổng Fiber",totalNeurons:"Tổng Neuron",stageDistribution:"Phân bố giai đoạn",shortTerm:"Ngắn hạn",working:"Làm việc",episodic:"Tình huống",semantic:"Ngữ nghĩa"},xv={title:"Sơ đồ tư duy",fibers:"Fiber",noFibers:"Không tìm thấy fiber nào.",selectFiber:"Chọn một Fiber",fiberLabel:"Fiber: {{id}}...",neuronsCount:"Neuron:",connectionsCount:"Kết nối:",selectFiberPrompt:"Chọn một fiber để xem sơ đồ tư duy"},Tv={title:"Cài đặt",general:"Tổng quát",version:"Phiên bản",activeBrain:"Bộ não đang dùng",totalBrains:"Tổng bộ não",brainFiles:"Tệp bộ não",brainsDirectory:"Thư mục bộ não",totalDiskUsage:"Dung lượng sử dụng",telegramBackup:"Sao lưu Telegram",connected:"Đã kết nối",chatIds:"Chat ID",autoBackup:"Tự động sao lưu khi tổng hợp",sendTest:"Gửi thử",sending:"Đang gửi...",backupNow:"Sao lưu ngay",backingUp:"Đang sao lưu...",notConfigured:"Chưa cấu hình",telegramSetup:"Đặt biến môi trường <code>NMEM_TELEGRAM_BOT_TOKEN</code> và thêm <code>[telegram] chat_ids</code> vào config.toml.",feedbackTitle:"Góp ý & Báo lỗi",reportBug:"Báo lỗi",reportBugDesc:"Phát hiện lỗi? Tạo issue với các bước tái hiện.",featureRequest:"Yêu cầu tính năng",featureRequestDesc:"Có ý tưởng cải thiện PugBrain? Chúng tôi rất muốn nghe.",discussions:"GitHub Discussions",discussionsDesc:"Câu hỏi, mẹo hay, và hỗ trợ cộng đồng.",testSuccess:"Đã gửi tin nhắn thử thành công",testPartial:"Một số tin nhắn gửi thất bại",testFailed:"Gửi tin nhắn thử thất bại",backupSuccess:"Đã sao lưu! {{brain}} ({{size}}MB) đến {{count}} chat",backupSendFailed:"Sao lưu gửi thất bại",backupFailed:"Sao lưu thất bại"},Ev={title:"Tiên Tri",loading:"Đang kết nối ký ức...",needMore:"Não bạn cần thêm ký ức",needMoreDesc:"Tiên Tri cần ít nhất 3 ký ức để mở khóa. Hãy nhờ AI ghi nhớ các quyết định, hiểu biết, và bài học — rồi quay lại đây.",dailyHint:"Chạm vào từng lá bài để xem kết quả",past:"Quá khứ",present:"Hiện tại",future:"Tương lai",readingDate:"Bói cho {{brain}} ngày {{date}}",whatifHint:"Nếu những ký ức này va chạm thì sao?",reshuffle:"Xáo lại",memory:"Ký ức",wildcard:"Lá bất ngờ",matchupComplete:"Hoàn thành đấu trí!",matchupScoreDesc:"Dựa trên mức kích hoạt và kết nối của ký ức bạn chọn",playAgain:"Chơi lại",round:"Vòng {{current}} / {{total}}",choose:"Chọn",chosen:"Đã chọn!",score:"Điểm",dailyReading:"Bói hàng ngày",whatif:"Nếu Như",matchup:"Đấu Trí",copyCard:"Chép ảnh",copied:"Đã chép!",downloadCard:"Tải xuống"},Ov={title:"Thống kê công cụ",totalEvents:"Tổng sự kiện",successRate:"Tỷ lệ thành công",uniqueTools:"Công cụ đã dùng",topTools:"Công cụ hàng đầu",usageOverTime:"Sử dụng theo thời gian",detailTable:"Chi tiết công cụ",tool:"Công cụ",calls:"Lượt gọi",avgDuration:"Thời gian TB",server:"Server",noData:"Chưa có dữ liệu. Sử dụng các công cụ PugBrain để bắt đầu theo dõi."},zv={nav:hv,common:gv,overview:mv,health:pv,enrichment:yv,graph:vv,timeline:bv,evolution:Sv,diagrams:xv,settings:Tv,oracle:Ev,toolStats:Ov},Dv={overview:"Overview",health:"Health",graph:"Graph",timeline:"Timeline",evolution:"Evolution",mindmap:"Mindmap",sync:"Cloud Sync",oracle:"Oracle",toolStats:"Tool Stats",settings:"Settings"},Av={confirm:"Confirm",cancel:"Cancel",delete:"Delete",loading:"Loading...",active:"Active",yes:"Yes",no:"No",none:"(none)",neurons:"neurons",brain:"Brain",collapseSidebar:"Collapse sidebar",expandSidebar:"Expand sidebar",mainNavigation:"Main navigation",lightMode:"Light mode",darkMode:"Dark mode",systemTheme:"System theme"},Nv={title:"Overview",neurons:"Neurons",synapses:"Synapses",fibers:"Fibers",brains:"Brains",brainList:"Brains",name:"Name",grade:"Grade",status:"Status",actions:"Actions",currentBrain:"Current active brain",switchTo:"Click to switch to {{name}}",deleteBrain:"Delete brain {{name}}",noBrains:"No brains found.",deleteBrainTitle:"Delete Brain",deleteBrainDesc:'Delete brain "{{name}}"? This will remove all neurons, synapses, and fibers permanently. This cannot be undone.',switchedTo:"Switched to brain: {{name}}",switchFailed:"Failed to switch brain",deleted:"Deleted brain: {{name}}",deleteFailed:"Failed to delete brain"},Cv={title:"Health",brainMetrics:"Brain Metrics",purity:"Purity",freshness:"Freshness",connectivity:"Connectivity",diversity:"Diversity",consolidation:"Consolidation",activation:"Activation",recall:"Recall",orphanRate:"Orphan Rate",radarName:"Health",warnings:"Warnings & Recommendations",noWarnings:"No warnings. Brain is healthy!",recommendations:"Recommendations",enrichTitle:"How to Enrich Your Brain",enrichDesc:"A richer brain means better recall. Here's how to build detailed neurons and strong synapses.",collapseTips:"Collapse tips",expandTips:"Expand tips",less:"Less",more:"More",topPenalties:"Top Issues Hurting Your Score",noPenalties:"No significant penalties. Keep it up!",penaltyPoints:"{{points}} pts lost",estimatedGain:"+{{gain}} pts if fixed",currentScore:"Current: {{score}}%",weight:"Weight: {{weight}}%",fixAction:"Fix"},Mv={rememberTitle:"Ask your agent to remember frequently",rememberTips:['After every decision: "Remember that we chose PostgreSQL over MongoDB for the user service"','After debugging: "Remember the root cause was a race condition in the WebSocket handler"','After meetings: "Remember Alice suggested rate limiting at the API gateway level"','After learning: "Remember that Vite HMR requires export default for React components"'],causalTitle:"Use rich, causal language",causalTips:['BAD: "PostgreSQL" → creates a single flat neuron','GOOD: "We chose PostgreSQL over MongoDB because we need ACID transactions for payment processing" → creates concept + entity + decision neurons with CAUSED_BY synapses',"Include WHY, not just WHAT — causal chains create richer neural connections","Mention people, dates, and context — they become separate neurons linked by synapses"],diverseTitle:"Diverse memory types = stronger recall",diverseTips:['Facts: "The API rate limit is 1000 req/min per user"','Decisions: "We decided to use JWT over sessions because of microservice architecture"',`Errors: "Import failed because the column 'email' was renamed to 'user_email' in v3"`,'Insights: "Pattern: always validate webhook signatures before processing payloads"','Workflows: "Deploy process: lint → test → build → push → verify health check"'],trainTitle:"Train from documents for permanent knowledge",trainTips:["Use pugbrain_train to import docs (PDF, DOCX, MD) — trained memories never decay","Use pugbrain_index to index your codebase — enables code-aware recall","Pin critical memories with pugbrain_pin — they skip decay and consolidation","Use pugbrain_eternal for project-level context that should persist across all sessions"]},_v={title:"Neural Graph",nodes:"Nodes:",networkVisualization:"Network Visualization",nodesCount:"{{nodes}} nodes, {{edges}} edges",noNeurons:"No neurons found in this brain.",concept:"concept",entity:"entity",time:"time",action:"action",state:"state",other:"other"},Rv={title:"Timeline",memoryTimeline:"Memory Timeline",entries:"{{total}} entries",noEntries:"No timeline entries.",range7d:"7 Days",range30d:"30 Days",range90d:"90 Days",rangeAll:"All",todayMemories:"Today",totalPeriod:"Total",avgPerDay:"Avg/Day",activeDays:"Active Days",activityTrend:"Activity Trend",neuronDistribution:"Neuron Distribution",recentActivity:"Recent Activity",neurons:"Neurons",fibers:"Fibers",synapses:"Synapses"},Uv={title:"Evolution",brainMetrics:"Brain Metrics",maturity:"Maturity",plasticity:"Plasticity",semanticRatio:"Semantic Ratio",totalFibers:"Total Fibers",totalNeurons:"Total Neurons",stageDistribution:"Stage Distribution",shortTerm:"Short Term",working:"Working",episodic:"Episodic",semantic:"Semantic"},wv={title:"Mindmap",fibers:"Fibers",noFibers:"No fibers found.",selectFiber:"Select a Fiber",fiberLabel:"Fiber: {{id}}...",neuronsCount:"Neurons:",connectionsCount:"Connections:",selectFiberPrompt:"Select a fiber to view its mindmap"},Bv={title:"Settings",general:"General",version:"Version",activeBrain:"Active Brain",totalBrains:"Total Brains",brainFiles:"Brain Files",brainsDirectory:"Brains Directory",totalDiskUsage:"Total Disk Usage",telegramBackup:"Telegram Backup",connected:"Connected",chatIds:"Chat IDs",autoBackup:"Auto-backup on consolidation",sendTest:"Send Test",sending:"Sending...",backupNow:"Backup Now",backingUp:"Backing up...",notConfigured:"Not Configured",telegramSetup:"Set <code>NMEM_TELEGRAM_BOT_TOKEN</code> env var and add <code>[telegram] chat_ids</code> to config.toml.",feedbackTitle:"Feedback & Bug Report",reportBug:"Report a Bug",reportBugDesc:"Found something broken? Open an issue with steps to reproduce.",featureRequest:"Feature Request",featureRequestDesc:"Have an idea to improve PugBrain? We'd love to hear it.",discussions:"GitHub Discussions",discussionsDesc:"Questions, tips, and community support.",testSuccess:"Test message sent successfully",testPartial:"Some messages failed to send",testFailed:"Failed to send test message",backupSuccess:"Backup sent! {{brain}} ({{size}}MB) to {{count}} chat(s)",backupSendFailed:"Backup failed to send",backupFailed:"Backup failed"},Lv={title:"Cloud Sync",refresh:"Refresh",connectionStatus:"Connection",status:"Status",cloudConnected:"Connected",notConnected:"Not Connected",hubUrl:"Hub URL",apiKey:"API Key",deviceId:"Device ID",disconnect:"Disconnect",setupCloud:"Connect to Cloud",setupTitle:"Connect to Cloud Hub",setupDesc:"Enter your hub URL and API key to sync memories across devices. Register at the hub to get your key.",keyRequired:"API key is required",keyInvalid:"API key must start with nmk_",keyHint:"Get your key by registering at the hub. It starts with nmk_.",connect:"Connect",connecting:"Connecting...",connected:"Cloud sync connected!",connectFailed:"Failed to connect",disconnected:"Cloud sync disconnected",disconnectFailed:"Failed to disconnect",devices:"Devices",lastSync:"Last sync",never:"Never",noDevices:"No devices registered yet. Sync from a device to register it.",changeLog:"Change Log",totalChanges:"Total Changes",synced:"Synced",pending:"Pending",latestSequence:"Latest Sequence",conflictStrategy:"Conflict Resolution",conflictDesc:"How to resolve when the same memory is changed on multiple devices.",strategyUpdated:"Conflict strategy updated",updateFailed:"Failed to update config"},jv={title:"Brain Oracle",loading:"Channeling your memories...",needMore:"Your brain needs more memories",needMoreDesc:"The Oracle requires at least 3 memories to unlock. Ask your AI agent to remember decisions, insights, and learnings — then return for your reading.",dailyHint:"Tap each card to reveal your reading",past:"Past",present:"Present",future:"Future",readingDate:"Reading for {{brain}} on {{date}}",whatifHint:"What if these memories collided?",reshuffle:"Reshuffle",memory:"Memory",wildcard:"Wildcard",matchupComplete:"Matchup Complete!",matchupScoreDesc:"Based on activation strength and connections of your chosen memories",playAgain:"Play Again",round:"Round {{current}} / {{total}}",choose:"Choose",chosen:"Chosen!",score:"Score",dailyReading:"Daily Reading",whatif:"What If",matchup:"Matchup",copyCard:"Copy Card",copied:"Copied!",downloadCard:"Download"},Hv={title:"Tool Stats",totalEvents:"Total Events",successRate:"Success Rate",uniqueTools:"Unique Tools",topTools:"Top Tools",usageOverTime:"Usage Over Time",detailTable:"Tool Details",tool:"Tool",calls:"Calls",avgDuration:"Avg Duration",server:"Server",noData:"No tool events recorded yet. Use PugBrain tools to start tracking."},qv={nav:Dv,common:Av,overview:Nv,health:Cv,enrichment:Mv,graph:_v,timeline:Rv,evolution:Uv,diagrams:wv,settings:Bv,sync:Lv,oracle:jv,toolStats:Hv};se.use(ng).use(o0).init({resources:{vi:{translation:zv},en:{translation:qv}},fallbackLng:"en",detection:{order:["localStorage","navigator"],lookupLocalStorage:"pug-lang",caches:["localStorage"]},interpolation:{escapeValue:!1}});const Yv=new yp({defaultOptions:{queries:{staleTime:3e4,retry:1,refetchOnWindowFocus:!1}}});$p.createRoot(document.getElementById("root")).render(w.jsx(K.StrictMode,{children:w.jsx(vp,{client:Yv,children:w.jsxs(Dp,{basename:window.location.pathname.startsWith("/dashboard")?"/dashboard":"/ui",children:[w.jsx(W0,{}),w.jsx(Ey,{position:"bottom-right",toastOptions:{className:"bg-card text-card-foreground border-border"}})]})})}));export{Bu as B,nb as a,L0 as b,R0 as c,w0 as d,Zv as e,tb as f,kv as g,Pv as h,Fv as i,Jv as j,$v as k,Wv as l,Iv as m,oe as n,U0 as o,ab as p,eb as q,d0 as r,mi as s,Kv as t,Ph as u};
